package cn.estsh.i3plus.pojo.aps.bean;

import cn.estsh.i3plus.pojo.aps.annotation.ClassLevelAnnotation;
import cn.estsh.i3plus.pojo.aps.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.aps.common.BeanRelation;
import cn.estsh.i3plus.pojo.aps.holders.EBaseOrder;
import cn.estsh.i3plus.pojo.base.enumutil.ApsEnumUtil;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.util.Date;

/**
 * @Description :销售订单
 * @Reference :
 * @Author : jason.niu
 * @CreateDate : 2019-09-17
 * @Modify:
 **/
@Data
@EqualsAndHashCode(callSuper = true)
@Entity
@Table(name = "APS_SALES_ORDER")
@Api("销售订单")
@ClassLevelAnnotation(level = 3)
public class SalesOrder extends BaseOrder {
    private static final long serialVersionUID = -511784925441907538L;

    @Column(name="LOW_EST")
    @ApiParam(value ="底阶最早开始时间")
    private Date lowEst;

    @Column(name="SPECIFY_LOW_EST")
    @ApiParam(value ="指定底阶最早开始时间")
    private Date specifyLowEst;

    @Column(name="SPECIFY_LET")
    @ApiParam(value ="指定最晚结束时间")
    private Date specifyLet;

    @Column(name="SPECIFY_LEAD_TIME")
    @ApiParam(value ="指定提前期")
    @FieldAnnotation(editType = ApsEnumUtil.EDIT_TYPE.DURATION)
    private String specifyLeadTime;

    @Column(name="CALC_LEAD_TIME")
    @ApiParam(value ="提前期计算值")
    @FieldAnnotation(modify = false)
    private String calcLeadTime;

    @Column(name="ALLOW_DELAY_TIME")
    @ApiParam(value ="允许延期时间")
    @FieldAnnotation(editType = ApsEnumUtil.EDIT_TYPE.DURATION)
    private String allowDelayTime;

    @Column(name="ORDER_STATUS")
    @ApiParam(value ="订单状态")
    @FieldAnnotation(defaultValue = "WAITING")
    private ApsEnumUtil.SALES_ORDER_STATUS orderStatus;

    @Column(name="ORDER_SPLIT")
    @ApiParam(value ="拆分下发")
    @FieldAnnotation(defaultValue = "NONE", modify = false)
    private ApsEnumUtil.SALES_ORDER_SPLIT_STATUS orderSplit = ApsEnumUtil.SALES_ORDER_SPLIT_STATUS.NONE;

    @Column(name="CAN_MAT_CALC")
    @ApiParam(value ="是否参与物料运算")
    @FieldAnnotation(defaultValue = "1")
    private Boolean canMatCalc = true;

    @Column(name="DELIVER_RATE")
    @ApiParam(value ="发货百分比")
    private Double deliverRate;

    @Column(name="FINISH_COUNT")
    @ApiParam(value ="完工数")
    @FieldAnnotation(modify = false, defaultValue = "0")
    private Double finishCount;

    @Column(name="QUALIFIED_COUNT")
    @ApiParam(value ="检验合格数量")
    @FieldAnnotation(modify = false, defaultValue = "0")
    private Double qualifiedCount;

    @Column(name="SERIAL_NUMBER")
    @ApiParam(value ="拆分订单流水号")
    @FieldAnnotation(property = false)
    private Integer serialNumber = 0;

    @Column(name="FORCE_COUNT")
    @ApiParam(value ="强制完成数量")
    @FieldAnnotation(modify = false, defaultValue = "0")
    private Double forceCount;

    @JsonIgnore
    public Work getWork() {
        return BeanRelation.get(this, EBaseOrder.Works);
    }
}
