package cn.estsh.i3plus.pojo.aps.bean;

import cn.estsh.i3plus.pojo.aps.annotation.ClassLevelAnnotation;
import cn.estsh.i3plus.pojo.aps.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.aps.annotation.MainKey;
import cn.estsh.i3plus.pojo.aps.common.BaseAPS;
import cn.estsh.i3plus.pojo.aps.common.BeanRelation;
import cn.estsh.i3plus.pojo.aps.holders.EStandOperation;
import cn.estsh.i3plus.pojo.aps.validator.InsertGroup;
import cn.estsh.i3plus.pojo.aps.validator.UpdateGroup;
import cn.estsh.i3plus.pojo.base.enumutil.ApsEnumUtil;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;

/**
 * @Description : 标准工序
 * @Reference :
 * @Author : jason.niu
 * @CreateDate : 2019-09-17
 * @Modify:
 **/
@Data
@EqualsAndHashCode(callSuper = true)
@Entity
@Table(name = "APS_STAND_OPERATION")
@Api("标准工序")
@MainKey(groups = {InsertGroup.class, UpdateGroup.class})
@ClassLevelAnnotation(level = 1)
public class StandOperation extends BaseAPS {
    private static final long serialVersionUID = -6869403951765771775L;

    @Column(name="CODE")
    @ApiParam(value ="编码")
    @FieldAnnotation(popSearch = true, mainkey = true)
    private String code;

    @Column(name="NAME")
    @ApiParam(value ="名称")
    @FieldAnnotation(popSearch = true)
    private String name;

    @Column(name="DIRECTION")
    @ApiParam(value ="排程方向")
    @FieldAnnotation(defaultValue = "POSITIVE")
    private ApsEnumUtil.DIRECTION direction;

    @Column(name="MIN_SPACE_TIME")
    @ApiParam(value ="最小时间间隔")
    @FieldAnnotation(editType = ApsEnumUtil.EDIT_TYPE.DURATION)
    private String minSpaceTime;

    @Column(name="MAX_SPACE_TIME")
    @ApiParam(value ="最大时间间隔")
    @FieldAnnotation(editType = ApsEnumUtil.EDIT_TYPE.DURATION)
    private String maxSpaceTime;

    @Column(name="FLUSH_TIME_BLOCK")
    @ApiParam(value ="基准时间间隔")
    @FieldAnnotation(editType = ApsEnumUtil.EDIT_TYPE.DURATION)
    // 刷新计划时将一天时间按块分割，后工作在本工作的下一时间块中排程。
    private String flushTimeBlock;

    @Column(name="BASE_TIME_LIMIT")
    @ApiParam(value ="基准时间限制")
    @FieldAnnotation(editType = ApsEnumUtil.EDIT_TYPE.DURATION)
    private String baseTimeLimit;

    @Column(name="OVER_SHIFT_SPLIT_LIMIT")
    @ApiParam(value ="跨班次时间限制")
    @FieldAnnotation(editType = ApsEnumUtil.EDIT_TYPE.DURATION)
    private String overShiftSplitLimit;

    @Column(name="COMB_TYPE")
    @ApiParam(value ="生产组合方式")
    @FieldAnnotation(defaultValue = "MAX_ALL_RESOURCE")
    private ApsEnumUtil.RES_COMB_TIME_TYPE combType;

    @Column(name="WORK_SHOP_ID")
    @ApiParam(value ="车间代码")
    @FieldAnnotation(relation = "WorkShop")
    private Long workShopId;

    @Column(name="TYPE")
    @ApiParam(value ="工序类型")
    private ApsEnumUtil.SANLUX_OPERATION_TYPE type = ApsEnumUtil.SANLUX_OPERATION_TYPE.NORMAL;

    @JsonIgnore
    public WorkShop getWorkShop() { return BeanRelation.get(this, EStandOperation.WorkShop); }

    public void setWorkShop(WorkShop workShop) {
        this.workShopId = workShop != null ? workShop.getId() : 0L;
        BeanRelation.set(this, EStandOperation.WorkShop, workShop);
    }
}
