package cn.estsh.i3plus.pojo.base.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import com.alibaba.fastjson.annotation.JSONField;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import org.hibernate.annotations.GenericGenerator;

import javax.persistence.*;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @Description :
 * @Reference :
 * @Author : Castle
 * @CreateDate : 2023/2/1 10:12
 * @Modify:
 **/
@Data
@MappedSuperclass
//对象状态监听
@EntityListeners(BaseBeanListener.class)
public class BaseBean40 implements Serializable {

    private static final long serialVersionUID = 1L;
    /**
     * //此处使用hibernate的主键策略方式
     * //手动设置,使用iplus-platform-common中的idtool生成
     * //将Long类型系列化成String避免精度丢失
     */
    @Id
    @GeneratedValue(generator = "IDGenerator")
    @GenericGenerator(name = "IDGenerator", strategy = "assigned")
    @Column(name = "ID")
    @ApiParam(value = "主键", example = "0")
    @JsonSerialize(using = ToStringSerializer.class)
    @AnnoOutputColumn(hidden = true)
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.NUMBER, isRequire = 2)
    public Long id;

    /**
     * get单独处理
     */
    public Long getId() {
        if (id != null) {
            return id.longValue();
        } else {
            return id;
        }
    }

    /**
     * MonogoDB _id映射
     *
     * @param id
     */
    @JSONField(name = "_id")
    public void setId(Long id) {
        this.id = id;
    }

    @Column(name = "ORGANIZE_CODE")
    @ApiParam(value = "组织代码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT, isQuery = 2, isRequire = 2)
    public String organizeCode;

    @Column(name = "IS_VALID", columnDefinition = "int default 1")
    @ApiParam(value = "有效性", example = "1")
    @AnnoOutputColumn(refClass = WmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description", hidden = true)
    public Integer isValid;

    @Column(name = "IS_DELETED", columnDefinition = "int default 2")
    @ApiParam(value = "是否已删除", example = "2")
    @AnnoOutputColumn(hidden = true)
    public Integer isDeleted;

    @Column(name = "CREATE_USER", updatable = false)
    @ApiParam(value = "创建用户")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.LIST, getValWay = CommonEnumUtil.DYNAMIC_FIELD_GET_WAY.URL,
            dataSrc = "/impp/operate/sys-user/query-user-by-pager",
            searchColumnName = "userName", listColumnName = "userLoginName,userName", explicitColumnName = "userName")
    public String createUser;

    @Column(name = "CREATE_DATE_TIME", updatable = false)
    @ApiParam(value = "创建日期")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.DATETIME, isRequire = 2)
    public String createDatetime;

    @Column(name = "MODIFY_USER")
    @ApiParam(value = "修改人")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.LIST, getValWay = CommonEnumUtil.DYNAMIC_FIELD_GET_WAY.URL,
            dataSrc = "/impp/operate/sys-user/query-user-by-pager",
            searchColumnName = "userName", listColumnName = "userLoginName,userName", explicitColumnName = "userName")
    public String modifyUser;

    @Column(name = "MODIFY_DATE_TIME")
    @ApiParam(value = "修改日期")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.DATETIME, isRequire = 2)
    public String modifyDatetime;

    @Transient
    @ApiParam(value = "创建日期查询用，查询起始日期", example = "2018-01-01 01:00:00")
    @AnnoOutputColumn(hidden = true)
    public String createDateTimeStart;

    @Transient
    @ApiParam(value = "创建日期查询用，查询结束日期", example = "2018-12-31 23:59:59")
    @AnnoOutputColumn(hidden = true)
    public String createDateTimeEnd;

    @Transient
    @ApiParam(value = "修改日期查询用，查询起始日期", example = "2018-01-01 01:00:00")
    @AnnoOutputColumn(hidden = true)
    public String modifyDateTimeStart;

    @Transient
    @ApiParam(value = "修改日期查询用，查询结束日期", example = "2018-12-31 23:59:59")
    @AnnoOutputColumn(hidden = true)
    public String modifyDateTimeEnd;

    @Transient
    @ApiParam(value = "排序属性")
    @AnnoOutputColumn(hidden = true)
    public String orderByParam = "";

    @Transient
    @ApiParam(value = "排序类型，1 正序，2 倒序", example = "1")
    @AnnoOutputColumn(hidden = true)
    public transient Integer ascOrDesc = 1;

    public int getIsValidVal() {
        return this.isValid == null ? 0 : this.isValid;
    }

    public int getIsDeletedVal() {
        return this.isDeleted == null ? 0 : this.isDeleted;
    }

    //排序方式
    public String orderBy() {
        String result = "";
        if (orderByParam != null && orderByParam.trim().length() > 0) {
            result = " order by " + orderByParam;
            if (ascOrDesc == CommonEnumUtil.ASC_OR_DESC.ASC.getValue()) {
                result += " asc";
            } else {
                result += " desc";
            }
        }
        return result;
    }

    /***
     * 扩展字段40
     * 23个String
     * 2个text
     * 5个int
     * 5个long
     * 5个bigDecimal
     */
    @Column(name = "EXTEND1")
    @ApiParam(value = "扩展1")
    public String extend1;

    @Column(name = "EXTEND2")
    @ApiParam(value = "扩展2")
    public String extend2;

    @Column(name = "EXTEND3")
    @ApiParam(value = "扩展3")
    public String extend3;

    @Column(name = "EXTEND4")
    @ApiParam(value = "扩展4")
    public String extend4;

    @Column(name = "EXTEND5")
    @ApiParam(value = "扩展5")
    public String extend5;

    @Column(name = "EXTEND6")
    @ApiParam(value = "扩展6")
    public String extend6;

    @Column(name = "EXTEND7")
    @ApiParam(value = "扩展7")
    public String extend7;

    @Column(name = "EXTEND8")
    @ApiParam(value = "扩展8")
    public String extend8;

    @Column(name = "EXTEND9")
    @ApiParam(value = "扩展9")
    public String extend9;

    @Column(name = "EXTEND10")
    @ApiParam(value = "扩展10")
    public String extend10;

    @Column(name = "EXTEND11")
    @ApiParam(value = "扩展11")
    public String extend11;

    @Column(name = "EXTEND12")
    @ApiParam(value = "扩展12")
    public String extend12;

    @Column(name = "EXTEND13")
    @ApiParam(value = "扩展13")
    public String extend13;

    @Column(name = "EXTEND14")
    @ApiParam(value = "扩展14")
    public String extend14;

    @Column(name = "EXTEND15")
    @ApiParam(value = "扩展15")
    public String extend15;


    @Column(name = "EXTEND16")
    @ApiParam(value = "扩展16")
    public String extend16;

    @Column(name = "EXTEND17")
    @ApiParam(value = "扩展17")
    public String extend17;

    @Column(name = "EXTEND18")
    @ApiParam(value = "扩展18")
    public String extend18;

    @Column(name = "EXTEND19")
    @ApiParam(value = "扩展19")
    public String extend19;

    @Column(name = "EXTEND20")
    @ApiParam(value = "扩展20")
    public String extend20;

    @Column(name = "EXTEND21")
    @ApiParam(value = "扩展21")
    public String extend21;

    @Column(name = "EXTEND22")
    @ApiParam(value = "扩展22")
    public String extend22;

    @Column(name = "EXTEND23")
    @ApiParam(value = "扩展23")
    public String extend23;


    @Column(name = "EXTEND24", columnDefinition = "text")
    @ApiParam(value = "扩展24")
    public String extend24;

    @Column(name = "EXTEND25", columnDefinition = "text")
    @ApiParam(value = "扩展25")
    public String extend25;

    @Column(name = "EXTEND26")
    @ApiParam(value = "扩展26")
    public Integer extend26;

    @Column(name = "EXTEND27")
    @ApiParam(value = "扩展27")
    public Integer extend27;

    @Column(name = "EXTEND28")
    @ApiParam(value = "扩展28")
    public Integer extend28;

    @Column(name = "EXTEND29")
    @ApiParam(value = "扩展29")
    public Integer extend29;

    @Column(name = "EXTEND30")
    @ApiParam(value = "扩展30")
    public Integer extend30;

    @Column(name = "EXTEND31")
    @ApiParam(value = "扩展31")
    public BigDecimal extend31;

    @Column(name = "EXTEND32")
    @ApiParam(value = "扩展32")
    public BigDecimal extend32;

    @Column(name = "EXTEND33")
    @ApiParam(value = "扩展33")
    public BigDecimal extend33;

    @Column(name = "EXTEND34")
    @ApiParam(value = "扩展34")
    public BigDecimal extend34;

    @Column(name = "EXTEND35")
    @ApiParam(value = "扩展35")
    public BigDecimal extend35;


    @Column(name = "EXTEND36")
    @ApiParam(value = "扩展36")
    public Long extend36;

    @Column(name = "EXTEND37")
    @ApiParam(value = "扩展37")
    public Long extend37;

    @Column(name = "EXTEND38")
    @ApiParam(value = "扩展38")
    public Long extend38;

    @Column(name = "EXTEND39")
    @ApiParam(value = "扩展39")
    public Long extend39;

    @Column(name = "EXTEND40")
    @ApiParam(value = "扩展40")
    public Long extend40;
}

