package cn.estsh.i3plus.pojo.base.enumutil;

import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * @Description :
 * @Reference :
 * @Author : Castle
 * @CreateDate : 2022/1/18 16:10
 * @Modify:
 **/
public class BspEnumUtil {


    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum PARAM_TYPE {
        METHOD_PARAM_TYPE(10, "method", "方法参数"),
        SCRIPT_PARAM_TYPE(20, "script", "脚本参数");
        private Integer value;
        private String code;
        private String description;

        PARAM_TYPE(Integer value, String code, String description) {
            this.value = value;
            this.code = code;
            this.description = description;
        }

        public static PARAM_TYPE getByValue(String value) {
            for (PARAM_TYPE actionType : values()) {
                if (actionType.getValue().equals(value)) {
                    return actionType;
                }
            }
            return null;
        }

        public Integer getValue() {
            return value;
        }

        public String getCode() {
            return code;
        }

        public String getDescription() {
            return description;
        }
    }


    /**
     * 语言类型（Groovy、Python、JavaScript、Scala、Ruby）
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum SCRIPT_LANGUAGE {
        GROOVY(10, "Groovy"),
        PYTHON(20, "Python"),
        JAVA_SCRIPT(30, "JavaScript"),
        SCALA(40, "Scala"),
        RUBY(50, "Ruby");

        private int value;
        private String description;

        SCRIPT_LANGUAGE(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }

    /**
     * 脚本类型（Groovy、Python、JavaScript、Scala、Ruby）
     * 用于策略模式，脚本执行
     * 要和language_type一对一
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum SCRIPT_TYPE {
        GROOVY(10, "groovyScript"),
        PYTHON(20, "pythonScript"),
        JAVA_SCRIPT(30, "javaScript"),
        SCALA(40, "scalaScript"),
        RUBY(50, "rubyScript");

        private int value;
        private String beanName;

        SCRIPT_TYPE(int value, String beanName) {
            this.value = value;
            this.beanName = beanName;
        }

        public int getValue() {
            return value;
        }

        public String getBeanName() {
            return beanName;
        }

        public static String valueOfBeanName(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].beanName;
                }
            }
            return tmp;
        }
    }

    /**
     * 方法组类型
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum METHOD_GROUP_TYPE {
        BSP(10, "BSP"),
        WMS(20, "WMS"),
        MES(30, "MES"),
        APS(40, "APS"),
        MES_PCN(50, "MES_PCN");

        private int value;
        private String description;

        METHOD_GROUP_TYPE(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }


    /**
     * 执行器区分执行的是方法还是脚本
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum METHOD_OR_SCRIPT {
        METHOD(10, "METHOD"),
        SCRIPT(20, "SCRIPT");

        private int value;
        private String description;

        METHOD_OR_SCRIPT(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }

    /**
     * 心跳状态 1存活，2死掉
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum HEART_BEAT {
        UP(1, "UP"),
        DOWN(2, "DOWN");

        private int value;
        private String description;

        HEART_BEAT(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }


    /**
     * 心跳状态 1存活，2死掉
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum REGISTRY_TYPE {
        MANUAL(1, "MANUAL"),
        AUTO(2, "AUTO");

        private int value;
        private String description;

        REGISTRY_TYPE(int value, String description) {
            this.value = value;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }
    }


    /**
     * 软件类型
     */
    @JsonFormat(shape = JsonFormat.Shape.OBJECT)
    public enum SOFT_TYPE {
        /**
         * WMS 服务
         */
        WMS(3, "i3wms", "仓库管理软件"),
        SWEB(7,"i3sweb", "供应商服务"),
        QMS(5, "i3qms", "质量管理软件"),
        TMS(101, "i3tms", "运输管理系统"),
        /**
         * Mes 服务
         */
        MES(4,  "i3mes", "生产管理软件"),
        MES_HISTORY(41,"i3mes-history","生产管理软件历史数据"),
        MES_PCN(6,  "i3mes-pcn", "生产管理软件-节点中心"),
        /**
         * PTL 服务
         */
        PTL(8,  "i3ptl", "亮灯自动拣选"),
        PTL_PCN(9,  "i3ptl-pcn", "亮灯自动拣选-节点中心"),
        /**
         * Block 服务
         */
        FORM(20,  "block-form", "智能表单"),
        REPORT(21,  "block-report", "智能报表"),
        WORKFLOW(22, "block-workflow", "智能工作流"),
        JOBFLOW(23,  "block-jobflow", "智能作业流"),
        SOFTSWITCH(24, "block-softswitch", "软件适配器"),
        HARDSWITCH(25, "block-hardswitch", "硬件适配器"),
        /**
         * LAC 服务
         */
        LAC(26, "lac", "连接适配器"),
        /**
         * 安灯服务
         */
        ANDON(27, "andon", "安灯"),
        /**
         * 计划排产服务
         */
        APS(28,  "i3aps", "高级计划与排产"),
        APS_2(18, "i3aps-2", "高级计划与排产-2"),
        APS_3(38,  "i3aps-3", "高级计划与排产-3"),
        APS_4(48,  "i3aps-4", "高级计划与排产-4"),
        SURFACE(98, "i3surface", "对外服务"),
        EAM(108,  "eam", "设备信息管理服务"),
        /**
         * 基础服务
         */
        IMPP(1,  "impp-platform", "IMPP平台"),
        CLOUD(97, "i3cloud", "微服务"),
        SCREEN(100,  "i3screen", "通用界面"),
        /**
         * 平台服务
         */
        CORE(2,  "i3core", "i3业务平台"),
        MDM(29,  "i3mdm", "数据中心MDM"),
        /**
         * 调试服务
         */
        DEV(9999,  "Development", "系统调试"),
        /**
         * 智能调度系统
         */
        LEO(50,  "impp-leo", "智能调度系统");
        /**
         * 产品ID
         */
        private int value;
        /**
         * 产品代码
         */
        private String code;
        /**
         * 产品描述
         */
        private String description;

        SOFT_TYPE(int value,  String code, String description) {
            this.value = value;
            this.code = code;
            this.description = description;
        }

        public int getValue() {
            return value;
        }

        public String getCode() {
            return code;
        }

        public String getDescription() {
            return description;
        }

        public static String valueOfCode(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].code;
                }
            }
            return tmp;
        }

        public static int codeOfValue(String code) {
            int tmp = 1;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].code.equals(code)) {
                    tmp = values()[i].value;
                }
            }
            return tmp;
        }



        public static String valueOfDescription(int val) {
            String tmp = null;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].value == val) {
                    tmp = values()[i].description;
                }
            }
            return tmp;
        }

        public synchronized static int descriptionOfValue(String desc) {
            int tmp = IMPP.value;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].description.equals(desc)) {
                    tmp = values()[i].value;
                    break;
                }
            }
            return tmp;
        }

        public static int descOf(String desc) {
            int tmp = IMPP.value;
            for (int i = 0; i < values().length; i++) {
                if (values()[i].name().equals(desc)) {
                    tmp = values()[i].value;
                }
            }
            return tmp;
        }
    }

}
