package cn.estsh.i3plus.pojo.bsp.server.bean.po;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.util.List;

/**
 * @Description :
 * @Reference :
 * @Author : Castle
 * @CreateDate : 2022/1/19 11:49
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "BSP_SCRIPT_PERSISTENCE", uniqueConstraints = {
        @UniqueConstraint(columnNames = {"ORGANIZE_CODE", "SCRIPT_NO"})
})
@Api("系统动态脚本")
public class ScriptPersistence extends BaseBean {
    @Column(name = "SCRIPT_NO", length = 50)
    @ApiModelProperty(value = "脚本调用的唯一编号，例如：WMS_PDA_0001")
    private String scriptNo;

    @ApiModelProperty(value = "脚本的中文名称")
    @Column(name = "SCRIPT_NAME", length = 50)
    private String scriptName;

    @ApiModelProperty(value = "目标执行器")
    @Column(name = "TARGET_EXECUTOR")
    private Integer targetExecutor;

    @ApiModelProperty(value = "脚本编写的语言 10=Groovy, 20=Jython, 30=JavaScript, 40=Scala, 50=JRuby")
    @Column(name = "LANGUAGE_TYPE")
    private Integer languageType;

    @Lob
    @Column(name = "SCRIPT_CONTENT", columnDefinition = "TEXT")
    @ApiModelProperty(value = "脚本的具体内容")
    private String scriptContent;

    @ApiModelProperty(value = "脚本的描述，包含脚本的用法，参数说明等")
    @Column(name = "SCRIPT_REMARK", length = 2000)
    private String scriptRemark;

    @ApiModelProperty(value = "编译后的脚本内容，通过预编译加快脚本的运行速度")
    @Transient
    private Object compiledScript;
//暂时不提供历史版本号功能
//    @Column(name = "SCRIPT_VERSION")
//    @ApiModelProperty(value = "脚本版本号")
//    private String scriptVersion;
//
//    @ApiModelProperty(value = "脚本编号列表")
//    @Transient
//    private List<String> versionList;

    @ApiModelProperty(value = "脚本参数列表")
    @Transient
    private List<ExecutorRegistryParamInfo> paramInfoList;

}
