package cn.estsh.i3plus.pojo.cdm.bean;

import cn.estsh.i3plus.pojo.cdm.annotation.BusiColumn;
import cn.estsh.i3plus.pojo.cdm.util.CdmEnumUtil;
import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "CDM_CUSTOMS_DETAIL",indexes = {@Index(columnList = "ORDER_NO")})
@Api("报关单明细")
public class CdmCustomsDetail extends BaseBean {

    @Column(name = "ORDER_NO")
    @ApiParam("单号")
    @BusiColumn(importGetMethod = "getCustomsDetailOrderNo")
    private String orderNo;

    @Column(name = "SAP_ORDER_NO")
    @ApiParam("SAP单号")
    private String sapOrderNo;

    @Column(name = "REF_ORDER_NO")
    @ApiParam("业务单号")
    private String refOrderNo;

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    @BusiColumn(importExcelColumn = 1)
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    @BusiColumn(importExcelColumn = 0)
    private String partNameRdd;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "QTY")
    @ApiParam("申报数量")
    @BusiColumn(importExcelColumn = 2)
    private Integer qty;

    @Column(name = "INVOICE_NO")
    @ApiParam("进出口发票")
    private String invoiceNo;

    /*取值来源为字典：ORIGIN_COUNTRY*/
    @Column(name = "PRODUCE_FRO")
    @ApiParam("原产国代号")
    @BusiColumn(importExcelColumn = 9)
    private Integer produceFro;

    /*取值来源为字典：PACKAGE_TYPE_DICTIONARY */
    @Column(name = "PACKAGE_TYPE")
    @ApiParam("包装类型")
    private String packageType;

    @Column(name = "TRADE_TYPE")
    @ApiParam("贸易类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.TRADE_TYPE.class,refForeignKey = "value", value = "description")
    private Integer tradeType;

    @Column(name = "TRADE_CODE")
    @ApiParam("贸易编码")
    private String tradeCode;

    @Column(name = "NOTE_BOOK_NO")
    @ApiParam("手册编号")
    private String noteBookNo;

    @Column(name = "REF_ORDER_TYPE")
    @ApiParam("单据类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.CUSTOMS_PART_PUT_REF_ORDER_TYPE.class,refForeignKey = "value", value = "description")
    private Integer refOrderType;

    @Column(name = "CUSTOMS_COMMODITY_NO")
    @ApiParam("海关商品料号")
    private String customsCommodityNo;

    @Column(name = "UNIT_PRICE")
    @ApiParam("单价")
    @BusiColumn(importExcelColumn = 3)
    private Double unitPrice;

    @Column(name = "CURRENCY")
    @ApiParam("币种")
    @BusiColumn(importExcelColumn = 4)
    private String currency;

    @Column(name = "LEGAL_MEASURE_NUMBER")
    @ApiParam("法定计量数量")
    @BusiColumn(importExcelColumn = 5)
    private Double legalMeasureNumber;

    @Column(name = "LEGAL_MEASURE_UNIT_NAME")
    @ApiParam("法定计量单位")
    @BusiColumn(importExcelColumn = 6)
    private String legalMeasureUnitName;

    @Column(name = "LEGAL2_MEASURE_NUMBER")
    @ApiParam("法定二计量数量")
    @BusiColumn(importExcelColumn = 7)
    private Double legal2MeasureNumber;

    @Column(name = "LEGAL2_MEASURE_UNIT_NAME")
    @ApiParam("法定二计量单位")
    @BusiColumn(importExcelColumn = 8)
    private String legal2MeasureUnitName;

    @Column(name = "CAR_NO")
    @ApiParam("车牌号码")
    @BusiColumn(importExcelColumn = 10)
    private String carNo;

    @Column(name = "GROSS_WEIGHT")
    @ApiParam("毛重")
    @BusiColumn(importExcelColumn = 11)
    private String grossWeight;

    @Column(name = "NET_WEIGHT")
    @ApiParam("净重")
    private String netWeight;

    @Column(name = "BOX_QTY")
    @ApiParam("箱数")
    private Integer boxQty;

    @Column(name = "RECORD_SERIAL_NUMBER")
    @ApiParam("备案序号")
    private Integer recordSerialNumber;

    @Column(name = "DIMENSIONS")
    @ApiParam("外形尺寸 mm")
    private String dimensions;

    @Column(name = "VOLUME")
    @ApiParam("体积")
    private String volume;

    @Column(name = "ORDER_STATUS",columnDefinition = "int(11) default 10")
    @ApiParam("报关状态")
    @AnnoOutputColumn(refClass = CdmEnumUtil.GENERATE.class,refForeignKey = "value", value = "description")
    private Integer orderStatus;

    @Column(name = "REF_QTY")
    @ApiParam("关联业务单数量")
    private Double refQty;

    @Column(name = "REF_ID")
    @ApiParam("关联业务单ID")
    private Long refId;

    /*取值来源为字典：SHIPPING_TYPE */
    @Column(name = "TRANS_PORT_TYPE")
    @ApiParam("运输方式")
    private String transPortType;

    @Column(name = "FINAL_COUNTRY_CODE")
    @ApiParam("目的国代号")
    private Integer finalCountryCode;

    @Column(name = "SUB_VENDOR_NO")
    @ApiParam("子供应商编码")
    private String subVendorNo;

    @Column(name = "SUB_VENDOR_NAME")
    @ApiParam("子供应商名称")
    private String subVendorName;

    @Column(name = "CUST_NO")
    @ApiParam("客户编码")
    private String custNo;

    @Column(name = "CUST_NAME")
    @ApiParam("客户名称")
    private String custName;

    @Transient
    @ApiParam("出发港")
    private String fromPort;

    @Transient
    @ApiParam("目的港")
    private String toPort;

    @Transient
    @ApiParam("现有数量")
    private String existingQty;

}
