package cn.estsh.i3plus.pojo.cdm.bean;

import cn.estsh.i3plus.pojo.cdm.annotation.BusiColumn;
import cn.estsh.i3plus.pojo.cdm.annotation.BusiTable;
import cn.estsh.i3plus.pojo.cdm.util.CdmEnumUtil;
import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "CDM_CUSTOMS_MASTER",indexes = {@Index(columnList = "ORDER_NO")})
@Api("报关单主表")
@BusiTable(importCustomLogicBefore = true)
public class CdmCustomsMaster extends BaseBean {

    @Column(name = "ORDER_NO")
    @ApiParam("单号")
    @BusiColumn(isPrimary = true,importGetMethod = "getCustomsOrderNo")
    private String orderNo;

    @Column(name = "BUSI_TYPE")
    @ApiParam("业务类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.CUSTOMS_BUSI_TYPE.class,refForeignKey = "value", value = "description")
    @BusiColumn(importExcelColumn = 0,isRequired = true)
    private Integer busiType;

    @Column(name = "CUSTOMS_TYPE")
    @ApiParam("报关类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.CUSTOMS_TYPE.class,refForeignKey = "value", value = "description")
    @BusiColumn(importExcelColumn = 3)
    private Integer customsType;

    @Column(name = "COMPNAY_LEVEL")
    @ApiParam("公司级别")
    @AnnoOutputColumn(refClass = CdmEnumUtil.COMPNAY_LEVEL.class,refForeignKey = "value", value = "description")
    private Integer compnayLevel;

    @Column(name = "GOODS_TYPE")
    @ApiParam("材料成品标志")
    @AnnoOutputColumn(refClass = CdmEnumUtil.GOODS_TYPE.class)
    private Integer goodsType;

    @Column(name = "UP_LOAD_STATUS",columnDefinition = "int(11) default 10")
    @ApiParam("核放单上传状态")
    @AnnoOutputColumn(refClass = CdmEnumUtil.UPLOAD.class,refForeignKey = "value", value = "description")
    private Integer upLoadStatus;

    @Column(name = "ORDER_STATUS",columnDefinition = "int(11) default 10")
    @ApiParam("报关状态")
    @AnnoOutputColumn(refClass = CdmEnumUtil.GENERATE.class,refForeignKey = "value", value = "description")
    private Integer orderStatus;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "CARD_ENTRY_DATE")
    @ApiParam("进出卡日期")
    private String cardEntryDate;

    @Column(name = "CAR_NO")
    @ApiParam("车牌号码")
    @BusiColumn(importExcelColumn = 11)
    private String carNo;

    @Column(name = "NET_WEIGHT")
    @ApiParam("车自重")
    @BusiColumn(importExcelColumn = 12)
    private Double netWeight;

    @Column(name = "CONTAINER_WEIGHT")
    @ApiParam("车架重")
    @BusiColumn(importExcelColumn = 13)
    private Double containerWeight;

    @Column(name = "INVOICE_NO")
    @ApiParam("发票号")
    @BusiColumn(importExcelColumn = 9)
    private String invoiceNo;

    @Column(name = "IS_CARPOOL")
    @ApiParam("是否总公司分公司拼车")
    @AnnoOutputColumn(refClass = CdmEnumUtil.TRUE_OR_FALSE.class,refForeignKey = "value", value = "description")
    private Integer isCarpool;

    @Column(name = "GOODS_ACCESS_TYPE")
    @ApiParam("货物进出类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.GOODS_PUT_OUT_TYPE.class,refForeignKey = "value", value = "description")
    @BusiColumn(importExcelColumn = 8)
    private Integer goodsAccessType;

    @Column(name = "QR_TYPE")
    @ApiParam("车辆二维码入关申请")
    @AnnoOutputColumn(refClass = CdmEnumUtil.CAR_QR_CODE_ENTRY_APPLICATION.class,refForeignKey = "value", value = "description")
    private Integer qrType;

    @Column(name = "CAR_ACCESS_TYPE")
    @ApiParam("车辆进出类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.CAR_PUT_OUT_TYPE.class,refForeignKey = "value", value = "description")
    @BusiColumn(importExcelColumn = 7)
    private Integer carAccessType;

    @Column(name = "TRAIN_NUMBER")
    @ApiParam("送货车次")
    @AnnoOutputColumn(refClass = CdmEnumUtil.DELIVERY_TRAIN_NUMBER.class,refForeignKey = "value", value = "description")
    private Integer trainNumber;

    @Column(name = "PRODUCT_EXIT_ENTRY_DATE")
    @ApiParam("原产品出入区日期")
    private String productExitEntryDate;

    /*取值来源为字典：SHIPPING_TYPE */
    @Column(name = "TRANS_PORT_TYPE")
    @ApiParam("运输方式")
    private String transPortType;

    @Column(name = "DELIVERY_DATE")
    @ApiParam("交货日期")
    @BusiColumn(importExcelColumn = 6)
    private String deliveryDate;

    @Column(name = "HEAD_CT_TYPE")
    @ApiParam("总公司托盘类型")
    private Integer headCtType;

    @Column(name = "HEAD_CT_QTY")
    @ApiParam("总公司托盘数量")
    private Integer headCtQty;

    @Column(name = "BRANCH_CT_TYPE")
    @ApiParam("分公司托盘类型")
    private Integer branchCtType;

    @Column(name = "BRANCH_CT_QTY")
    @ApiParam("分公司托盘数量")
    private Integer branchCtQty;

    @Column(name = "REMARK")
    @ApiParam("周转箱类型及数量")
    @BusiColumn(importExcelColumn = 18)
    private String remark;

    /**成品发运字段 start **/

    @Column(name = "CUST_NO")
    @ApiParam("客户编码")
    private String custNo;

    @Column(name = "CUST_NAME")
    @ApiParam("客户名称")
    private String custName;

    @Column(name = "contractNo")
    @ApiParam("合同号")
    private String contractNo;

    @Column(name = "BILL_NO")
    @ApiParam("提单号")
    private String billNo;

    @Column(name = "CONTAINER_TYPE")
    @ApiParam("集装箱类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.CONTAINER_TYPE.class,refForeignKey = "value", value = "description")
    private Integer containerType;

    /**取值来源为 字典SHIP_COMPNAY_DICTIONARY**/
    @Column(name = "SHIP_COMPNAY_CODE")
    @ApiParam("船公司编码")
    private String shipCompnayCode;


    /**取值来源为 字典SHIP_COMPNAY_DICTIONARY**/
    @Column(name = "SHIP_COMPNAY_NAME")
    @ApiParam("船公司名称")
    private String shipCompnayName;


    /**取值来源为 字典PAY_TYPE_DICTIONARY**/
    @Column(name = "PAY_TYPE")
    @ApiParam("付款方式类型")
    private String payType;


    @Column(name = "DEPARTURE_DAY")
    @ApiParam("出港日")
    private String departureDay;

    @Column(name = "DEST_CITY")
    @ApiParam("运抵国")
    private String destCity;

    @Column(name = "PACKAGE_QTY")
    @ApiParam("包装数量")
    private Integer packageQty;

    @Column(name = "FROM_PORT")
    @ApiParam("出发港")
    private String fromPort;

    @Column(name = "TO_PORT")
    @ApiParam("目的港")
    private String toPort;

    /**字典：PAYMENT_DICTIONARY**/
    @Column(name = "PAYMENT")
    @ApiParam("成交方式")
    private String payment;

    /**成品发运字段 end **/

    /**字典维护：PRODUCT_GROUP_DICTIONARY**/
    @Column(name = "PRODUCT_GROUP")
    @ApiParam("产品组(物料主线别)")
    private String productGroup;

    /** 物流/设备字段 start **/

    @Column(name = "COUNTERPARTY_CODE")
    @ApiParam("交易方代码")
    @BusiColumn(importExcelColumn = 2)
    private String counterpartyCode;

    @Column(name = "COUNTERPARTY_NAME")
    @ApiParam("交易方名称")
    @BusiColumn(importExcelColumn = 1)
    private String counterpartyName;

    @Column(name = "TRADE_TYPE")
    @ApiParam("贸易类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.TRADE_TYPE.class,refForeignKey = "value", value = "description")
    @BusiColumn(importExcelColumn = 4)
    private Integer tradeType;

    @Column(name = "BUSI_DECLARE_NO")
    @ApiParam("业务申报表编号")
    @BusiColumn(importExcelColumn = 5)
    private String busiDeclareNo;

    @Column(name = "BIND_TYPE")
    @ApiParam("绑定类型")
    @AnnoOutputColumn(refClass = CdmEnumUtil.BIND_TYPE.class)
    @BusiColumn(importExcelColumn = 10)
    private Integer bindType;

    @Column(name = "TOTAL_GROSS_WEIGHT")
    @ApiParam("总毛重")
    @BusiColumn(importExcelColumn = 14)
    private Double totalGrossWeight;

    @Column(name = "TOTAL_NET_WEIGHT")
    @ApiParam("总净重")
    @BusiColumn(importExcelColumn = 15)
    private Double totalNetWeight;

    @Column(name = "TOTAL_NUMBER")
    @ApiParam("总件数")
    @BusiColumn(importExcelColumn = 16)
    private Double totalNumber;

    // 字典维护 CURRENCY_SYSTEM_DICTIONARY
    @Column(name = "PACKAGE_TYPE")
    @ApiParam("包装类型")
    @BusiColumn(importExcelColumn = 17)
    private String packageType;

    @Column(name = "IS_BONDED_GOODS_CARPOOL")
    @ApiParam("是否与保税货物拼车")
    @AnnoOutputColumn(refClass = CdmEnumUtil.TRUE_OR_FALSE.class,refForeignKey = "value", value = "description")
    @BusiColumn(importExcelColumn = 18)
    private Integer isBondedGoodsCarpool;

    @Column(name = "IS_GENERATE_EXPORT_TASK" ,columnDefinition = "int(11) default 2")
    @ApiParam("是否已生成导出任务")
    @AnnoOutputColumn(refClass = CdmEnumUtil.TRUE_OR_FALSE.class,refForeignKey = "value", value = "description")
    private Integer isGenerateExportTask;

    //使用合同号字段
//    @Column(name = "TRANSACTION_NO")
//    @ApiParam("P/O NO单号")
//    private String transactionNo;

    @Column(name = "OUT_AREA_DATE")
    @ApiParam("出区日期")
    private String outAreaDate;

    @Column(name = "MARK")
    @ApiParam("唛头;发货标记;装运标志")
    private String mark;

    /**查询参数 start **/

    @Transient
    @ApiParam("查询参数，开始交货日期")
    private String deliveryDateStart;

    @Transient
    @ApiParam("查询参数，结束交货日期")
    private String deliveryDateEnd;

    @Transient
    @ApiParam("查询参数，进出卡开始日期")
    private String cardEntryDateStart;

    @Transient
    @ApiParam("查询参数，进出卡结束日期")
    private String cardEntryDateEnd;

    @Transient
    @ApiParam("付款方式")
    private String payTypeDesc;


    /**查询参数 end **/
}
