package cn.estsh.i3plus.pojo.cdm.bean;

import cn.estsh.i3plus.pojo.cdm.util.CdmEnumUtil;
import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 导出任务
 * @Reference :
 * @Author : puxiao
 * @CreateDate : 2022/5/10 22:48
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "CDM_EXPORT_TASK",indexes = {@Index(columnList = "TASK_NO,REF_ORDER_NO,MODULE_CODE")})
@Api("导出任务")
public class CdmExportTask extends BaseBean {

    @Column(name = "TASK_NO")
    @ApiParam("任务编码")
    private String taskNo;

    @Column(name = "REF_ORDER_NO")
    @ApiParam("关联单号")
    private String refOrderNo;

    @Column(name = "MODULE_CODE")
    @ApiParam("模块编码")
    private String moduleCode;

    @Column(name = "PARAMS",columnDefinition="TEXT")
    @ApiParam("参数")
    private String params;

    @Column(name = "PARAMS_CLASS_NAME")
    @ApiParam("参数类")
    private String paramsClassName;

    @Column(name = "TASK_STATUS")
    @ApiParam("状态")
    @AnnoOutputColumn(refClass = CdmEnumUtil.EXPORT_TASK_STATUS.class, refForeignKey = "value", value = "description")
    private Integer taskStatus;

    @Column(name = "REMARK")
    @ApiParam("备注")
    private String remark;

    @Transient
    @ApiParam("报关类型")
    private Integer customsType;

    @Transient
    @ApiParam("供应商编码")
    private String vendorNo;

    @Transient
    @ApiParam("供应商名称")
    private String vendorName;

    @Transient
    @ApiParam("车牌号码")
    private String carNo;

    @Transient
    @ApiParam("送货车次")
    private String trainNumber;

    public CdmExportTask(Long id, String organizeCode, String createUser, String createDatetime, String modifyUser, String modifyDatetime, String taskNo, String refOrderNo, String moduleCode, String params, String paramsClassName, Integer taskStatus, String remark, Integer customsType, String vendorNo, String vendorName, String carNo) {
        this.taskNo = taskNo;
        this.refOrderNo = refOrderNo;
        this.moduleCode = moduleCode;
        this.params = params;
        this.paramsClassName = paramsClassName;
        this.taskStatus = taskStatus;
        this.remark = remark;
        this.customsType = customsType;
        this.vendorNo = vendorNo;
        this.vendorName = vendorName;
        this.carNo = carNo;
        this.id = id;
        this.organizeCode = organizeCode;
        this.createUser = createUser;
        this.createDatetime = createDatetime;
        this.modifyUser = modifyUser;
        this.modifyDatetime = modifyDatetime;
    }

    public CdmExportTask(String taskNo, String refOrderNo, String moduleCode, String params, String paramsClassName, Integer taskStatus, String remark, Integer customsType, String vendorNo, String vendorName, String carNo, String trainNumber) {
        this.taskNo = taskNo;
        this.refOrderNo = refOrderNo;
        this.moduleCode = moduleCode;
        this.params = params;
        this.paramsClassName = paramsClassName;
        this.taskStatus = taskStatus;
        this.remark = remark;
        this.customsType = customsType;
        this.vendorNo = vendorNo;
        this.vendorName = vendorName;
        this.carNo = carNo;
        this.trainNumber = trainNumber;
    }

    public CdmExportTask() {
    }
}
