package cn.estsh.i3plus.pojo.cdm.bean;

import cn.estsh.i3plus.pojo.cdm.util.CdmEnumUtil;
import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : CDM采购信息
 * @Reference :
 * @Author : puxiao
 * @CreateDate : 2022/5/19 17:59
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "CDM_PURCHASE_INFO", indexes = {
        @Index(columnList = "VENDOR_NO, PART_NO"),
        @Index(columnList = "VENDOR_NO"),
        @Index(columnList = "PART_NO")
})
@Api("CDM采购信息")
public class CdmPurchaseInfo extends BaseBean {
    @Column(name = "VENDOR_NO")
    @ApiParam("供应商代码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String vendorNo;

    @ApiParam("供应商名称")
    @Transient
    private String vendorName;

    @Column(name = "PART_NO")
    @ApiParam("物料代码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNo;

    @ApiParam("物料名称")
    @Transient
    private String partNameRdd;

    @Column(name = "PURCHASE_CATEGORY")
    @ApiParam("采购信息类别")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    @AnnoOutputColumn(refClass = CdmEnumUtil.PURCHASE_CATEGORY.class, refForeignKey = "value", value = "description")
    private String purchaseCategory;


    @Column(name = "EFF_START_TIME")
    @ApiParam("有效开始日期")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String effStartTime;

    @Column(name = "EFF_END_TIME")
    @ApiParam("有效截止日期")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String effEndTime;

    @Column(name = "CURRENCY")
    @ApiParam("币种")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String currency;

    @Column(name = "UNIT_PRICE",columnDefinition = "decimal(18,8)")
    @ColumnDefault("0")
    @ApiParam("单价")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.NUMBER)
    private Double unitPrice;

    @Column(name = "QUANTITY_UNIT")
    @ApiParam("数量单位")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String quantityUnit;

    @Column(name = "SALES_ORGANIZE_CODE")
    @ApiParam("销售组织")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String saleOrganizeCode;
}
