package cn.estsh.i3plus.pojo.cdm.model;

import cn.estsh.i3plus.pojo.cdm.util.CdmEnumUtil;
import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.ColumnDefault;

import javax.persistence.*;

@Api("采购退货单报关model")
@Data
@NoArgsConstructor
@AllArgsConstructor
public class CdmCustomMovementDetailModel {

    @ApiParam("物料编码")
    public String partNo;

    @ApiParam("物料名称")
    public String partNameRdd;

    @ApiParam("行号")
    public String item;

    @ApiParam(
            value = "需求数量",
            example = "0"
    )
    public Double qty;

    @ApiParam("单位")
    public String unit;

    @ApiParam("订单号")
    public String orderNo;
    @Column(
            name = "SRC_WH_NO"
    )
    @ApiParam("源仓库代码")
    public String srcWhNo;

    @ApiParam("源存储区代码")
    public String srcZoneNo;

    @ApiParam("源库位代码")
    public String srcLocateNo;

    @ApiParam("目标仓库代码")
    public String destWhNo;

    @ApiParam("目标存储区代码")
    public String destZoneNo;

    @ApiParam("目标库位代码")
    public String destLocateNo;

    @ApiParam(
            value = "条码打印数量",
            example = "1"
    )
    private Double printQty;

    @ApiParam("计划日期")
    private String planDate;

    @ApiParam("计划时间")
    private String planTime;

    @Column(
            name = "SRC_NO"
    )
    @ApiParam("源单号")
    private String srcNo;

    @ApiParam(
            value = "状态",
            example = "1"
    )
    private Integer itemStatus;

    @ApiParam("工序")
    private String workCellCode;

    @ApiParam("缺陷代码")
    private String defectCode;

    @ApiParam("缺陷名称")
    private String defectName;

    @ApiParam("缺陷原因代码")
    private String dcCode;

    @ApiParam("缺陷原因名称")
    private String dcName;

    @ApiParam("维修代码")
    private String repairCode;

    @ApiParam("维修名称")
    private String repairName;

    @ApiParam(
            value = "是否免费",
            example = "1"
    )
    @AnnoOutputColumn(
            refClass = WmsEnumUtil.TRUE_OR_FALSE.class,
            refForeignKey = "value",
            value = "description"
    )
    public Integer isFree;

    @ApiParam("操作原因")
    private String remark;

    @ColumnDefault("0")
    @ApiParam(
            value = "已拣货数量",
            example = "1"
    )
    private Double pickQty;

    @ColumnDefault("0")
    @ApiParam(
            value = "已出库数量",
            example = "1"
    )
    private Double outQty;

    @ColumnDefault("0")
    @ApiParam(
            value = "已收货数量",
            example = "1"
    )
    private Double recQty;

    @ColumnDefault("0")
    @ApiParam(
            value = "已移库数量",
            example = "1"
    )
    private Double moveQty;

    @ColumnDefault("0")
    @ApiParam(
            value = "任务生成数量",
            example = "1"
    )
    private Double taskGenerateQty;

    @ColumnDefault("0")
    @ApiParam("已打印数量")
    private Double printGenerateQty;

    @ApiParam("源库存地代码")
    public String srcAreaNo;

    @ApiParam("目的库存地代码")
    public String destAreaNo;

    @ApiParam("目的线边存储区代码")
    public String destXBZoneNo;

    @ApiParam("批次")
    public String lotNo;

    @ApiParam("源单行号")
    public String srcItem;

    @ApiParam("客户订单号")
    public String custOrderNo;

    @ApiParam("指定生产日期")
    private String assignDateCode;

    @ApiParam("销售单据号")
    private String soOrderNo;

    @ApiParam("材料类型")
    private String melType;

    @ApiParam("项目号")
    private String projectNo;

    @ApiParam("生产小组")
    private String productionGroup;

    @ApiParam("客户零件号")
    private String custPartNo;

    @ApiParam("物料类型")
    private String materialType;

    @ApiParam("简称")
    private String partSpec;

    @ApiParam("工单码")
    private String workOrderCode;

    @ApiParam("父位置号")
    private String seqNo;


    @ApiParam("id")
    public Long id;

    @ApiParam("组织代码")
    public String organizeCode;

    @ApiParam(
            value = "有效性",
            example = "1"
    )
    public Integer isValid;

    @ApiParam(
            value = "是否已删除",
            example = "2"
    )
    public Integer isDeleted;

    @ApiParam("创建用户")
    public String createUser;

    @ApiParam("创建日期")
    public String createDatetime;

    @ApiParam("修改人")
    public String modifyUser;

    @ApiParam("修改日期")
    public String modifyDatetime;


    @Transient
    @ApiParam("未报关数量")
    private Double notDeclaredQty;

    public Double getNotDeclaredQty() {
        if (notDeclaredQty == null){
            return getQty();
        }
        return notDeclaredQty;
    }

    @Transient
    @ApiParam("报关状态")
    @AnnoOutputColumn(refClass = CdmEnumUtil.IS_DECLARED.class)
    private Integer declaredStatus;

    @Transient
    @ApiParam("供应商名称")
    public String vendorName;
    @Transient
    @ApiParam("供应商编号")
    private String vendorNo;

    public Integer getDeclaredStatus() {
        if (getNotDeclaredQty() == 0 || getNotDeclaredQty() == 0.0){
            return CdmEnumUtil.IS_DECLARED.IS_DECLARED.getValue();
        }else if (getNotDeclaredQty() < getQty()){
            return CdmEnumUtil.IS_DECLARED.DECLARED_ING.getValue();
        }else if (getNotDeclaredQty() == getQty()){
            return CdmEnumUtil.IS_DECLARED.NOT_DECLARED.getValue();
        }
        return CdmEnumUtil.IS_DECLARED.NOT_DECLARED.getValue();
    }
}
