package cn.estsh.i3plus.pojo.cdm.model;

import cn.estsh.i3plus.pojo.cdm.util.CdmEnumUtil;
import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.common.Pager;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.annotations.ColumnDefault;

import java.io.Serializable;


/**
 * @Description : PO采购订单表-实体类
 * @Reference : SwebPurchaseOrder
 * @Author : duan.yang
 * @CreateDate : 2021-01-15 21:41
 * @Modify: 修改
 **/
@Data
@NoArgsConstructor
@AllArgsConstructor
@Api("采购订单-PO-MODEL")
public class SwebPurchaseOrderModel implements Serializable {

    private static final long serialVersionUID = 288136219989308275L;

    @ApiParam("单据号")
    public String orderNo;

    @ApiParam("供应商编号")
    private String vendorNo;

    @ApiParam("供应商名称")
    private String vendorName;

    @ApiParam("计划员代码")
    private String plannerCode;
    @ApiParam(
            value = "订单类型",
            example = "1"
    )
    private Integer orderType;

    @ApiParam("上级包装编号")
    private String parentPackageNo;

    @ApiParam("道口")
    private String dock;

    @ApiParam("库存地")
    private String erpWarehouse;

    @ApiParam(
            value = "PO状态",
            example = "1"
    )
    private Integer poStatus;

    @ApiParam("发运时间")
    private String shipTime;

    @ApiParam("发布时间")
    private String publishTime;

    @ApiParam("交货时间")
    private String deliveryTime;

    @ApiParam("收货时间")
    private String recTime;

    @ApiParam(
            value = "是否收货",
            example = "2"
    )
    private Integer isSyn;

    @ApiParam("订单时间")
    private String orderTime;

    @ApiParam("关联单号")
    private String refOrderNo;

    @ApiParam("预计交货时间")
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private String expectedTime;

    @ApiParam("合同号")
    private String refNo;

    @ApiParam("订单来源")
    private Integer orderSource;

    @ApiParam("是否追加")
    private Integer isExtAdd;

    @ApiParam("预计到货时间 开始时间")
    private String expectedTimeStart;

    @ApiParam("预计到货时间 结束时间")
    private String expectedTimeEnd;

    @ApiParam("是否同步")
    public Integer isSync;

    @ApiParam("SAP单号")
    private String sapOrderNo;

    @ApiParam("工厂代码")
    private String factoryNo;

    @ApiParam("工厂名称")
    private String factoryName;

    @ApiParam("币种")
    private String currencyType;

    @ApiParam("单价")
    @ColumnDefault("0")
    private Double price = 0.0;

    @ApiParam("数量")
    @ColumnDefault("0")
    private Double orderQty = 0.0;

    @ApiParam("总价")
    @ColumnDefault("0")
    private Double total = 0.0;

    @ApiParam("物料编码")
    private String partNo;

    @ApiParam("物料名称")
    private String partName;

    @ApiParam("单位")
    private String unit;

    @ApiParam("变更前需求日")
    private String demandDayBeforeChange;

    @ApiParam("变更前交货数量")
    private Double deliveryAmountBeforeChange = 0.0;

    @ApiParam("变更后需求日")
    private String demandDayAfterChange;

    @ApiParam("变更后交货数量")
    private Double deliveryAmountAfterChange = 0.0;

    @ApiParam("收货数量")
    private Double recQty = 0.0;

    @ApiParam("检验合格数量")
    private Double qualifiedQty = 0.0;

    @ApiParam("入库数量")
    private Double inStockQty = 0.0;

    @ApiParam("同步标识")
    private Integer isSyncWms = 2;

    @ApiParam("PO单价")
    private Double netPrice;

    @ApiParam("PO单价(货币)")
    private String currency;

    @ApiParam("单位(倍数)")
    private Double multipleUnit;

    @ApiParam("PO金额")
    private Double poAmount;

    @ApiParam("PO金额(币别)")
    private String poCurrency;

    @ApiParam("打印状态")
    private Integer printStatus;

    @ApiParam("出厂报告状态")
    private Integer factoryReportStatus;

    @ApiParam("出厂报告状态-查询参数")
    private Integer factoryReportStatusParam;

    @ApiParam("上传时间")
    private String uploadDateTime;

    @ApiParam("文件ID")
    private Long fileId;

    @ApiParam("文件源名")
    private String fileOriginName;

    @ApiParam("文件URL")
    private String fileUrl;

    @ApiParam("已报关数量")
    private Double declaredQty;

    @ApiParam("未报关数量")
    private Double notDeclaredQty;

    //public Double getNotDeclaredQty() {
    //    if (orderQty == null || notDeclaredQty == null){
    //        return orderQty;
    //    }
    //    return orderQty - declaredQty;
    //}

    @ApiParam("报关状态")
    @AnnoOutputColumn(
            refClass = CdmEnumUtil.IS_DECLARED.class,
            refForeignKey = "value",
            value = "description"
    )
    private Integer declaredStatus;

    @ApiParam("id")
    private Long id;

    @ApiParam("修改时间")
    private String modifyDatetime;

    @ApiParam("修改人")
    private String modifyUser;

    @ApiParam("组织代码")
    private String organizeCode;

    @ApiParam("分页信息")
    private Pager pager;
}
