package cn.estsh.i3plus.pojo.eam.common;


import cn.estsh.i3plus.pojo.model.wms.BasBeanFieldInfoModel;
import cn.estsh.i3plus.pojo.model.wms.BasBeanInfoModel;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.hibernate.annotations.GenericGenerator;

import javax.persistence.Column;
import javax.persistence.ForeignKey;
import javax.persistence.Id;
import javax.persistence.Table;
import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import java.lang.reflect.Field;
import java.net.JarURLConnection;
import java.net.URL;
import java.util.*;
import java.util.jar.JarEntry;
import java.util.jar.JarFile;

/**
 * @Description :APS 实体对象的元信息
 * 包含实体对象之间的关联关系信息。
 * @Reference :
 * @Author : jason.niu
 * @CreateDate : 2019-09-17
 * @Modify:
 **/
public class BeanInfo {


    /**
     * 根据数据库表实体路径扫描获取字段信息可导入数据
     *
     * @return
     * @throws Exception
     */
    @ApiOperation("根据数据库实体对象路径扫描获取字段信息")
    public static List<Class<?>> importEntityField() {
        List<Class<?>> classList = loadClass("cn.estsh.i3plus.pojo.eam");
        return classList;
    }

    /**
     * 根据数据库表实体路径扫描获取字段信息
     *
     * @return
     * @throws Exception
     */
    @ApiOperation("根据数据库实体对象路径扫描获取字段信息")
    public static List<BasBeanInfoModel> globalScanDbEntityField() throws Exception {
        List<BasBeanInfoModel> resultList = new ArrayList<>();
        List<Class<?>> classList = loadClass("cn.estsh.i3plus.pojo.bean.master");

        // 循环获取实例字段信息
        for (Class<?> clazz : classList) {
            String tableName = null, tableDesc = null;
            BasBeanInfoModel beanInfoModel = new BasBeanInfoModel();
            List<BasBeanFieldInfoModel> fieldInfoModelList = new ArrayList<>();
            // cn.estsh.i3plus.pojo.andon.bean
            String packageName = clazz.getPackage().getName();
            String systemName = packageName.substring(21, packageName.indexOf(".", 21));

            // 获取普通属性的@ApiParam，@Table,@ApiParam
            Table tableField = clazz.getAnnotation(Table.class);
            ApiModel apiAnnotation = clazz.getAnnotation(ApiModel.class);

            //如果没有@Table注解则不存入数据库中
            if (tableField == null) {
                continue;
            } else {
                // 获取表名
                tableName = tableField.name();
            }

            // 判断是否存在Table注解
            if (apiAnnotation != null) {
                // 实体Bean对应数据库表中文描述
                tableDesc = apiAnnotation.value();
            } else {
                tableDesc = clazz.getSimpleName();
            }

            // 获得字段注解
            for (Field field : getFiledsInfo(clazz.getName())) {
                // 封装实体字段数据
                packBeanFieldData(fieldInfoModelList, field, tableName, tableDesc);
            }

            // 封装数据
            beanInfoModel.setEntityName(clazz.getSimpleName());
            beanInfoModel.setTableName(tableName);
            beanInfoModel.setSystemName(systemName);
            beanInfoModel.setTableDesc(tableDesc);
            beanInfoModel.setFieldInfoModelList(fieldInfoModelList);
            resultList.add(beanInfoModel);
        }

        return resultList;
    }

    @ApiOperation("根据数据库实体对象路径扫描获取字段信息")
    public static Map<String, String> globalScanDbEntityFieldMap() {
        Map<String, String> map = new HashMap<>();
        List<Class<?>> classList = loadClass("cn.estsh.i3plus.eam.pojo.pojo");

        // 循环获取实例字段信息
        for (Class<?> clazz : classList) {
            String tableDesc = null;

            ApiModel apiAnnotation = clazz.getAnnotation(ApiModel.class);
            Api api = clazz.getAnnotation(Api.class);
            // 判断是否存在Table注解
            if (apiAnnotation != null) {
                // 实体Bean对应数据库表中文描述
                tableDesc = apiAnnotation.value();
                map.put(clazz.getSimpleName(), tableDesc);
            } else if (api != null) {
                tableDesc = api.value();
                map.put(clazz.getSimpleName(), tableDesc);
            }

        }

        return map;
    }

    /**
     * 加载本地服务实现
     *
     * @param packName
     * @param dirPath
     * @param clses
     */
    private static void loadClassImpl(String packName, String dirPath, List<Class<?>> clses) {
        File dir = new File(dirPath);
        if (!dir.exists() || !dir.isDirectory()) {
            return;
        }

        File[] dirFiles = dir.listFiles(new FileFilter() {

            @Override
            public boolean accept(File file) {
                return file.isDirectory() || file.getName().endsWith(".class");
            }
        });

        for (File file : dirFiles) {
            if (file.isDirectory()) {
                loadClassImpl(packName + "." + file.getName(), dirPath + "/" + file.getName(), clses);
            } else {
                String clsName = file.getName();
                clsName = clsName.substring(0, clsName.length() - 6);
                try {
                    clses.add(Class.forName(packName + "." + clsName));
                } catch (ClassNotFoundException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static List<Class<?>> loadClass(String packName) {
        List<Class<?>> clses = new ArrayList<>();
        ClassLoader loader = Thread.currentThread().getContextClassLoader();
        String strFile = packName.replaceAll("\\.", "/");
        try {
            Enumeration<URL> urls = loader.getResources(strFile);
            while (urls.hasMoreElements()) {
                URL url = urls.nextElement();
                if (url != null) {
                    String protocol = url.getProtocol();
                    String filePath = url.getPath();
                    if (protocol.equals("file")) {
                        loadClassImpl(packName, filePath, clses);
                    } else if (protocol.equals("jar")) {
                        loadJarImpl(packName, url, clses);
                    }
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return clses;
    }

    //加载Jar
    private static void loadJarImpl(String packName, URL url, List<Class<?>> clses) throws IOException {
        JarURLConnection jarURLConnection = (JarURLConnection) url.openConnection();
        JarFile jarFile = jarURLConnection.getJarFile();
        Enumeration<JarEntry> jarEntries = jarFile.entries();
        while (jarEntries.hasMoreElements()) {
            JarEntry jarEntry = jarEntries.nextElement();
            final String jarEntryName = jarEntry.getName();
            if (jarEntryName.endsWith(".class")) {
                String clsName = jarEntryName.replace("/", ".");
                if (clsName.startsWith(packName)) {
                    clsName = clsName.substring(0, clsName.length() - 6);
                    try {
                        clses.add(Class.forName(clsName));
                    } catch (ClassNotFoundException e) {
                        e.printStackTrace();
                    }
                }
            }
        }
    }

    public static List<Field> getFiledsInfo(String className) throws ClassNotFoundException {
        List<Field> list = new ArrayList<>();
        Class<?> clazz = Class.forName(className);
        Field[] fields = clazz.getDeclaredFields();
        list.addAll(Arrays.asList(fields));
//        Class<?> superClazz = clazz.getSuperclass();
//        if (superClazz != null) {
//            Field[] superFields = superClazz.getDeclaredFields();
//            list.addAll(Arrays.asList(superFields));
//        }
        return list;
    }


    private static void packBeanFieldData(List<BasBeanFieldInfoModel> fieldInfoModelList, Field field, String tableName, String tableDesc) {
        // 字段名称
        Column fieldColumn = field.getAnnotation(Column.class);
        // 如果字段注解为空跳过
        if (fieldColumn == null) {
            return;
        }

        // 主键
        Id pkId = field.getAnnotation(Id.class);
        String isPk = pkId == null ? "N" : "Y";
        // 外键
        ForeignKey foreignKey = field.getAnnotation(ForeignKey.class);
        String isFk = foreignKey == null ? "N" : "Y";
        // 是否是主键自增
        GenericGenerator genericGenerator = field.getAnnotation(GenericGenerator.class);
        String isGeneric = genericGenerator == null ? "N" : "Y";
        // 字段名称
        String fieldName = fieldColumn.name();
        // 字段描述
        ApiParam fieldApiParam = field.getAnnotation(ApiParam.class);
        String fieldDesc = fieldApiParam != null ? fieldApiParam.value() : fieldName;
        // 字段类型
        String fieldType = field.getGenericType().getTypeName();
        // 字段是否允许为空
        String fieldIsNull = fieldColumn.nullable() == false ? "N" : "Y";
        // 唯一约束
        String fieldIsUnique = fieldColumn.unique() == false ? "N" : "Y";

        // 封装字段信息
        BasBeanFieldInfoModel beanFieldInfoModel = new BasBeanFieldInfoModel();
        beanFieldInfoModel.setTableName(tableName);
        beanFieldInfoModel.setFieldName(field.getName());
        beanFieldInfoModel.setFieldDesc(fieldDesc);
        beanFieldInfoModel.setFieldType(getDbFieldTypeByJavaFieldType(fieldType));
        beanFieldInfoModel.setIsFieldForeignKey(isFk);
        beanFieldInfoModel.setIsFieldNull(fieldIsNull);
        beanFieldInfoModel.setIsFieldPrimaryKey(isPk);
        beanFieldInfoModel.setIsFieldUnique(fieldIsUnique);
        beanFieldInfoModel.setIsFieldGeneric(isGeneric);
        beanFieldInfoModel.setTableDesc(tableDesc);
        fieldInfoModelList.add(beanFieldInfoModel);
    }

    private static String getDbFieldTypeByJavaFieldType(String fieldType) {
        String dbFieldType = null;

        if (StringUtils.equalsIgnoreCase(fieldType, "java.lang.String")) {
            dbFieldType = "VARCHAR(255)";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.lang.Double") || StringUtils.equalsIgnoreCase(fieldType, "Float")) {
            dbFieldType = "DECIMAL(18, 3)";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.lang.Integer")) {
            dbFieldType = "INTEGER";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.lang.Long")) {
            dbFieldType = "BIGINT";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "byte[]")) {
            dbFieldType = "VARBINARY";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.sql.Date")) {
            dbFieldType = "DATE";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.sql.Timestamp")) {
            dbFieldType = "TIMESTAMP";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.sql.Blob")) {
            dbFieldType = "BLOB";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.sql.Clob")) {
            dbFieldType = "CLOB";
        } else if (StringUtils.equalsIgnoreCase(fieldType, "java.math.BigDecimal")) {
            dbFieldType = "NUMERIC";
        }

        return dbFieldType;
    }
}
