package cn.estsh.i3plus.pojo.eam.common;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import io.swagger.annotations.ApiParam;
import lombok.Data;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.MappedSuperclass;
import javax.persistence.Transient;
import java.util.HashMap;
import java.util.Map;

/**
 * @author Jason
 * @ClassName: CommonBean
 * @Description: 通用实体类的基类
 * @date 2022-03-22
 */
@Data
@MappedSuperclass
@JsonIgnoreProperties(value={"hibernateLazyInitializer","handler","fieldHandler"})
public class CommonBean extends BaseBean {

    @Convert(converter = HashMapConverter.class)
    @FieldAnnotation(property = false)
    @Column(name = "CUSTOM_FIELDS",columnDefinition="nvarchar(max)")
    private Map<String, Object> customFields = new HashMap<>();

    @ApiParam(value = "主键值")
    @FieldAnnotation(display = false, isShow = false)
    @Transient
    private String key;

    @FieldAnnotation(property = false)
    private transient Long updateId = 0L;

    public CommonBean() {
    }

    public Object getCustomField(String code) {
        return getCustomFields().get(code);
    }

    public void setCustomField(String code, Object value) {
        getCustomFields().put(code, value);
    }

    public String getCustomString(String code) {
        Object value = getCustomFields().get(code);
        if (value == null) {
            return "";
        }
        return value.toString();
    }

    public Integer getCustomInteger(String code) {
        Object value = getCustomFields().get(code);
        if (value == null) {
            return null;
        }

        if (value.getClass() == String.class) {
            return Integer.valueOf((String) value);
        } else if (value.getClass() == Integer.class) {
            return (Integer) value;
        }
        return null;
    }

    public Double getCustomDouble(String code) {
        Object value = getCustomFields().get(code);
        if (value == null) {
            return null;
        }

        if (value.getClass() == String.class) {
            return Double.valueOf((String) value);
        } else if (value.getClass() == Double.class) {
            return (Double) value;
        }
        return null;
    }

    public Boolean getCustomBoolean(String code) {
        Object value = getCustomFields().get(code);
        if (value == null) {
            return null;
        }

        if (value.getClass() == Boolean.class) {
            return (Boolean) value;
        } else if (value.getClass() == Integer.class) {
            return (Integer) value == 1;
        }
        return null;
    }
}
