package cn.estsh.i3plus.pojo.eam.common;


import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.codemaker.SnowflakeIdMaker;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.base.util.StringUtil;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.eam.common.pojo.DynamicEnum;
import cn.estsh.i3plus.pojo.eam.common.pojo.FieldInfo;
import cn.estsh.i3plus.pojo.eam.common.pojo.GridField;
import cn.estsh.i3plus.pojo.eam.repository.DynamicEnumRepoitory;
import cn.estsh.i3plus.pojo.eam.repository.FieldInfoRepository;
import cn.estsh.i3plus.pojo.eam.repository.GridFieldRepository;
import cn.estsh.i3plus.pojo.eam.util.EnumUtil;
import cn.estsh.i3plus.pojo.wms.sqlpack.WmsHqlPack;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.persistence.ManyToMany;
import javax.persistence.OneToMany;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;
import java.sql.Timestamp;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author Jason
 * @ClassName: FieldInfoDao
 * @Description: 字段的访问层
 * @date 2022-03-22
 */
@Component
public class FieldInfoDao {
    private static final Logger LOG = LoggerFactory.getLogger(FieldInfoDao.class);
    @Autowired
    private FieldInfoRepository repository;
    @Autowired
    private GridFieldRepository gridFieldRepository;
    @Autowired
    private SnowflakeIdMaker snowflakeIdMaker;
    @Autowired
    private DynamicEnumRepoitory eamEnumRepoitory;

    public FieldInfo create() {
        FieldInfo bean = new FieldInfo();
        bean.setId(snowflakeIdMaker.nextId());
        bean.setIsValid(CommonEnumUtil.VALID);
        bean.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
        return bean;
    }

    public Map<String, FieldInfo> getDefaultFieldInfos(Class<? extends CommonBean> cls) {
        List<FieldInfo> infos = new ArrayList<>();
        try {
            getInnerFieldInfosImpl(infos, cls, cls, 0);
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return infos.stream().collect(Collectors.toMap(FieldInfo::getCode, info -> info));
    }

    private FieldInfo getDefaultFieldByCode(Class<? extends CommonBean> cls, String code) {
        return getDefaultFieldInfos(cls).get(code);
    }

    public FieldInfo getDefaultFieldByName(Class<? extends CommonBean> cls, String name) {
        Map<String, FieldInfo> fieldInfos = getDefaultFieldInfos(cls);
        for (Map.Entry<String, FieldInfo> entry : fieldInfos.entrySet()) {
            FieldInfo info = entry.getValue();
            if (StringUtils.isEmpty(info.getName())) {
                continue;
            }
            if (info.getName().equals(name)) {
                return info;
            }
        }

        return null;
    }

    private void getInnerFieldInfosImpl(List<FieldInfo> infos, Class<? extends BaseBean> cls, Class<? extends BaseBean> originCls, int orderNumber) throws Exception {
        if (cls == null) {
            return;
        }

        boolean defDisplay = true;
        boolean defShow = true;
        if (cls == CommonBean.class || cls == BaseBean.class) {
            defDisplay = false;
            defShow = false;
        }

        Field[] fields = cls.getDeclaredFields();
        for (Field field : fields) {
            if (Modifier.isTransient(field.getModifiers()) && !field.getName().equals("ascOrDesc")) {
                continue;
            }
            if (Modifier.isStatic(field.getModifiers())) {
                continue;
            }

            Class<?> typeClass = null;
            OneToMany oneToMany = field.getAnnotation(OneToMany.class);
            if (oneToMany != null) {
                typeClass = oneToMany.targetEntity();
            }
            ManyToMany manyToMany = field.getAnnotation(ManyToMany.class);
            if (manyToMany != null) {
                typeClass = manyToMany.targetEntity();
            }

            FieldAnnotation annotation = field.getAnnotation(FieldAnnotation.class);
            if (annotation != null) {
                if (!annotation.property()) {
                    continue;
                }
            }

            FieldInfo info = create();
            info.setCode(field.getName());
            ApiParam apiParam = field.getAnnotation(ApiParam.class);
            if (apiParam != null) {
                info.setName(apiParam.name());
            } else {
                ApiModelProperty apiProperty = field.getAnnotation(ApiModelProperty.class);
                if (apiProperty != null) {
                    info.setName(apiProperty.name());
                } else {
                    info.setName(field.getName());
                }
            }
            info.setCustomize(false);
            info.setClassName(originCls.getSimpleName());
            info.setClazz(originCls);
            if (info.getCode().equals("createDatetime") || info.getCode().equals("modifyDatetime")) {
                info.setTypeClass(Date.class);
            } else {
                info.setTypeClass(typeClass != null ? typeClass : field.getType());
            }
            if (typeClass != null) {
                info.setType(COMMON_FIELD_TYPE.LIST);
            } else {
                info.setType(getFieldType(info.getTypeClass()));
            }
            info.setTypeName(info.getTypeClass().getSimpleName());
            info.setTypeFullName(info.getTypeClass().getName());
            info.setOrderNumber(orderNumber++);

            if (annotation != null) {
                info.setModify(annotation.modify());
                info.setDisplay(annotation.display());
                info.setIsShow(annotation.isShow());
                info.setPric(annotation.pric());
                info.setMainKey(annotation.mainkey());
                info.setDefaultValue(annotation.defaultValue());
                info.setReadFunction(annotation.readFunction());
                info.setPopSearch(annotation.popSearch());
                info.setPopCondition(annotation.popCondition());
                info.setEditType(annotation.editType());
                info.setNotEmpty(annotation.notEmpty());
                info.setIsWhereSelect(annotation.isWhereSelect());
                info.setIsUpdate(annotation.isUpdate());

                info.setDynamicCalculate(annotation.dynamicCalculate());
                if (!StringUtil.isEmpty(annotation.typeName())) {
                    info.setTypeName(annotation.typeName());
                    if (ServiceInfo.getBeanClass(annotation.typeName()) == null) {  // 为页面自定义枚举
                        info.setType(COMMON_FIELD_TYPE.DYNAMIC_ENUM);
                        info.setEditType(COMMON_EDIT_TYPE.ENUM);
                    }
                }
                if (info.getEditType() != null && info.getEditType() == COMMON_EDIT_TYPE.DURATION) {
                    info.setType(COMMON_FIELD_TYPE.DURATION);
                }
                if (annotation.multiEnumClass() != Object.class) {
                    info.setTypeClass(annotation.multiEnumClass());
                    info.setType(COMMON_FIELD_TYPE.MULTI_ENUM);
                    info.setEditType(COMMON_EDIT_TYPE.MULTI_ENUM);
                    info.setTypeName(info.getTypeClass().getSimpleName());
                    info.setTypeFullName(info.getTypeClass().getName());
                }
                if (annotation.mainkey()) {
                    info.setNotEmpty(true);
                    info.setIsWhereSelect(true);
                    info.setIsUpdate(true);
                }
            } else {
                info.setModify(defDisplay || info.getCode().equals("isValid"));
                info.setDisplay(defDisplay);
                info.setIsShow(defShow);
                info.setMainKey(false);
                info.setIsUpdate(true);
                info.setDefaultValue("");
                info.setReadFunction("");
                info.setExcelExportVal("");
                info.setPopSearch(false);
                info.setPopCondition(false);
                info.setNotEmpty(false);
                info.setIsWhereSelect(false);
                info.setIsUpdate(false);
                info.setDynamicCalculate(false);
            }

            try {
                info.setGetMethod(cls.getMethod("get" + StringUtils.capitalize(info.getCode())));
            } catch (Exception ignored) {
            }
            try {
                info.setSetMethod(cls.getMethod("set" + StringUtils.capitalize(info.getCode()), field.getType()));
            } catch (Exception ignored) {
            }

            if (info.getGetMethod() == null) {
                throw new NoSuchMethodException(cls.getName() + "`s filed " + info.getCode() + " has not get method");
            }
            if (info.getSetMethod() == null) {
                throw new NoSuchMethodException(cls.getName() + "`s filed " + info.getCode() + " has not set method");
            }

            infos.add(info);
        }

        Class<?> supperClass = cls.getSuperclass();
        if (BaseBean.class.isAssignableFrom(supperClass)) {
            getInnerFieldInfosImpl(infos, (Class<BaseBean>) cls.getSuperclass(), originCls, orderNumber);
        }
    }

    private static COMMON_FIELD_TYPE getFieldType(Class<?> cls) {
        COMMON_FIELD_TYPE type = null;
        if (cls == Boolean.class || cls == boolean.class) {
            type = COMMON_FIELD_TYPE.BOOLEAN;
        } else if (cls == Character.class) {
            type = COMMON_FIELD_TYPE.CHAR;
        } else if (cls == Short.class || cls == short.class) {
            type = COMMON_FIELD_TYPE.SHORT;
        } else if (cls == Integer.class || cls == int.class) {
            type = COMMON_FIELD_TYPE.INTEGER;
        } else if (cls == Long.class || cls == long.class) {
            type = COMMON_FIELD_TYPE.LONG;
        } else if (cls == Double.class || cls == Float.class ||
                cls == double.class || cls == float.class) {
            type = COMMON_FIELD_TYPE.DOUBLE;
        } else if (cls == String.class) {
            type = COMMON_FIELD_TYPE.STRING;
        } else if (cls == Date.class || cls == java.sql.Date.class || cls == Timestamp.class) {
            type = COMMON_FIELD_TYPE.DATE_TIME;
        } else if (Enum.class.isAssignableFrom(cls)) {
            type = COMMON_FIELD_TYPE.ENUM;
        } else if (CommonBean.class.isAssignableFrom(cls)) {
            type = COMMON_FIELD_TYPE.OBJECT;
        } else if (List.class.isAssignableFrom(cls)) {
            type = COMMON_FIELD_TYPE.LIST;
        }
        return type;
    }

    public static Class<?> getFieldClass(COMMON_FIELD_TYPE type) {
        Class<?> cls = null;
        switch (type) {
            case BOOLEAN:
                cls = Boolean.class;
                break;
            case CHAR:
                cls = Character.class;
                break;
            case SHORT:
                cls = Short.class;
                break;
            case INTEGER:
                cls = Integer.class;
                break;
            case LONG:
                cls = Long.class;
                break;
            case DOUBLE:
                cls = Double.class;
                break;
            case DATE:
            case TIME:
            case DATE_TIME:
                cls = Date.class;
                break;
            case DYNAMIC_ENUM:
            case STRING:
                cls = String.class;
                break;
            default:
                break;
        }

        return cls;
    }

    public FieldInfo getById(Long id) {
        return repository.getById(id);
    }

    private void insertImpl(FieldInfo info) {
        if ((info.getType() == null || info.getType() == COMMON_FIELD_TYPE.NONE)) {
            info.setType(COMMON_FIELD_TYPE.STRING);
            info.setModify(false);
            info.setDisplay(true);
            info.setIsShow(true);
        }
        if (info.getClazz() == null) {
            info.setClazz(ServiceInfo.getBeanClass(info.getClassName()));
        }

        Class<?> typeClass = getFieldClass(info.getType());
        if (typeClass == null) {
            if (!StringUtil.isEmpty(info.getTypeFullName())) {
                try {
                    typeClass = Class.forName(info.getTypeFullName());
                } catch (ClassNotFoundException e) {
                    LOG.error("获取类型的Class失败：" + info.getTypeFullName(), e);
                }
            } else if (!StringUtil.isEmpty(info.getTypeName())) {
                typeClass = ServiceInfo.getBeanClass(info.getTypeName());
            } else {
                LOG.error("无效字段类型：" + info.getName());
                return;
            }
            if (typeClass == null) {
                return;
            }
        }
        info.setTypeClass(typeClass);
        if (StringUtils.isEmpty(info.getTypeName())) {
            info.setTypeName(typeClass.getSimpleName());
        }
        info.setTypeFullName(typeClass.getName());

        if (info.getPopSearch() == null) {
            info.setPopSearch(false);
        }
        if (info.getPopCondition() == null) {
            info.setPopCondition(false);
        }

        try {
            if (info.getGetMethod() == null) {
                if (info.getCustomize()) {
                    info.setGetMethod(info.getClazz().getMethod("getCustomField", String.class));
                } else {
                    info.setGetMethod(info.getClazz().getMethod("get" + StringUtils.capitalize(info.getCode())));
                }
            }
            if (info.getSetMethod() == null) {
                if (info.getCustomize()) {
                    info.setSetMethod(info.getClazz().getMethod("setCustomField", String.class, Object.class));
                } else if (info.getType() == COMMON_FIELD_TYPE.MULTI_ENUM) {
                    info.setSetMethod(info.getClazz().getMethod("set" + StringUtils.capitalize(info.getCode()), Integer.class));
                } else if (info.getType() == COMMON_FIELD_TYPE.DURATION) {
                    try {
                        info.setSetMethod(info.getClazz().getMethod("set" + StringUtils.capitalize(info.getCode()), String.class));
                    } catch (NoSuchMethodException ex) {
                        info.setSetMethod(info.getClazz().getMethod("set" + StringUtils.capitalize(info.getCode()), Integer.class));
                    }
                } else if (info.getCode().equals("createDatetime") || info.getCode().equals("modifyDatetime")) {
                    info.setSetMethod(info.getClazz().getMethod("set" + StringUtils.capitalize(info.getCode()), String.class));
                } else {
                    info.setSetMethod(info.getClazz().getMethod("set" + StringUtils.capitalize(info.getCode()), info.getTypeClass()));
                }
            }
        } catch (Exception ignored) {
        }
    }

    public long insert(FieldInfo item) {
        insertImpl(item);
        repository.save(item);
        return item.getId();
    }

    public void insert(Iterable<FieldInfo> items) {
        for (FieldInfo item : items) {
            insertImpl(item);
        }
        repository.saveAll(items);
    }

    private void updateImpl(FieldInfo item) {
        Class<?> typeClass = getFieldClass(item.getType());
        if (typeClass == null) {
            if (!StringUtil.isEmpty(item.getTypeFullName())) {
                try {
                    typeClass = Class.forName(item.getTypeFullName());
                } catch (ClassNotFoundException e) {
                    LOG.error("获取类型的Class失败：" + item.getTypeFullName(), e);
                }
            } else if (!StringUtil.isEmpty(item.getTypeName())) {
                typeClass = ServiceInfo.getBeanClass(item.getTypeName());
            } else {
                LOG.error("无效字段类型：" + item.getName());
                return;
            }
            if (typeClass == null) {
                return;
            }
        }
        item.setTypeClass(typeClass);
        if (StringUtils.isEmpty(item.getTypeName())) {
            item.setTypeName(typeClass.getSimpleName());
        }
        item.setTypeFullName(typeClass.getName());
    }

    public void update(FieldInfo item) {
        updateImpl(item);
        repository.save(item);
    }

    public void update(Iterable<FieldInfo> items) {
        for (FieldInfo item : items) {
            updateImpl(item);
        }
        repository.saveAll(items);
    }

    public void delete(FieldInfo item) {
        repository.delete(item);
    }

    public void delete(Iterable<FieldInfo> items) {
        repository.deleteAll(items);
    }

    public void deleteById(Long id) {
        repository.deleteById(id);
    }

    public int deleteByIds(Long[] ids) {
        return repository.deleteByIds(ids);
    }

    private List<FieldInfo> getByBeanClass(Class<? extends CommonBean> cls) {
        FieldInfo fieldInfo = new FieldInfo();
        fieldInfo.setClassName(cls.getSimpleName());
        fieldInfo.setOrganizeCode("");
        fieldInfo.setIsValid(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
        fieldInfo.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());

        DdlPackBean hqlInfo = DdlPackBean.getDdlPackBean(ServiceInfo.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(fieldInfo.getClassName(), "className", hqlInfo);
        WmsHqlPack.getStringBuilderPack(fieldInfo, hqlInfo);

        List<FieldInfo> fieldInfos = repository.findByHqlWhere(hqlInfo);
        Map<String, FieldInfo> defaultFields = getDefaultFieldInfos(cls);
        for (FieldInfo info : fieldInfos) {
            insertImpl(info);
            defaultFields.remove(info.getCode());
        }
        fieldInfos.addAll(defaultFields.values());
        return fieldInfos;
    }

    private FieldInfo getByFieldCode(Class<? extends CommonBean> cls, String code) {
        FieldInfo fieldInfo = new FieldInfo();
        fieldInfo.setClassName(cls.getSimpleName());
        fieldInfo.setCode(code);
        fieldInfo.setOrganizeCode("");
        fieldInfo.setIsValid(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
        fieldInfo.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());

        DdlPackBean hqlInfo = DdlPackBean.getDdlPackBean(ServiceInfo.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(fieldInfo.getClassName(), "className", hqlInfo);
        DdlPreparedPack.getStringEqualPack(fieldInfo.getCode(), "code", hqlInfo);
        WmsHqlPack.getStringBuilderPack(fieldInfo, hqlInfo);

        FieldInfo info = repository.getByProperty(hqlInfo);
        if (info != null) {
            insertImpl(info);
            return info;
        }
        return getDefaultFieldByCode(cls, code);
    }

    public FieldInfo getByFieldName(Class<? extends CommonBean> cls, String name) {
        FieldInfo fieldInfo = new FieldInfo();
        fieldInfo.setClassName(cls.getSimpleName());
        fieldInfo.setName(name);
        fieldInfo.setOrganizeCode("");
        fieldInfo.setIsValid(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
        fieldInfo.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());

        DdlPackBean hqlInfo = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(fieldInfo.getClassName(), "className", hqlInfo);
        DdlPreparedPack.getStringEqualPack(fieldInfo.getName(), "name", hqlInfo);
        WmsHqlPack.getStringBuilderPack(fieldInfo, hqlInfo);
        GridField gridField = gridFieldRepository.getByProperty(hqlInfo);

        FieldInfo info = null;
        if (!Objects.isNull(gridField)) {
            DdlPackBean hqlInfoNew = new DdlPackBean();
            DdlPreparedPack.getStringEqualPack(gridField.getClassName(), "className", hqlInfoNew);
            DdlPreparedPack.getStringEqualPack(gridField.getCode(), "code", hqlInfoNew);
            info = repository.getByProperty(hqlInfoNew);
            if (!Objects.isNull(info)) {
                info.setName(fieldInfo.getName());
            }

        }
        if (Objects.isNull(info)) {
            info = repository.getByProperty(hqlInfo);
        }
        if (info != null) {
            insertImpl(info);
        }
        return info != null ? info : getDefaultFieldByName(cls, name);
    }

    public List<FieldInfo> list(Class<? extends CommonBean> cls) {
        List<FieldInfo> result = new LinkedList<>();
        List<FieldInfo> fieldInfos = getByBeanClass(cls);
        DdlPackBean hqlInfo = DdlPackBean.getDdlPackBean(ServiceInfo.getOrganizeCode());
        List<DynamicEnum> eamEnums = eamEnumRepoitory.findByHqlWhere(hqlInfo);
        for (FieldInfo fieldInfo : fieldInfos) {
            setEnumItems(fieldInfo, eamEnums);
            result.add(fieldInfo);
        }
        result.sort((o1, o2) -> {
            if (o1.getOrderNumber() == null) {
                if (o2.getOrderNumber() == null) {
                    return o1.getCode().compareTo(o2.getCode());
                } else {
                    return 1;
                }
            } else if (o2.getOrderNumber() == null) {
                return -1;
            }
            return o1.getOrderNumber() - o2.getOrderNumber();
        });

        return result;
    }

    public FieldInfo get(Class<? extends CommonBean> cls, String code) {
        FieldInfo fieldInfo = getByFieldCode(cls, code);
        if (fieldInfo != null) {
            setEnumItems(fieldInfo, null);
        }
        return fieldInfo;
    }

    public List<FieldInfo> listMainKeys(Class<? extends CommonBean> cls, List<FieldInfo> fieldInfos) {
        List<FieldInfo> result = new ArrayList<>();
        if (CollectionUtils.isEmpty(fieldInfos)) {
            fieldInfos = getByBeanClass(cls);
        }
        FieldInfo idField = null;
        for (FieldInfo fieldInfo : fieldInfos) {
            if (fieldInfo.getMainKey() != null && fieldInfo.getMainKey()) {
                setEnumItems(fieldInfo, null);
                result.add(fieldInfo);
            }

            if (fieldInfo.getCode().equals("id")) {
                idField = fieldInfo;
            }
        }
        if (result.isEmpty()) {
            if (idField == null) {
                idField = getByFieldCode(cls, "id");
            }
            result.add(idField);
        }
        return result;
    }

    public FieldInfo getByName(Class<? extends CommonBean> cls, String name) {
        FieldInfo fieldInfo = getByFieldName(cls, name);
        if (fieldInfo != null) {
            setEnumItems(fieldInfo, null);
        }
        return fieldInfo;
    }

    private void setEnumItems(FieldInfo fieldInfo, List<DynamicEnum> eamEnums) {
        if (fieldInfo.getType() == COMMON_FIELD_TYPE.ENUM || fieldInfo.getType() == COMMON_FIELD_TYPE.MULTI_ENUM) {
            fieldInfo.setEnumItems(EnumUtil.convertEnumConstants((Class<? extends Enum<?>>) fieldInfo.getTypeClass()));
        } else if (fieldInfo.getType() == COMMON_FIELD_TYPE.DYNAMIC_ENUM) {
            fieldInfo.setEnumItems(getDynamicEnums(fieldInfo.getTypeName(), eamEnums));
        }
    }

    private List<Map<String, Object>> getDynamicEnums(String typeName, List<DynamicEnum> eamEnums) {
        List<Map<String, Object>> result = new ArrayList<>();
        DynamicEnum model = new DynamicEnum();
        model.setEnumType(typeName);
        model.setOrganizeCode(ServiceInfo.getOrganizeCode());
        model.setIsValid(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
        model.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
        if (CollectionUtils.isEmpty(eamEnums)) {
            DdlPackBean hqlInfo = DdlPackBean.getDdlPackBean(ServiceInfo.getOrganizeCode());
            DdlPreparedPack.getStringEqualPack(model.getEnumType(), "enumType", hqlInfo);
            WmsHqlPack.getStringBuilderPack(model, hqlInfo);
            eamEnums = eamEnumRepoitory.findByHqlWhere(hqlInfo);
        } else {
            eamEnums = eamEnums.stream().
                    filter(k -> k.getEnumType().equals(model.getEnumType())).collect(Collectors.toList());
        }

        if (CollectionUtils.isEmpty(eamEnums)) {
            return result;
        }
        for (DynamicEnum eam : eamEnums) {
            Map<String, Object> value = new HashMap<>();
            value.put("value", eam.getEnumValue());
            value.put("description", eam.getEnumValueDesc());
            result.add(value);
        }
        return result;
    }
}
