package cn.estsh.i3plus.pojo.eam.common;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.util.StringUtils;

import javax.persistence.AttributeConverter;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * @author Jason
 * @ClassName: HashMapConverter
 * @Description: json转换器
 * @date 2022-03-23
 */
public class HashMapConverter implements AttributeConverter<Map<String, Object>, String> {
    protected static final Logger LOG = LoggerFactory.getLogger(HashMapConverter.class);
    private static ObjectMapper mapperInstance = null;
    private static ObjectMapper getMapper() {
        if (mapperInstance == null) {
            synchronized (HashMapConverter.class) {
                if (mapperInstance == null) {
                    mapperInstance = new ObjectMapper();
                    mapperInstance.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
                    mapperInstance.configure(SerializationFeature.FAIL_ON_EMPTY_BEANS, false);
                }
            }
        }

        return mapperInstance;
    }

    @Override
    public String convertToDatabaseColumn(Map<String, Object> stringObjectMap) {
        String customerInfoJson = null;
        try {
            customerInfoJson = getMapper().writeValueAsString(stringObjectMap);
        } catch (final JsonProcessingException e) {
            LOG.error("JSON writing error", e);
        }

        return customerInfoJson;
    }

    @Override
    public Map<String, Object> convertToEntityAttribute(String s) {
        if (StringUtils.isEmpty(s)) {
            return new HashMap<>();
        }
        Map<String, Object> customerInfo = null;
        try {
            customerInfo = getMapper().readValue(s, Map.class);
        } catch (final IOException e) {
            LOG.error("JSON reading error", e);
        }

        return customerInfo;
    }
}
