package cn.estsh.i3plus.pojo.eam.common;

import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.jpa.dao.BaseRepository;
import cn.estsh.i3plus.pojo.eam.common.dto.CommonPager;
import cn.estsh.i3plus.pojo.eam.common.pojo.FieldInfo;
import cn.estsh.i3plus.pojo.platform.bean.SysFile;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;
import java.util.Map;

/**
 * @author Jason
 * @ClassName: CommonService
 * @Description: 通用Service接口
 * @date 2022-03-22
 */
public interface ICommonService<T extends CommonBean> {
    BaseRepository<T, Long> getRepository();

    T create();

    List<T> list();

    T getById(long id);

    @ApiParam("通用查询数据带分页")
    ListPager<T> listByPager(List<CommonPager.Filter> filters, List<CommonPager.SortData> sorts, Pager pagers, String org);

    @ApiParam("通用查询数据不带分页")
    List<T> listQuery(List<CommonPager.Filter> filters, List<CommonPager.SortData> sorts, String org);

    T insert(T item);

    T getInsertValue(T item);

    List<T> insert(Iterable<T> items);

    void update(T item);

    void update(Iterable<T> items);

    void delete(T item);

    void delete(Iterable<T> items);

    void deleteById(Long id);

    int deleteByIds(Long[] ids);

    String getStringValue(CommonBean bean, FieldInfo info);

    String getMainKeyValue(CommonBean bean);

    T getByMainKey(List<FieldInfo> fieldInfos, List<String> values);

    Object getValue(CommonBean bean, FieldInfo info);

    void setValue(CommonBean bean, FieldInfo info, Object value);

    void setStringValue(CommonBean bean, FieldInfo info, String value);

    void uploadFile(MultipartFile file, Long beanId, Long configId, String userName);

    SysFile downloadFile(Long beanId, Long configId);

    void deleteFile(Long beanId, Long configId);


    @ApiOperation(value = "上传图片")
    Map<Long, String> fileJpg(MultipartFile file, Long id, String userName);

    @ApiOperation(value = "上传文档")
    Map<Long, String> filePdf(MultipartFile file, Long id, String userName);

    T getByMainKeyOrganizeCode(List<FieldInfo> fieldInfos, List<String> values, String organizeCode);
}
