package cn.estsh.i3plus.pojo.eam.common.pojo;


import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.eam.common.COMMON_EDIT_TYPE;
import cn.estsh.i3plus.pojo.eam.common.COMMON_FIELD_TYPE;
import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.Transient;
import java.lang.reflect.Method;
import java.sql.JDBCType;
import java.util.List;
import java.util.Map;

/**
 * @author Jason
 * @ClassName: FieldInfo
 * @Description: 字段信息
 * @date 2022-03-22
 */
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name = "COMMON_FIELD_INFO")
@Api("字段信息")
public class FieldInfo extends CommonBean {
    @Column(name = "CODE")
    @ApiParam(value = "编码")
    @FieldAnnotation(popSearch = true, mainkey = true)
    private String code;

    @Column(name = "NAME")
    @ApiParam(value = "名称")
    @FieldAnnotation(popSearch = true, mainkey = true)
    private String name;

    @Column(name = "CLASS_NAME")
    @ApiParam(value = "所属类简称")
    private String className;

    @Column(name = "TYPE")
    @ApiParam(value = "类型")
    @FieldAnnotation(defaultValue = "STRING")
    private COMMON_FIELD_TYPE type;

    @Column(name = "TYPE_NAME")
    @ApiParam(value = "类型名称")
    private String typeName;

    @Column(name = "TYPE_FULL_NAME")
    @ApiParam(value = "类型全名称包含路径")
    private String typeFullName;

    @Column(name = "CUSTOMIZE")
    @ApiParam(value = "是否为自定义字段")
    @FieldAnnotation(defaultValue = "true")
    private Boolean customize = true;

    @Column(name = "MODIFY")
    @ApiParam(value = "是否能修改")
    @FieldAnnotation(defaultValue = "true")
    private Boolean modify = true;

    @Column(name = "DISPLAY")
    @ApiParam(value = "是否在界面显示")
    @FieldAnnotation(defaultValue = "true")
    private Boolean display = true;

    @Column(name = "IS_SHOW")
    @ApiParam(value = "是否表单字段展示:默认1-显示，2-隐藏")
    private Boolean isShow = true;

    @Column(name = "PRIC")
    @ApiParam(value = "浮点数显示精度")
    @FieldAnnotation(defaultValue = "2")
    private Integer pric;

    @Column(name = "TIPS")
    @ApiParam(value = "字段提示")
    private String tips;

    @Column(name = "ORDER_NUMBER")
    @ApiParam(value = "序号")
    private Integer orderNumber;

    @Column(name = "MAIN_KEY")
    @ApiParam(value = "主键标识")
    private Boolean mainKey;

    @Column(name = "JDBC_TYPE")
    @ApiParam(value = "数据库类型")
    private JDBCType jdbcType;

    @Column(name = "DEFAULT_VALUE")
    @ApiParam(value = "字段默认值")
    private String defaultValue;

    @Column(name = "READ_FUNCTION")
    @ApiParam(value = "取值函数")
    private String readFunction;

    @Column(name = "POP_SEARCH")
    @ApiParam(value = "弹出选择时是否显示")
    private Boolean popSearch;

    @Column(name = "POP_CONDITION")
    @ApiParam(value = "弹出选择时是否使用这个条件查询")
    private Boolean popCondition = false;

    @Column(name = "EDIT_TYPE")
    @ApiParam(value = "字段编辑类型")
    private COMMON_EDIT_TYPE editType;

    @ApiParam(value = "枚举项内容")
    private transient List<Map<String, Object>> enumItems;

    @Column(name = "NOT_EMPTY")
    @ApiParam(value = "不能为空")
    private Boolean notEmpty;

    @Column(name = "DYNAMIC_CALCULATE")
    @ApiParam(value = "是否获取新增值")
    private Boolean dynamicCalculate;

    @Column(name = "IS_WHERE_SELECT")
    @ApiParam(value = "是否为查询条件")
    private Boolean isWhereSelect;

    @Column(name = "IS_UPDATE")
    @ApiParam(value = "是否能在编辑页面输入值:默认1-不可编辑，2-可编辑")
    private Boolean isUpdate = false;

    @Column(name = "EXCEL_EXPORT_VAL")
    @ApiParam(value = "导出取值函数")
    private String excelExportVal;

    @JsonIgnore
    @Transient
    private transient Class<? extends BaseBean> clazz;
    @JsonIgnore
    @Transient
    private transient Class<?> typeClass;
    @JsonIgnore
    @Transient
    private transient Method getMethod;
    @JsonIgnore
    @Transient
    private transient Method setMethod;
}

