package cn.estsh.i3plus.pojo.eam.common.serviceimpl;


import cn.estsh.i3plus.platform.common.convert.ConvertBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.codemaker.SnowflakeIdMaker;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.FieldInfoDao;
import cn.estsh.i3plus.pojo.eam.common.IGridFieldService;
import cn.estsh.i3plus.pojo.eam.common.ServiceInfo;
import cn.estsh.i3plus.pojo.eam.common.dto.GridFieldDto;
import cn.estsh.i3plus.pojo.eam.common.pojo.FieldInfo;
import cn.estsh.i3plus.pojo.eam.common.pojo.GridField;
import cn.estsh.i3plus.pojo.eam.repository.GridFieldRepository;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class GridFieldServiceImpl implements IGridFieldService {
    @Autowired
    private SnowflakeIdMaker snowflakeIdMaker;
    @Autowired
    private GridFieldRepository gridFieldRepository;
    @Autowired
    private FieldInfoDao fieldInfoDao;

    private <T extends CommonBean> T create(Class<T> cls) {
        T bean = null;
        try {
            bean = cls.newInstance();
            bean.setId(snowflakeIdMaker.nextId());
            bean.setIsValid(CommonEnumUtil.VALID);
            bean.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
            bean.setOrganizeCode(ServiceInfo.getOrganizeCode());
        } catch (InstantiationException | IllegalAccessException e) {
        }
        return bean;
    }

    private GridFieldDto createFieldDto(FieldInfo fieldInfo, String gridName, GridField gridField) {
        GridFieldDto dto = new GridFieldDto();
        BeanUtils.copyProperties(fieldInfo, dto);
        dto.setGridName(gridName);
        if (gridField != null) {
            dto.setName(gridField.getName());
            dto.setDisplay(gridField.getDisplay());
            dto.setIsShow(gridField.getIsShow());
            dto.setIsUpdate(gridField.getIsUpdate());
            dto.setNotEmpty(gridField.getNotEmpty());
            dto.setOrderNumber(gridField.getOrderNumber());
        }
        return dto;
    }

    @Override
    public List<GridFieldDto> list(Class<? extends CommonBean> cls, String gridName) {
        List<GridFieldDto> result = new ArrayList<>();

        DdlPackBean hqlInfo = DdlPackBean.getDdlPackBean(ServiceInfo.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(cls.getSimpleName(), "className", hqlInfo);
        if (!StringUtils.isEmpty(gridName)) {
            DdlPreparedPack.getStringEqualPack(gridName, "gridName", hqlInfo);
        } else {
            DdlPreparedPack.getIsNull("gridName", hqlInfo);
        }

        List<GridField> gridFields = gridFieldRepository.findByHqlWhere(hqlInfo);
        List<FieldInfo> fieldInfos = fieldInfoDao.list(cls);
        List<GridField> deleteGridFields = new ArrayList<>();
        for (GridField gridField : gridFields) {
            boolean bFind = fieldInfos.removeIf(temp -> {
                if (temp.getCode().equals(gridField.getCode())) {
                    result.add(createFieldDto(temp, gridName, gridField));
                    return true;
                }
                return false;
            });
            if (!bFind) {
                deleteGridFields.add(gridField);
            }
        }
        for (FieldInfo fieldInfo : fieldInfos) {
            result.add(createFieldDto(fieldInfo, gridName, null));
        }
        gridFieldRepository.deleteAll(deleteGridFields);
        return result;
    }

    @Override
    public void insert(List<GridFieldDto> fieldInfos) {
        for (GridFieldDto dto : fieldInfos) {
            Class<? extends CommonBean> cls = ServiceInfo.getBeanClass(dto.getClassName());
            FieldInfo fieldInfo = fieldInfoDao.get(cls, dto.getCode());
            if (fieldInfo == null) {
                fieldInfo = create(FieldInfo.class);
                fieldInfo.setCode(dto.getCode());
                fieldInfo.setName(dto.getName());
                fieldInfo.setType(dto.getType());
                fieldInfo.setEditType(dto.getEditType());
                fieldInfo.setTypeName(dto.getTypeName());
                fieldInfo.setTypeFullName(dto.getTypeFullName());
                fieldInfo.setClassName(cls.getSimpleName());
                fieldInfo.setModify(dto.getModify());
                fieldInfo.setNotEmpty(dto.getNotEmpty());
                fieldInfo.setDynamicCalculate(dto.getDynamicCalculate());
                fieldInfo.setDisplay(dto.getDisplay());
                fieldInfo.setIsShow(dto.getIsShow());
                fieldInfo.setPric(dto.getPric());
                fieldInfo.setDefaultValue(dto.getDefaultValue());
                fieldInfo.setReadFunction(dto.getReadFunction());
                fieldInfo.setExcelExportVal(dto.getExcelExportVal());
                fieldInfo.setOrganizeCode(dto.getOrganizeCode());
                fieldInfo.setIsWhereSelect(dto.getIsWhereSelect());
                fieldInfo.setIsUpdate(dto.getIsUpdate());
                ConvertBean.serviceModelInitialize(fieldInfo, dto.getCreateUser());
                fieldInfoDao.insert(fieldInfo);
            }
            GridField gridField = create(GridField.class);
            gridField.setCode(dto.getCode());
            gridField.setName(dto.getName());
            gridField.setClassName(cls.getSimpleName());
            gridField.setDisplay(dto.getDisplay());
            gridField.setIsShow(dto.getIsShow());
            gridField.setIsUpdate(dto.getIsUpdate());
            gridField.setNotEmpty(dto.getNotEmpty());
            gridField.setGridName(dto.getGridName());
            gridField.setOrganizeCode(dto.getOrganizeCode());
            ConvertBean.serviceModelInitialize(gridField, dto.getCreateUser());
            gridFieldRepository.save(gridField);
        }
    }

    @Override
    public void update(List<GridFieldDto> fieldInfos) {
        for (GridFieldDto dto : fieldInfos) {
            Class<? extends CommonBean> cls = ServiceInfo.getBeanClass(dto.getClassName());
            FieldInfo fieldInfo = fieldInfoDao.get(cls, dto.getCode());
            if (fieldInfo != null) {
                fieldInfo.setType(dto.getType());
                fieldInfo.setEditType(dto.getEditType());
                fieldInfo.setTypeName(dto.getTypeName());
                fieldInfo.setTypeFullName(dto.getTypeFullName());
                fieldInfo.setOrganizeCode(dto.getOrganizeCode());
                fieldInfo.setIsWhereSelect(dto.getIsWhereSelect());
                fieldInfo.setIsUpdate(dto.getIsUpdate());
                ConvertBean.serviceModelUpdate(fieldInfo, dto.getCreateUser());
                fieldInfoDao.update(fieldInfo);
            }

            GridField gridField = getByName(cls, dto.getGridName(), dto.getCode());
            if (gridField != null) {
                gridField.setDisplay(dto.getDisplay());
                gridField.setIsShow(dto.getIsShow());
                gridField.setIsUpdate(dto.getIsUpdate());
                gridField.setNotEmpty(dto.getNotEmpty());
                gridField.setName(dto.getName());
                gridField.setOrderNumber(dto.getOrderNumber());
                gridField.setOrganizeCode(dto.getOrganizeCode());
                ConvertBean.serviceModelUpdate(gridField, dto.getCreateUser());
                gridFieldRepository.save(gridField);
            }
        }
    }

    @Override
    public GridField getByName(Class<? extends CommonBean> cls, String gridName, String name) {
        DdlPackBean hqlInfo = DdlPackBean.getDdlPackBean(ServiceInfo.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(cls.getSimpleName(), "className", hqlInfo);
        if (!StringUtils.isEmpty(gridName)) {
            DdlPreparedPack.getStringEqualPack(gridName, "gridName", hqlInfo);
        }
        DdlPreparedPack.getStringEqualPack(name, "code", hqlInfo);
        return gridFieldRepository.getByProperty(hqlInfo);
    }
}
