package cn.estsh.i3plus.pojo.eam.pojo;

import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.ExcludeImportExport;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;
import cn.estsh.i3plus.pojo.eam.common.COMMON_EDIT_TYPE;
import javax.persistence.*;

/**
 * @Description : 区域类别关系
 * @Reference :
 * @Author : jimmy.zeng
 * @CreateDate : 2022-05-09 17:15
 * @Modify:
 **/
@Data
@Entity
@Table(name = "EAM_AREA_PART_GROUP", uniqueConstraints = {
        @UniqueConstraint(columnNames = {"AREA_PART_GROUP_CODE", "AREA", "PART_GROUP"})})
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Api(value = "区别类别关系", description = "区别类别关系")
@ExcludeImportExport
public class EamAreaPartGroup extends CommonBean {

    @Column(name = "AREA_PART_GROUP_CODE")
    @ApiParam(name = "区域类别编码")
    @FieldAnnotation(popSearch = true)
    private String areaPartGroupCode;

    @Column(name = "AREA")
    @ApiParam(name = "区域")
    @FieldAnnotation(typeName = "EAM_AREA", mainkey = true, popSearch = true)
    private String area;

    @Transient
    @ApiParam(name = "原区域代码")
    @FieldAnnotation(readFunction = "getOriginalArea")
    private String originalArea;

    @Column(name = "AREA_DESC")
    @ApiParam(name = "区域描述")
    @FieldAnnotation(modify = false, display = false, popSearch = true)
    private String areaDesc;

    @Column(name = "PART_GROUP")
    @ApiParam(name = "类别")
    @FieldAnnotation(typeName = "EAM_PART_GROUP", mainkey = true, popSearch = true)
    private String partGroup;

    @Transient
    @ApiParam(name = "原类别代码")
    @FieldAnnotation(readFunction = "getOriginalPartGroup")
    private String originalPartGroup;

    @Column(name = "PART_GROUP_DESC")
    @ApiParam(name = "类别描述")
    @FieldAnnotation(modify = false, display = false, popSearch = true)
    private String partGroupDesc;

    @Transient
    @ApiParam(name = "区域集合")
    @FieldAnnotation(display = false)
    private String areaStr;

    @Column(name = "PART_GROUP_COLOR")
    @ApiParam(name = "颜色")
    @FieldAnnotation(editType = COMMON_EDIT_TYPE.COLOR_PICKER)
    private String partGroupColor;

    @Column(name = "PART_GROUP_COLOR_RGB")
    @ApiParam(name = "颜色RGB")
    private String partGroupColorRgb;

    public static Object funOriginalArea(Object[] bean) {
        if (bean.length <= 0 || bean == null) {
            return null;
        }
        return JSON.parseObject(JSON.toJSONString(bean[0]), EamAreaPartGroup.class).getArea();

    }

    public static Object funOriginalPartGroup(Object[] bean) {
        if (bean.length <= 0 || bean == null) {
            return null;
        }
        return JSON.parseObject(JSON.toJSONString(bean[0]), EamAreaPartGroup.class).getPartGroup();

    }
}
