package cn.estsh.i3plus.pojo.eam.pojo;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.ExcludeImportExport;
import cn.estsh.i3plus.pojo.eam.util.EamEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;
import org.springframework.util.StringUtils;

import javax.persistence.*;
import java.util.List;

/**
 * @Description : 备品备件盘点明细表
 * @Reference :
 * @Author : jimmy.zeng
 * @CreateDate : 2022-05-11 17:56
 * @Modify:
 **/
@Data
@Entity
@Table(name = "EAM_DOC_CS_DETAILS")
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Api(value = "备品备件盘点明细表", description = "备品备件盘点明细表")
@ExcludeImportExport
public class EamDocCsDetails  extends CommonBean {

    @Column(name = "ORDER_NO")
        @ApiParam(name = "单据号",value = "盘点单")
    private String orderNo;

    @Column(name = "AREA")
    @ApiParam(name = "区域",value = "区域")
    private String area;

    @Column(name = "PART_GROUP")
    @ApiParam(name = "类别",value = "类别")
    private String partGroup;

    @Column(name = "PART_NO")
    @ApiParam(name = "备品备件管理编码",value = "备品备件管理编码")
    private String partNo;

    @Column(name = "PART_NAME")
    @ApiParam(name = "备品备件名称",value  = "备品备件名称")
    private String partName;

    @Column(name = "IS_URGENT")
    @ApiParam(name = "是否紧急",value = "是否紧急")
    @AnnoOutputColumn(refClass =  CommonEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer isUrgent;

    @Column(name = "ITEM_STATUS")
    @ApiParam(name = "单据状态",value = "单据状态")
    @AnnoOutputColumn(refClass = EamEnumUtil.ORDER_DOC_STATUS.class, refForeignKey = "value", value = "description")
    private String itemStatus;

    @Column(name = "PART_QTY")
    @ApiParam(name = "在库数量",value = "在库数量")
    private Double partQty;

    @Column(name = "FACT_QTY")
    @ApiParam(name = "实盘数量",value = "实盘数量")
    private Double factQty;

    /**
     * 相当于库位
     */
    @Column(name = "FACT_KEEPING_AREA")
    @ApiParam(name = "实际保管场所",value = "保管场所")
    private String factKeepingArea;

    @Column(name = "REMARK")
    @ApiParam(name = "备注",value = "备注")
    private String remark;

    @Transient
    @ApiParam(value = "差异数量")
    private Double diffQty;

    @Transient
    @ApiParam(value = "区域类别集合")
    public List<EamAreaPartGroup> eamAreaPartGroupList;

    @Transient
    @ApiParam(value = "备品备件集合")
    private List<EamStock> eamStockList;

    @Transient
    @ApiParam(value = "区域str")
    private String areaStr;

    @Transient
    @ApiParam(value = "类别Str")
    private String partGroupStr;

    @Transient
    @ApiParam(value = "备品备件管理编码Str")
    private String partNoStr;

    @Transient
    @ApiParam(value = "单据状态")
    private String orderStatus;

    @Transient
    @ApiParam(value = "单据状态")
    private String orderStatusVal;

    public EamDocCsDetails() {
    }

    public EamDocCsDetails(Long id, String orderNo, String orderStatus, String createUser, String modifyUser,
                           String createDatetime, String modifyDatetime) {
        this.id = id;
        this.orderNo = orderNo;
        this.orderStatus = orderStatus;
        this.createUser = createUser;
        this.modifyUser = modifyUser;
        this.createDatetime = createDatetime;
        this.modifyDatetime = modifyDatetime;
    }

    public String getOrderStatusVal() {
        if (StringUtils.isEmpty(this.orderStatus)) {
            return null;
        }
        return EamEnumUtil.ORDER_DOC_CS_STATUS.valueOfDescription(this.orderStatus);
    }
}
