package cn.estsh.i3plus.pojo.eam.pojo;

import cn.estsh.i3plus.pojo.eam.common.COMMON_EDIT_TYPE;
import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.ExcludeImportExport;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.eam.common.validator.InsertGroup;
import cn.estsh.i3plus.pojo.eam.util.EamEnumUtil;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiParam;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;

import javax.persistence.*;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.PositiveOrZero;

/**
 * @author ns
 * @create 2022/4/12 0012 下午 17:19
 * 计划规则表
 */
@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
@Entity
@Table(name = "EAM_PLAN_RULE", indexes = {
        @Index(columnList = "EQU_CODE")
})
@ApiModel("EamPlanRule实体类")
@ExcludeImportExport
public class EamPlanRule extends CommonBean {

    @ApiParam(name = "业务类型")
    @Column(name = "BUSI_TYPE")
    @NotNull(groups = InsertGroup.class)
    @Enumerated(EnumType.ORDINAL)
    @FieldAnnotation( modify = false, defaultValue ="CHECK")
    private EamEnumUtil.EAM_DOC_BUSI_TYPE busiType = EamEnumUtil.EAM_DOC_BUSI_TYPE.CHECK;

    @ApiParam(name = "设备编码")
    @Column(name = "EQU_CODE")
    @NotBlank(groups = InsertGroup.class)
    @FieldAnnotation(mainkey = true, popSearch = true, typeName = "Equipment", editType = COMMON_EDIT_TYPE.OBJECT)
    private String equCode;

    @ApiParam(name = "设备名称")
    @Column(name = "EQU_NAME")
    private String equName;

    @ApiParam(name = "设备等级")
    @Column(name = "EQU_LEVEL")
    @FieldAnnotation(typeName = "EAM_EQU_LEVEL")
    private String equLevel;

    @ApiParam(name = "频次")
    @Column(name = "FREQUENCY")
    @FieldAnnotation(typeName = "FREQUENCY", notEmpty = true)
    private String frequency;

    @ApiParam(name = "频次单位")
    @Column(name = "UNIT")
    private String unit;

    @ApiParam(name = "提前创建天数,默认 0")
    @Column(name = "ADV_DAYS")
    @PositiveOrZero
    private Integer advDays;

    @Lob
    @ApiParam(name = "备注")
    @Column(name = "REMARK")
    private String remark;

    @ApiParam(name = "生产线编码")
    @Column(name = "WORKCENTER")
    @FieldAnnotation(typeName = "EAM_WORKCENTER")
    private String workcenter;

    @ApiParam(name = "上次生成的单号")
    @Column(name = "LAST_ORDER_NO")
    private String lastOrderNo;

    @ApiParam(name = "上次生成的单号的时间")
    @Column(name = "LAST_GENERATE_DATA_TIME")
    private String lastGenerateDataTime;

    @ApiParam(name = "下次生成的单号的时间")
    @Column(name = "NEXT_GENERATE_DATA_TIME")
    @FieldAnnotation(editType = COMMON_EDIT_TYPE.DATE_TIME)
    private String nextGenerateDataTime;

    @ApiParam(name = "根据corn表达式生成的下次执行时间")
    @Column(name = "NEXT_CRON_DATA_TIME")
    @FieldAnnotation(editType = COMMON_EDIT_TYPE.DATE_TIME)
    private String nextCronDataTime;
}
