package cn.estsh.i3plus.pojo.eam.pojo;


import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.ExcludeImportExport;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.eam.util.EamEnumUtil;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 备品备件库存表
 * @Reference :
 * @Author : jimmy.zeng
 * @CreateDate : 2022-05-09 14:29
 * @Modify:
 **/
@Data
@Entity
@Table(name = "EAM_STOCK")
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Api("备品备件库存表")
@ExcludeImportExport
public class EamStock extends CommonBean {

    @Column(name = "AREA")
    @ApiParam(name = "区域")
    @FieldAnnotation(typeName = "EAM_AREA", mainkey = true)
    private String area;

    @Column(name = "PART_GROUP")
    @ApiParam(name = "物料组")
    @FieldAnnotation(typeName = "EAM_PART_GROUP", mainkey = true)
    private String partGroup;

    @Column(name = "PART_NO")
    @ApiParam(name = "备品备件管理编码")
    @FieldAnnotation(mainkey = true)
    private String partNo;

    @Column(name = "PART_NAME")
    @ApiParam(name = "备品备件名称")
    private String partName;

    @Column(name = "PART_QTY")
    @ApiParam(name = "在库数量")
    private Double partQty;

    @Column(name = "IS_FREEZE")
    @AnnoOutputColumn(refClass = EamEnumUtil.STOCK_STATUS.class, refForeignKey = "value", value = "description")
    @ApiParam(name = "是否冻结")
    @FieldAnnotation(excelExportVal = "getEamStockIsFreeze")
    private EamEnumUtil.STOCK_STATUS isFreeze;

    @Transient
    @ApiParam(name = "最大库存")
    private Double max;

    @Transient
    @ApiParam(name = "最小库存")
    private Double min;

    @Transient
    @ApiParam(name = "类别集合")
    private String partGroupStr;

    @Transient
    @ApiParam(name = "区域集合")
    private String areaStr;

    @Transient
    @ApiParam(name = "保管场所")
    private String keepingArea;

    @Transient
    @ApiParam(name = "类别描述")
    private String partGroupDesc;

    @Transient
    @ApiParam(name = "区域描述")
    private String areaDesc;

    public EamStock() {
    }

    public EamStock(String area, String areaDesc, String partGroup, String partGroupDesc, String partNo, String partName,
                    Double partQty, Double max, Double min,
                    String createUser, String modifyUser, String createDatetime, String modifyDatetime, String organizeCode) {
        this.area = area;
        this.areaDesc = areaDesc;
        this.partGroup = partGroup;
        this.partGroupDesc = partGroupDesc;
        this.partNo = partNo;
        this.partName = partName;
        this.partQty = partQty;
        this.max = max;
        this.min = min;
        this.createUser = createUser;
        this.modifyUser = modifyUser;
        this.createDatetime = createDatetime;
        this.modifyDatetime = modifyDatetime;
        this.organizeCode = organizeCode;
    }

    public EamStock(String area, String partGroup, String partNo, String partName, Double partQty,
                    Double max, Double min, String keepingArea) {
        this.area = area;
        this.partGroup = partGroup;
        this.partNo = partNo;
        this.partName = partName;
        this.partQty = partQty;
        this.max = max;
        this.min = min;
        this.keepingArea = keepingArea;
    }

    public Double getPartQty() {
        return this.partQty == null ? 0 : this.partQty;
    }

    public static Object funEamStockIsFreeze(Object[] bean) {
        if (bean.length <= 0 || bean == null) {
            return null;
        }
        EamStock stock = JSON.parseObject(JSON.toJSONString(bean[0]), EamStock.class);
        return stock.getIsFreeze().getDescription();

    }
}
