package cn.estsh.i3plus.pojo.eam.pojo;


import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.ExcludeImportExport;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.eam.util.EamEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang3.StringUtils;
import cn.estsh.i3plus.pojo.eam.common.COMMON_EDIT_TYPE;
import javax.persistence.*;

/**
 * @Description:
 * @CreateDate 2022/3/30 13:50
 * @Author 尹肖
 */
@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
@Entity
@Table(name = "EQUIPMENT", uniqueConstraints = {
        @UniqueConstraint(columnNames = {"EQU_CODE"})})
@Api("设备台账")
@ExcludeImportExport
public class Equipment extends CommonBean {

    @Column(name = "EQU_CODE")
    @ApiParam(name = "资产编码")
    @FieldAnnotation(mainkey = true, popSearch = true, popCondition = true)
    private String equCode;

    @Column(name = "EQU_CLASS")
    @ApiParam(name = "设备大类")
    @FieldAnnotation(popSearch = true)
    private String equClass;

    @Column(name = "EQU_NAME")
    @ApiParam(name = "资产名称")
    @FieldAnnotation(popSearch = true)
    private String equName;

    @Column(name = "EQU_FILE_ROUTE")
    @ApiParam(name = "资产参考文档")
    @FieldAnnotation(popSearch = true, modify = false)
    private String equFileRoute;

    @Column(name = "EQU_FILE_ROUTE_ID")
    @ApiParam(name = "资产参考文档id")
    @FieldAnnotation(modify = false, display = false, isShow = false)
    private String equFileRouteId;

    @Column(name = "MAIN_USER")
    @ApiParam(name = "责任人")
    private String mainUser;

    @Column(name = "EQU_TYPE")
    @ApiParam(name = "资产类型")
    @FieldAnnotation(typeName = "EquipmentType", editType = COMMON_EDIT_TYPE.OBJECT, dynamicCalculate = true)
    private String equType;

    @Column(name = "EQU_TYPE_NAME")
    @ApiParam(name = "资产类型名称")
    private String equTypeName;

    @Column(name = "LOCATE")
    @ApiParam(name = "存放地点")
    @FieldAnnotation(typeName = "EAM_LOCATE")
    private String locate;

    @Column(name = "UNIT")
    @ApiParam(name = "寿命单位")
    private String unit;

    @Column(name = "LIFE")
    @ApiParam(name = "寿命")
    private String life;

    @Column(name = "KEEP_DEPARTMENT")
    @ApiParam(name = "保管部门")
    private String keepDepartment;

    @Column(name = "WORKCENTER_CODE")
    @ApiParam(name = "产线编码")
    @FieldAnnotation(typeName = "EAM_WORKCENTER", notEmpty = true)
    private String workcenterCode;

    @Column(name = "EQU_LEVEL")
    @ApiParam(name = "等级")
    @FieldAnnotation(typeName = "EAM_EQU_LEVEL", popSearch = true)
    private String equLevel;

    @Column(name = "EQU_PHOTO")
    @ApiParam(name = "图片")
    @FieldAnnotation(modify = false)
    private String equPhoto;

    @Column(name = "EQU_PHOTO_ID")
    @ApiParam(name = "图片id")
    @FieldAnnotation(modify = false, isShow = false, display = false)
    private String equPhotoId;

    @Column(name = "USED_TIME")
    @ApiParam(name = "已用时间")
    @FieldAnnotation(modify = false)
    private String usedTime;

    @Column(name = "STA")
    @ApiParam(name = "状态")
    @FieldAnnotation(typeName = "EAM_EQU_STATUS")
    private String sta;

    @Column(name = "PRODUCT_VENDOR")
    @ApiParam(name = "厂商")
    private String productVendor;

    @Column(name = "IS_ISPECT_TOOL")
    @ApiParam(name = "是否检查机")
    private Boolean isIspectTool;

    @Column(name = "EQU_STATUS")
    @ApiParam(name = "设备状态")
    private EamEnumUtil.EQU_STATUS equStatus = EamEnumUtil.EQU_STATUS.NORMAL;

    @Transient
    @ApiParam(name = "设备状态")
    @FieldAnnotation(modify = false, isShow = false, display = false)
    private String equStatusVal;

    @Column(name = "WARN")
    @ApiParam(name = "预警数值")
    private Integer warn;

    @Column(name = "LAST_MAINTENANCE_TIME")
    @FieldAnnotation(editType = COMMON_EDIT_TYPE.DATE_TIME)
    @ApiParam(name = "上次保养时间")
    private String lastMaintenanceTime;

    @Column(name = "LIFE_DISTR")
    @ApiParam(name = "寿命分布")
    private EamEnumUtil.LIFE_DISTR lifeDistr;


    @Column(name = "EAM_CAREER")
    @ApiParam(name = "事业别")
    @FieldAnnotation(typeName = "EAM_CAREER")
    private String eamCareer;

    @Column(name = "EQU_NATURE")
    @ApiParam(name = "设备性质")
    @FieldAnnotation(typeName = "EQU_NATURE")
    private String equNature;

    @Column(name = "ENABLE_TIME")
    @ApiParam(name = "启动时间")
    @FieldAnnotation(editType = COMMON_EDIT_TYPE.DATE)
    private String enableTime;

    @Column(name = "EQU_PRICE")
    @ApiParam(name = "资产价值")
    @FieldAnnotation(popSearch = true)
    private String equPrice;

    @Column(name = "PARENT_ID")
    @ApiParam(name = "父id")
    @FieldAnnotation(modify = false, isShow = false, display = false)
    private String parentId;

    @Column(name = "TYPE1")
    @ApiParam(name = "类型1")
    @FieldAnnotation(typeName = "TYPE1",popSearch = true)
    private String type1;

    @Column(name = "TYPE2")
    @ApiParam(name = "类型2")
    @FieldAnnotation(typeName = "TYPE2")
    private String type2;

    @Column(name = "TYPE3")
    @ApiParam(name = "类型3")
    @FieldAnnotation(typeName = "TYPE3")
    private String type3;

    @Column(name = "TYPE4")
    @ApiParam(name = "类型4")
    @FieldAnnotation(typeName = "TYPE4")
    private String type4;

    @Column(name = "TYPE5")
    @ApiParam(name = "类型5")
    @FieldAnnotation(typeName = "TYPE5")
    private String type5;

    @Column(name = "VARIANT")
    @ApiParam(name = "型号")
    private String variant;


    @Column(name = "MAIN_PARAM")
    @ApiParam(name = "主要参数")
    private String mainParam;

    @Column(name = "USR_YEAR")
    @ApiParam(name = "使用年限")
    private String usrYear;

    @Column(name = "USR_COUNT")
    @ApiParam(name = "使用次数")
    private Integer usrCount;

    @Column(name = "PURCHASE_DATA")
    @ApiParam(name = "采购时间")
    private String purchaseData;

    public String getEquStatusVal() {
        if (this.equStatus == null) return equStatusVal;
        this.equStatusVal = this.equStatus.getValue();
        return this.equStatusVal;
    }

    public void setEquStatusVal(String equStatusVal) {
        if (!StringUtils.isEmpty(equStatusVal)) {
            this.equStatus = EamEnumUtil.EQU_STATUS.valueOf(equStatusVal);
        }
        this.equStatusVal = equStatusVal;
    }
}
