package cn.estsh.i3plus.pojo.eam.pojo.importexport;

import cn.estsh.i3plus.pojo.eam.common.CommonBean;
import cn.estsh.i3plus.pojo.eam.common.annotation.FieldAnnotation;
import cn.estsh.i3plus.pojo.eam.util.EamEnumUtil;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.ApiParam;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.Setter;

import javax.persistence.*;
import java.util.List;

/**
 * @author Jason
 * @ClassName: ImportTable
 * @Description: 通用导入表
 * @date 2022-04-14
 */
@Getter
@Setter
@EqualsAndHashCode(callSuper = true)
@Entity
@Table(name = "COMMON_IMPORT_TABLE")
public class ImportTable extends CommonBean {

    @Column(name="IN_NAME")
    @ApiParam(name ="内部表名")
    @FieldAnnotation(notEmpty = true)
    private EamEnumUtil.IMPORT_TABLE_NAME inName;

    @Column(name="OUT_NAME")
    @ApiParam(name ="外部表名")
    @FieldAnnotation(notEmpty = true)
    private String outName;

    @Column(name="SKIP_ROWS")
    @ApiParam(name ="跳过行数")
    @FieldAnnotation(defaultValue = "0")
    private Integer skipRows;

    @Column(name="ORDER_NUMBER")
    @ApiParam(name ="序号")
    private Integer orderNumber;

    @Column(name="REPEAT_IGNORE")
    @ApiParam(name ="重复忽略")
    private Boolean repeatIgnore;

    @Lob
    @Column(name="INNER_FILTER")
    @ApiParam(name ="内部对象筛选")
    private String innerFilter;

    @Lob
    @Column(name="OUTTER_FILTER")
    @ApiParam(name ="外部对象筛选")
    private String outterFilter;

    @Column(name="POST_HANDLE")
    @ApiParam(name ="后处理")
    private String postHandle;

    @Column(name="UPDATE_SQL")
    @ApiParam(name ="更新外部数据")
    private String updateSQL;

    @ManyToOne
    @JoinColumn(name = "importProject")
    @FieldAnnotation(display = false, isShow = false)
    private ImportProject importProject;

    @JsonIgnore
    @OneToMany(targetEntity = ImportField.class, mappedBy = "importTable", orphanRemoval = true, fetch=FetchType.EAGER)
    @FieldAnnotation(display = false, isShow = false)
    private List<ImportField> importFields;
}
