package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 四时会议
 * @Reference :
 * @Author : songlian.shi
 * @CreateDate : 2022-06-29 14:57
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_ABNORMAL_FOUR_HOUR_MEET",indexes = {@Index(columnList = "ORDER_NO,PART_NO,MACHINE_CODE")})
@Api("四时会议")
public class SxQmsAbnormalFourHourMeet extends BaseBean {

    //master

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    @Column(name = "APPLY_DATE_TIME")
    @ApiParam("发生日(问题提出日期)")
    private String applyDatetime;

    @Column(name = "DEFECT_LEVEL")
    @ApiParam("缺陷等级")
    @AnnoOutputColumn(refClass = QmsEnumUtil.DEFECT_LEVEL.class, refForeignKey = "value", value = "description")
    private Integer defectLevel;

    //confirm

    @Column(name = "IS_PREVENT_OCCUR")
    @ApiParam("是否再发防止")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer isPreventOccur;

    //master

    @Column(name = "MACHINE_CODE")
    @ApiParam("机型(机种编码)")
    private String machineCode;

    @Column(name = "PART_NO")
    @ApiParam("番号(物料编码)")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("部品名(物料名称)")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNameRdd;

    //detail

    @Column(name = "BAD_CONTENT")
    @ApiParam("异常内容(不良内容)")
    private String badContent;

    @Column(name = "DATE_CODE")
    @ApiParam("不良批次(部品生产日期)")
    private String dateCode;

    @Column(name = "DUTY_DIFF_NAME")
    @ApiParam("责任部门")
    private String dutyDiffName;

    @Column(name = "OCCURE_COUNT")
    @ApiParam("不良数(发生数/检查数)")
    private Integer occureCount;

    @Column(name = "RECHECK_PLACE")
    @ApiParam("检查数")
    private Integer recheckPlace;

    //fourHourMeet

    @Column(name = "BAD_NATURE")
    @ApiParam("不良性质")
    private String badNature;

    @Column(name = "IMPERMANENT_POLICY")
    @ApiParam("临时对策")
    private String impermanentPolicy;

    @Column(name = "IS_RELEASE_QUALITY",columnDefinition = "int default 1")
    @ApiParam("是否发行异常联络")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer isReleaseQuality;

    //master

    @Column(name = "ABNORMAL_CREATE_DATE")
    @ApiParam("异常发出日(创建日期)")
    public String abnormalCreateDate;

    @Column(name = "REPLY_END_DATE")
    @ApiParam("对策要求回复日(回复期限日期)")
    private String replyEndDate;

    //fourHourMeet

    @Column(name = "ACTUAL_REPLY_DATE")
    @ApiParam("实际回复日")
    private String actualReplyDate;

    //reply

    @Column(name="OCCURE_OUT_FLOW_REASON")
    @ApiParam("原因(发生原因+流出原因,之间;隔开)")
    public String occureOutFlowReason;

    @Column(name="TEMP_DEAL_PREVENT_OPTION")
    @ApiParam("对策(临时应急对策+再发防止对策,之间;隔开)")
    public String tempDealPreventOption;

    //fourHourMeet

    @Column(name = "END_DATE")
    @ApiParam("完结日")
    private String endDate;

    @Column(name = "PROGRESS_TRACK")
    @ApiParam("进度跟踪")
    private String progressTrack;

    @Column(name = "EFFECT_TRACK")
    @ApiParam("对策后效果跟踪")
    private String effectTrack;

    @Column(name = "MEET_PERSONNEL")
    @ApiParam("与会部门/人员")
    private String meetPersonnel;

    @Column(name = "CAUSE_ANALYSIS")
    @ApiParam("原因分析")
    private String causeAnalysis;
}
