package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.util.List;

/**
 * @Description : 异常联络单
 * @Reference :
 * @Author : puxiao
 * @CreateDate : 2022-02-19 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_ABNORMAL_MASTER",indexes = {@Index(columnList = "ORDER_NO,PART_NO")})
@Api("异常联络单")
public class SxQmsAbnormalMaster extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    @Column(name = "BUSI_TYPE")
    @ApiParam("异常场所")
    @AnnoOutputColumn(refClass = QmsEnumUtil.ABNORMAL_SOURCE.class, refForeignKey = "value", value = "description")
    public Integer busiType;


    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNameRdd;

    @Column(name = "MACHINE_CODE")
    @ApiParam("机种编码")
    private String machineCode;

    /**
     * yyyy-MM-dd 格式
     */
    @Column(name = "APPLY_DATE_TIME")
    @ApiParam("问题提出日期")
    private String applyDatetime;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "DEFECT_LEVEL")
    @ApiParam("缺陷等级")
    @AnnoOutputColumn(refClass = QmsEnumUtil.DEFECT_LEVEL.class, refForeignKey = "value", value = "description")
    private Integer defectLevel;

    @Column(name = "ORDER_STATUS")
    @ApiParam("状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.ABNORMAL_ORDER_STATUS.class, refForeignKey = "value", value = "description")
    private Integer orderStatus;

    @Column(name = "SAFETY_MGR_TYPE")
    @ApiParam("安全管理责任")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SAFETY_MGR_TYPE.class, refForeignKey = "value", value = "description")
    private Integer safetyMgrType;

    @Column(name = "SAFETY_JUDGE_TYPE")
    @ApiParam("安全判定要求")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SAFETY_JUDGE_TYPE.class, refForeignKey = "value", value = "description")
    private Integer safetyJudgeType;

    /**
     * yyyy-MM-dd 格式
     */
    @Column(name = "REPLY_END_DATE")
    @ApiParam("回复期限日期")
    private String replyEndDate;


    @Column(name = "REPLY_OVER_TIME",columnDefinition = "int default 2")
    @ApiParam("是否超时回复")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer replyOverTime;


    @Column(name = "REF_ORDER_NO")
    @ApiParam("关联单号")
    private String refOrderNo;

    /**
     * 责任区分
     */
    @Column(name = "DUTY_DIFF")
    @ApiParam("责任区分")
    @AnnoOutputColumn(refClass = QmsEnumUtil.DUTY_DIFF.class, refForeignKey = "value", value = "description")
    private Integer dutyDiff;

    @Column(name = "MANAGEMENT_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("物管确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer managementConfirm;

    @Column(name = "MANAGEMENT_CONFIRM_STATUS")
    @ApiParam("物管确认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer managementConfirmStatus;

    @Column(name = "MANAGEMENT_CONFIRM_DATE_TIME")
    @ApiParam("物管确认时间")
    private String managementConfirmDateTime;

    @Column(name = "MATERIL_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("资材确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer materialConfirm;

    @Column(name = "MATERIL_CONFIRM_STATUS")
    @ApiParam("资材确认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer materialConfirmStatus;

    @Column(name = "MATERIL_CONFIRM_DATE_TIME")
    @ApiParam("资材确认时间")
    private String materialConfirmDateTime;


    @Column(name = "RECEIVE_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("发行")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer receiveConfirm;

    @Column(name = "RECEIVE_CONFIRM_STATUS")
    @ApiParam("发行结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer receiveConfirmStatus;

    @Column(name = "RECEIVE_CONFIRM_DATE_TIME")
    @ApiParam("发行时间")
    private String receiveConfirmDateTime;


    @Column(name = "REGULATE_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("调达确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer regulateConfirm;

    @Column(name = "REGULATE_CONFIRM_STATUS")
    @ApiParam("调达确认状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer regulateConfirmStatus;

    @Column(name = "REGULATE_CONFIRM_DATE_TIME")
    @ApiParam("调达确认时间")
    private String regulateConfirmDateTime;


    @Column(name = "CONTACT_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("联络单确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer contactConfirm;

    @Column(name = "CONTACT_CONFIRM_STATUS")
    @ApiParam("联络单确认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer contactConfirmStatus;

    @Column(name = "CONTACT_CONFIRM_DATE_TIME")
    @ApiParam("联络单确认时间")
    private String contactConfirmDateTime;


    @Column(name = "DEAL_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("联络单回复")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer dealConfirm;

    @Column(name = "DEAL_CONFIRM_STATUS")
    @ApiParam("联络单回复结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer dealConfirmStatus;

    @Column(name = "DEAL_CONFIRM_DATE_TIME")
    @ApiParam("联络单回复时间")
    private String dealConfirmDateTime;

    @Column(name = "ISSUE_DEPARTMENT_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("回复确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer issueDePartmentConfirm;

    @Column(name = "ISSUE_DEPARTMENT_CONFIRM_STATUS")
    @ApiParam("回复确认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer issueDePartmentConfirmStatus;

    @Column(name = "ISSUE_DEPARTMENT_CONFIRM_DATE_TIME")
    @ApiParam("回复确认时间")
    private String issueDePartmentConfirmDateTime;

    @Column(name = "SUPERVISOR_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("课长确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer supervisorConfirm;

    @Column(name = "SUPERVISOR_CONFIRM_STATUS")
    @ApiParam("课长确认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer supervisorConfirmStatus;

    @Column(name = "SUPERVISOR_CONFIRM_DATE_TIME")
    @ApiParam("课长确认时间")
    private String supervisorConfirmDateTime;

    @Column(name = "QUALITY_DIRECTOR_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("品质部长确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer qualityDirectorConfirm;

    @Column(name = "QUALITY_DIRECTOR_CONFIRM_STATUS")
    @ApiParam("品质部长确认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer qualityDirectorConfirmStatus;



    @Column(name = "QUALITY_DIRECTOR_DATE_TIME")
    @ApiParam("品质部长确认时间")
    private String qualityDirectorConfirmDateTime;


    @Column(name = "DIRECTOR_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("部长确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer directorConfirm;

    @Column(name = "DIRECTOR_CONFIRM_STATUS")
    @ApiParam("部长确认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer directorConfirmStatus;


    @Column(name = "DIRECTOR_DATE_TIME")
    @ApiParam("部长确认时间")
    private String directorConfirmDateTime;


    @Column(name = "CHECK_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("检印确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer checkConfirm;

    @Column(name = "CHECK_CONFIRM_STATUS")
    @ApiParam("检印结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer checkConfirmStatus;

    @Column(name = "CHECK_CONFIRM_DATE_TIME")
    @ApiParam("检印时间")
    private String checkConfirmDateTime;

    @Column(name = "RECOGNIZE_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("承认确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer recognizeConfirm;

    @Column(name = "RECOGNIZE_CONFIRM_STATUS")
    @ApiParam("承认结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer recognizeConfirmStatus;

    @Column(name = "RECOGNIZE_CONFIRM_DATE_TIME")
    @ApiParam("承认时间")
    private String recognizeConfirmDateTime;

    @Column(name = "APPLY_DEPARTMENT_CODE")
    @ApiParam("申请部门")
    private String applyDepartmentCode;


    @Column(name = "IS_SEND_EMAIL",columnDefinition = "int default 2")
    @ApiParam("发送邮件")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer isSendEmail;

    /**
     * 取字典信息
     */
    @Column(name = "PRODUCT_TYPE")
    @ApiParam("产品分类")
    @AnnoOutputColumn(refClass = QmsEnumUtil.EP_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer productType;



    @Column(name = "EXTRA_REF_ORDER_NO")
    @ApiParam("次要关联单号")
    private String extraRefOrderNo;


    @Transient
    @ApiParam("开始时间")
    private String createDatetimeStart;

    @Transient
    @ApiParam("结束时间")
    private String createDatetimeEnd;

    @Transient
    @ApiParam("线别")
    private String workCenterCode;


    @Transient
    @ApiParam("部门代码")
    private String departmentcode;


    @Transient
    @ApiParam("异常场所名称")
    private String busiTypeName;


    @Transient
    @ApiParam("缺陷等级名称")
    private String defectLevelName;

    @Transient
    @ApiParam("责任区分名称")
    private String dutyDiffName;

    @Transient
    @ApiParam("不良内容")
    private String badContent;

    @Transient
    @ApiParam("导出模板code")
    private String exportTemplateCode;

    @Transient
    @ApiParam("供应商编码集合")
    private List<String> vendorNoLst;


    private Double rcQty;

    private Double rejectQty;

    private String dateCode;

    private String rcDate;

    private String checkDate;

    @AnnoOutputColumn(refClass = QmsEnumUtil.ABNORMAL_DETAIL_OPTION.class, refForeignKey = "value", value = "description")
    private Integer currentBatchOption;

    public SxQmsAbnormalMaster() {

    }
    public SxQmsAbnormalMaster(String orderNo,
                               Integer productType,
                               String workCenterCode,
                               String vendorNo,
                               String vendorName,
                               String partNo,
                               String partNameRdd,
                               Double rcQty,
                               Double rejectQty,
                               String dateCode,
                               String rcDate,
                               String checkDate,
                               String badContent,
                               Integer currentBatchOption,
                               String createUser) {
        this.orderNo = orderNo;
        this.productType = productType;
        this.workCenterCode =workCenterCode;
        this.vendorNo = vendorNo;
        this.vendorName = vendorName;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.rcQty = rcQty;
        this.rejectQty = rejectQty;
        this.dateCode =dateCode;
        this.rcDate = rcDate;
        this.checkDate =checkDate;
        this.badContent = badContent;
        this.currentBatchOption =currentBatchOption;
        this.createUser = createUser;
    }

    public Integer getManagementConfirm() {
        if(this.managementConfirm==null || this.managementConfirm==0) {
            return null;
        }
        return this.managementConfirm;
    }


}
