package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 异常联络单回复
 * @Reference :
 * @Author : puxiao
 * @CreateDate : 2022-02-19 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_ABNORMAL_REPLY",indexes = {@Index(columnList = "ORDER_NO")})
@Api("异常联络单")
public class SxQmsAbnormalReply extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    @Column(name="OCCURE_CAUSE")
    @ApiParam("发生原因")
    public String occureReason;

    @Column(name="OCCURE_CAUSE_FILE")
    @ApiParam("发生原因附件")
    public String occureReasonFileUrl;

    @Column(name="OUT_FLOW_REASON")
    @ApiParam("流出原因")
    public String outFlowReason;

    @Column(name="OUT_FLOW_REASON_FILE")
    @ApiParam("流出原因附件")
    public String outFlowReasonFileUrl;

    @Column(name="TEMP_DEAL_OPTION")
    @ApiParam("临时应急对策")
    public String tempDealOption;

    @Column(name="TEMP_DEAL_OPTION_FILE")
    @ApiParam("临时应急对策附件")
    public String tempDealOptionFileUrl;

    /**
     * 公司内部、公司外部。
     */
    @Column(name="WORK_SITE")
    @ApiParam("加工场所")
    @AnnoOutputColumn(refClass = QmsEnumUtil.WORK_SITE.class, refForeignKey = "value", value = "description")
    public Integer workSite;

    /**
     * 枚举：作业人员、设备/机器、原材料、作业方法、环境因素、管理上不完善、作业指导文件和管理资料不足、其他。
     */
    @Column(name="CAUSE_ANALYSIS")
    @ApiParam("原因分析")
    @AnnoOutputColumn(refClass = QmsEnumUtil.ABNORMAL_ANALYSIS_CAUSE.class, refForeignKey = "value", value = "description")
    public Integer causeAnalysis;

    @Column(name="OTHER_REASON")
    @ApiParam("其它原因说明")
    public String otherReason;

    @Column(name = "PREVENT_OPTION")
    @ApiParam("再发防止对策")
    private String preventOption;

    @Column(name = "PREVENT_OPTION_FILE")
    @ApiParam("再发防止对策附件")
    private String preventOptionFileUrl;

    @Column(name = "UPLOAD_DATE_TIME")
    @ApiParam("上传时间")
    private String uploadDateTime;

    @Column(name = "FILE_ID")
    @ApiParam("文件ID")
    private Long fileId;

    @Column(name = "FILE_ORIGIN_NAME")
    @ApiParam("文件源名")
    private String fileOriginName;

    @Column(name = "FILE_URL")
    @ApiParam("文件URL")
    private String fileUrl;


    /**
     * 责任区分
     */
    @ApiParam("责任区分")
    @Transient
    private Integer dutyDiff;

    /**
     * yyyy-MM-dd 格式
     */
    @ApiParam("回复期限日期")
    @Transient
    private String replyEndDate;

    @ApiParam("异常发行日期")
    @Transient
    private String abnormalReleaseDate;

    @ApiParam("实际回答日期")
    @Transient
    private String actualReplyDate;

    public SxQmsAbnormalReply(){

    }

    public SxQmsAbnormalReply(String orderNo, String organizeCode) {
        this.orderNo = orderNo;
        this.organizeCode = organizeCode;
    }

}
