package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @Author: Xinwang.Yi
 * @CreateDate: 2022/02/11 02:01 下午
 * @Description:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_CUSTOMER_COMPLAINT_MASTER", indexes = {
        @Index(columnList = "COMPLAINT_NO"),
        @Index(columnList = "COMPLAINT_TYPE"),
        @Index(columnList = "ABNORMAL_SOURCE"),
        @Index(columnList = "PART_NO"),
        @Index(columnList = "CUSTOMER_NO"),
        @Index(columnList = "PUBLISH_DATE"),
        @Index(columnList = "PLAN_ARRIVE_DATE"),
        @Index(columnList = "DEFECT_LEVEL"),
        @Index(columnList = "SITUATION"),
})
@Api("客诉记录主表")
public class SxQmsCustomerComplaintMaster extends BaseBean implements Serializable {

    private static final long serialVersionUID = 1032035656058358048L;

    @Column(name = "COMPLAINT_NO")
    @ApiParam("客诉单号")
    private String complaintNo;

    @Column(name = "COMPLAINT_TYPE")
    @ApiParam("客诉类型 10-异常联络，20-速报")
    private Integer complaintType;

    @Column(name = "ABNORMAL_SOURCE")
    @ApiParam("异常场所 10-市场不良、20-到货不良、30-受入不良、40-工程不良、50-改判")
    @AnnoOutputColumn(refClass = QmsEnumUtil.BU_ABNORMAL_SOURCE.class, refForeignKey = "value", value = "description")
    private Integer abnormalSource;

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    private String partNameRdd;

    @Column(name = "CUSTOMER_NO")
    @ApiParam("客户编码")
    private String customerNo;

    @Column(name = "CUSTOMER_NAME")
    @ApiParam("客户名称")
    private String customerName;

    @Column(name = "PUBLISH_DATE")
    @ApiParam("发行日期")
    private String publishDate;

    @Column(name = "PLAN_ARRIVE_DATE")
    @ApiParam("预定回达日")
    private String planArriveDate;

    @Column(name = "DEPARTMENT_NO")
    @ApiParam("事业部管理NO")
    private String departmentNo;

    @Column(name = "BADNESS_CODE")
    @ApiParam("不良点")
    private String badnessCode;

    @Column(name = "BADNESS_NAME")
    @ApiParam("不良点名称")
    private String badnessName;

    @Column(name = "ISSUE_DESC")
    @ApiParam("问题点描述")
    private String issueDesc;

    @Column(name = "DEFECT_LEVEL")
    @ApiParam("缺陷等级 10-轻度缺陷，20-中度缺陷，30-重度缺陷")
    @AnnoOutputColumn(refClass = QmsEnumUtil.DEFECT_LEVEL.class, refForeignKey = "value", value = "description")
    private Integer defectLevel;

    @Column(name = "QTY")
    @ApiParam("件数")
    private Integer qty;

    @Column(name = "SITUATION")
    @ApiParam("发生情况 10-初发，20-再发")
    private Integer situation;

    @Column(name = "PRODUCE_DATE")
    @ApiParam("生产日期")
    private String produceDate;

    @Column(name = "COMPLAINT_STATUS")
    @ApiParam("客诉单状态 10-已创建、20-已分析、30-已整改、40-已确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.BU_COMPLAINT_STATUS.class, refForeignKey = "value", value = "description")
    private Integer complaintStatus;

    @Column(name = "FILE_ID1")
    @ApiParam("文件编号1")
    private Long fileId1;

    @Column(name = "FILE_URL1")
    @ApiParam("文件URL1")
    private String fileUrl1;

    @Column(name = "FILE_ORIGIN_NAME1")
    @ApiParam("文件原名1")
    private String fileOriginName1;

    @Column(name = "FILE_ID2")
    @ApiParam("文件编号2")
    private Long fileId2;

    @Column(name = "FILE_URL2")
    @ApiParam("文件URL2")
    private String fileUrl2;

    @Column(name = "FILE_ORIGINNAME2")
    @ApiParam("文件原名2")
    private String fileOriginName2;

    @Column(name = "UPLOAD_DATE_TIME")
    @ApiParam("上传时间")
    private String uploadDatetime;

    @Column(name = "COUNTERMEASURE_CONFIRM")
    @ApiParam("对策确认 10-通过，20-不通过")
    private Integer countermeasureConfirm;

    @Column(name = "COUNTERMEASURE_NO_PASS_EXPLAIN")
    @ApiParam("对策不通过说明")
    private String countermeasureNoPassExplain;

    @Column(name = "ABARBEITUNG_CONFIRM")
    @ApiParam("整改确认 10-通过，20-不通过")
    private Integer abarbeitungConfirm;

    @Column(name = "ABARBEITUNG_NO_PASS_EXPLAIN")
    @ApiParam("整改不通过说明")
    private String abarbeitungNoPassExplain;

    @Column(name = "MANUFACTURING_SERIAL_NO")
    @ApiParam("制造编号")
    private String manufacturingSerialNo;

    @Column(name = "INSTALLATION_TIME")
    @ApiParam("安装时间")
    private String installationTime;

    @Column(name = "THE_COST_OF_TIME")
    @ApiParam("购机时间")
    private String theCostOfTime;

    @Column(name = "TIME_OF_FAILURE")
    @ApiParam("故障发生时间")
    private String timeOfFailure;

    @Column(name = "FAULT_PHENOMENON")
    @ApiParam("故障现象")
    private String faultPhenomenon;

    @Column(name = "FAILURE_CAUSE")
    @ApiParam("故障原因")
    private String failureCause;

    @Column(name = "MANUFACTURING_DATE")
    @ApiParam("制造日期")
    private String manufacturingDate;

    @Column(name = "HOURS_OF_USE")
    @ApiParam("使用时间 故障发生时间-安装时间。单位：月")
    private Double hoursOfUse;

    @Column(name = "DEPARTMENT_OF_PRODUCT_CODING")
    @ApiParam("部品编码")
    private String departmentOfProductCoding;

    @Column(name = "DEPARTMENT_OF_PRODUCT_NAME")
    @ApiParam("部品名称")
    private String departmentOfProductName;

    @Column(name = "UNIT_PRICE")
    @ApiParam("单价")
    private BigDecimal unitPrice;

    @Column(name = "AMOUNT")
    @ApiParam("金额")
    private BigDecimal amount;

    @Column(name = "SERVICE_NETWORK_STATION")
    @ApiParam("服务网点")
    private String serviceNetworkStation;

    @Column(name = "WHETHER_SECONDARY_MAINTENANCE")
    @ApiParam("是否二次维修")
    @AnnoOutputColumn(refClass = QmsEnumUtil.WHETHER_SECONDARY_MAINTENANCE.class, refForeignKey = "value", value = "description")
    private Integer whetherSecondaryMaintenance;

    @Column(name = "REMARK")
    @ApiParam("备注")
    private String remark;

    @Column(name = "SEND_ADDRESS")
    @ApiParam("仕向地")
    private String sendAddress;
}
