package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * 文件描述
 * qms物料信息
 *
 * @author puxiao.liao
 * @date 2021年02月11日 9:59
 */
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_PART",indexes = {@Index(columnList = "PART_NO")})
@Api("QMS物料信息")
public class SxQmsPart extends BaseBean {

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNameRdd;

    @Column(name = "PART_TYPE")
    @ApiParam("物料类型")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT,dataSrc = "WMS_PART_TYPE")
    @AnnoOutputColumn(refClass = QmsEnumUtil.WMS_PART_TYPE_STR.class, refForeignKey = "value", value = "description")
    private Integer partType;

    @Column(name = "PART_EXT_MAINTAINED",columnDefinition = "int(11) default 2")
    @ApiParam("是否维护品质属性")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer partExtMaintained;

    @Column(name = "PRODUCT_TYPE")
    @ApiParam("产品分类")
    private String productType;


    @ApiParam("机种编码")
    @Column(name = "MACHINE_CODE")
    private String machineCode;

    @Column(name = "PRODUCT_STAGE")
    @ApiParam("产品阶段")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PRODUCT_STAGE_TYPE.class, refForeignKey = "value", value = "description")
    private Integer productStage;

    @Column(name = "PART_PRODUCT_TYPE")
    @ApiParam("部品分类")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.NUMBER)
    @AnnoOutputColumn(refClass = QmsEnumUtil.PART_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer partProductType;

    @Column(name = "NOTE_STATUS")
    @ApiParam("式样书状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.NOTE_STATUS_TYPE.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "NOTE_STATUS_TYPE")
    private Integer noteStatus;

    @Column(name = "IS_OQC")
    @ApiParam("是否出货检")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "TRUE_OR_FALSE")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description", hidden = true)
    private Integer isOqc;

    @Column(
            name = "COLOR_CODE"
    )
    @ApiParam("颜色代码")
    private String colorCode;
    @Column(
            name = "COLOR_NAME"
    )
    @ApiParam("颜色名称")
    private String colorName;

    @Column(
            name = "PPT_CODE"
    )
    @ApiParam("产品类型代码")
    private String pptCode;

    @Column(
            name = "CATEGORY_CODE1"
    )
    @ApiParam("分类1")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CATEGORY_CODE1.class, refForeignKey = "value", value = "description", hidden = true)
    private String categoryCode1;
    @Column(
            name = "CATEGORY_CODE2"
    )
    @ApiParam("分类2")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CATEGORY_CODE2.class, refForeignKey = "value", value = "description", hidden = true)
    private String categoryCode2;
    @Column(
            name = "CATEGORY_CODE3"
    )
    @ApiParam("分类3")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CATEGORY_CODE3.class, refForeignKey = "value", value = "description", hidden = true)
    private String categoryCode3;

    @Column(name = "GOODS_CODE")
    @ApiParam("商品码")
    private String goodsCode;

    @Column(name = "SALES_TO")
    @ApiParam("销售向")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SALES_TO.class, refForeignKey = "value", value = "description", hidden = true)
    private String salesTo;

    @Column(name = "CAREER")
    @ApiParam("事业别")
    private String career;

    @Column(name = "CHECK_TYPE")
    @ApiParam("检查区分")
    @AnnoOutputColumn(refClass = QmsEnumUtil.BU_PART_CHECK_TYPE.class, refForeignKey = "value", value = "description")
    private Integer checkType;

    @Column(name = "TO_LAND")
    @ApiParam("仕向地")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SALES_TO.class, refForeignKey = "value", value = "description", hidden = true)
    private String toLand;

    @ApiParam("产品分类名称")
    @Transient
    private String productTypeName;

    @ApiParam("部品分类名称")
    @Transient
    private String partProductTypeName;


    public Integer getPartExtMaintained() {
        if (partExtMaintained == null || QmsEnumUtil.TRUE_OR_FALSE.valueOf(partExtMaintained) == null) {
            return QmsEnumUtil.TRUE_OR_FALSE.FALSE.getValue();
        }
        return partExtMaintained;
    }

    @Transient
    @ApiParam("是否维护品质属性，查询参数")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer partExtMaintainedParam;

    @Transient
    @ApiParam("事业别名称")
    private String careerName;
}
