package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * 文件描述
 * qms物料信息
 *
 * @author puxiao.liao
 * @date 2021年02月11日 9:59
 */
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_PART_EXT", indexes = {
        @Index(columnList = "PART_NO"),
        @Index(columnList = "IS_OQC"),
        @Index(columnList = "PART_NO, IS_OQC")
})
@Api("QMS物料品质属性")
public class SxQmsPartExt extends BaseBean {

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNameRdd;

    @Column(name = "IQC")
    @ApiParam("是否免检")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "TRUE_OR_FALSE")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description", hidden = true)
    private Integer iqc;

    @Column(name = "IQC_COUNT",columnDefinition =  "int default 0")
    @ApiParam("免检达成批次")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.NUMBER)
    private Integer iqcCount;

    @Column(name = "IQC_PASS_COUNT",columnDefinition =  "int default 0")
    @ApiParam("已免检达成批次")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.NUMBER)
    private Integer iqcPassCount;


    public Integer getIqcPassCount(){
        if(this.iqcPassCount == null) {
            return 0;
        }
        return this.iqcPassCount;
    }
    /**
     * 取产线信息表
     */
    @Column(name = "WORK_CENTER_CODE")
    @ApiParam("生产线编码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.LIST, getValWay = CommonEnumUtil.DYNAMIC_FIELD_GET_WAY.OBJ,
            dataSrc = "cn.estsh.i3plus.ext.qms.pojo.bean.WmsWorkCenter",
            searchColumnName = "workCenterCode,workCenterName", listColumnName = "workCenterCode,workCenterName", explicitColumnName = "workCenterCode")
    private String workCenterCode;

    @ApiParam("机种编码")
    @Column(name = "MACHINE_CODE")
    private String machineCode;

    @Column(name = "PART_TYPE")
    @ApiParam("部品分类")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.NUMBER)
    @AnnoOutputColumn(refClass = QmsEnumUtil.PART_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer partType;

    /**
     * 取字典信息
     */
    @Column(name = "PRODUCT_TYPE")
    @ApiParam("产品分类")
/*
    @AnnoOutputColumn(refClass = SysDictionary.class,refForeignKey = "PRODUCT_TYPE_DICTIONARY")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, getValWay = CommonEnumUtil.DYNAMIC_FIELD_GET_WAY.URL,
            isRequire = 2, dataSrc = "/qms/qms-enum/qms-enum/query?enumType=PRODUCT_TYPE_DICTIONARY", listColumnName = "enumValue", explicitColumnName = "enumValueDesc")
*/
    @AnnoOutputColumn(refClass = QmsEnumUtil.EP_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer productType;

    @Column(name = "CHECK_TYPE")
    @ApiParam("检查区分")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PART_CHECK_TYPE.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "PART_CHECK_TYPE")
    private Integer checkType;

    @Column(name = "PRODUCT_STAGE")
    @ApiParam("产品阶段")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PRODUCT_STAGE_TYPE.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "PRODUCT_STAGE_TYPE")
    private Integer productStage;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "SEND_ADDRESS")
    @ApiParam("仕向地")
    private String sendAddress;

    @Column(name = "PURCHASER")
    @ApiParam("购入方")
    private String purchaser;


    @Column(name = "NOTE_STATUS")
    @ApiParam("式样书状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.NOTE_STATUS_TYPE.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "NOTE_STATUS_TYPE")
    private Integer noteStatus;


    @Column(name = "IS_OQC")
    @ApiParam("是否出货检")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "TRUE_OR_FALSE")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description", hidden = true)
    private Integer isOqc;

    @Transient
    @ApiParam("机种名称")
    private String machineName;
}
