package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_PROJECT_INSPECTION_SN_RECORD",indexes = {@Index(columnList = "INSPECTION_NO")})
@Api("工程巡检条码检测记录")
public class SxQmsProjectInspectionSnRecord extends BaseBean {

    @Column(name = "TASK_NO")
    @ApiParam("任务编码")
    private String taskNo;

    @Column(name = "INSPECTION_NO")
    @ApiParam("巡查项单号")
    private String inspectionNo;

    @Column(name = "INSPECTION_NAME")
    @ApiParam("巡查项名称")
    private String inspectionName;

    @Column(name = "SN")
    @ApiParam("包装条码")
    private String sn;

    @Column(name = "WORK_CENTER")
    @ApiParam("生产线编码")
    private String workCenter;

    @Column(name = "WORK_CENTER_NAME")
    @ApiParam("生产线名称")
    private String workCenterName;

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    private String partNameRdd;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "DATE_CODE")
    @ApiParam("生产日期")
    private String dateCode;

    @Column(name = "RECORD_RESULT")
    @ApiParam("结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QMS_OQC_CHECK_DETAIL_RESULT.class, refForeignKey = "value", value = "description")
    private Integer recordResult;

    @Column(name = "CHECK_TYPE")
    @ApiParam("检测类型")
    private Integer checkType;

    @Column(name = "ACTUAL_VALUE")
    @ApiParam("实测值")
    private String actualValue;

    /**比值类型 可能为字符串**/
    @Column(name = "STANDARD_VALUE")
    @ApiParam("标准值")
    private String standardValue;

    @Column(name = "MAX_VALUE")
    @ApiParam("最大值")
    private Double maxValue;

    @Column(name = "MIN_VALUE")
    @ApiParam("最小值")
    private Double minValue;

    @Column(name = "REMARK")
    @ApiParam("备注")
    private String remark;

    @Column(name = "IS_NECESSARY")
    @ApiParam("是否必检")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer isNecessary;

    @Transient
    @ApiParam("单据状态")
    private Integer orderStatus;

    @Transient
    @ApiParam("总结果")
    private Integer taskRecordResult;

    @Transient
    @ApiParam(value = "开始时间")
    private String createDatetimeStart;

    @Transient
    @ApiParam(value = "结束时间")
    private String createDatetimeEnd;



    public SxQmsProjectInspectionSnRecord(){}

    public SxQmsProjectInspectionSnRecord(
           String inspectionNo,
           String taskNo,
           String sn,
           Integer taskRecordResult,
           Integer orderStatus,
           String partNo,
           String partNameRdd,
           Integer checkType,
           String actualValue,
           Integer recordResult,
           String createDatetime,
           String createUser
    ){
        this.inspectionNo = inspectionNo;
        this.taskNo = taskNo;
        this.sn = sn;
        this.taskRecordResult = taskRecordResult;
        this.orderStatus = orderStatus;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.checkType = checkType;
        this.actualValue = actualValue;
        this.recordResult = recordResult;
        this.createDatetime = createDatetime;
        this.createUser = createUser;
    }
}
