package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 质检单明细信息
 * @Reference :
 * @Author : puxiao.liao
 * @CreateDate : 2022-03-06 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_QC_DETAILS",indexes = {@Index(columnList = "ORDER_NO,PART_NO,VENDOR_NO")})
@Api("质检单明细信息")
public class SxQmsQCDetails extends BaseBean {
    private static final long serialVersionUID = 7442224593652923072L;
    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    private String partNameRdd;

    @Column(name = "ITEM")
    @ApiParam("行号")
    private String item;

    @Column(name = "QTY", columnDefinition = "decimal(18,8)", nullable = false)
    @ColumnDefault("0")
    @ApiParam(value = "数量", example = "0")
    private Double qty;

    @Column(name = "UNIT")
    @ApiParam("单位")
    private String unit;

    @Column(name = "ORDER_NO")
    @ApiParam("订单号")
    private String orderNo;

    /**
     * 状态:N=正常,C=行取消
     */
    @Column(name = "ITEM_STATUS")
    @ApiParam(value = "状态", example = "1")
    @AnnoOutputColumn(refClass = WmsEnumUtil.QC_ITEM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer itemStatus;

    @Column(name = "REMARK")
    @ApiParam("备注")
    private String remark;


    @Column(name = "FACT_QTY", columnDefinition = "decimal(18,8)", nullable = false)
    @ColumnDefault("0")
    @ApiParam(value = "实检数量", example = "0")
    private Double factQty;

    @Column(name = "PASS_QTY", columnDefinition = "decimal(18,8)", nullable = false)
    @ColumnDefault("0")
    @ApiParam(value = "合格数量", example = "0")
    private Double passQty;

    @Column(name = "REJECT_QTY", columnDefinition = "decimal(18,8)", nullable = false)
    @ColumnDefault("0")
    @ApiParam(value = "不合格数量", example = "0")
    private Double rejectQty;

    @Column(name = "RC_QTY", columnDefinition = "decimal(18,8)", nullable = false)
    @ColumnDefault("0")
    @ApiParam(value = "收货数量", example = "0")
    private Double rcQty;

    @Version
    @Column(name = "LOCK_VERSION", columnDefinition = "int default 0")
    @ApiParam(value = "乐观锁", example = "1")
    private transient Integer lockVersion;

    /************报表查询字段*****************/
    @Column(name = "PART_TYPE")
    @ApiParam("部品分类")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.NUMBER)
    @AnnoOutputColumn(refClass = QmsEnumUtil.PART_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer partType;


    @Column(name = "PRODUCT_TYPE")
    @ApiParam("产品分类")
    @AnnoOutputColumn(refClass = QmsEnumUtil.EP_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer productType;

    @Column(name = "WORK_CENTER_CODE")
    @ApiParam("生产线编码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.LIST, getValWay = CommonEnumUtil.DYNAMIC_FIELD_GET_WAY.OBJ,
            dataSrc = "cn.estsh.i3plus.ext.qms.pojo.bean.WmsWorkCenter",
            searchColumnName = "workCenterCode,workCenterName", listColumnName = "workCenterCode,workCenterName", explicitColumnName = "workCenterCode")
    private String workCenterCode;


    @Column(name = "PART_CHECK_TYPE")
    @ApiParam("检查区分")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PART_CHECK_TYPE.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, isRequire = 2, dataSrc = "PART_CHECK_TYPE")
    private Integer partCheckType;


    @Column(name = "VENDOR_DESC")
    @ApiParam(value = "供应商全称")
    private String vendorDesc;

    @Column(name = "VENDOR_NO")
    @ApiParam(value = "供应商编号")
    public String vendorNo;

    @Transient
    @ApiParam(value = "单据状态")
    private Integer orderStatus;


    @Transient
    @ApiParam(value = "开始时间")
    private String createDatetimeStart;

    @Transient
    @ApiParam(value = "结束时间")
    private String createDatetimeEnd;


    @Transient
    @ApiParam(value = "关联单号")
    private String refSrc;

    private Integer qcStatus;

    @ApiParam(value = "单据数量")
    private Double poQty;
    public SxQmsQCDetails() {
    }


    public SxQmsQCDetails(String orderNo,
                          String vendorNo,
                          String vendorDesc,
                          String partNo,
                          String partNameRdd,
                          Double qty,
                          String refSrc,
                          Double poQty,
                          Integer qcStatus,
                          Integer orderStatus,
                          Integer partType,
                          Integer partCheckType) {
        this.orderNo = orderNo;
        this.vendorNo = vendorNo;
        this.vendorDesc = vendorDesc;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.qty = qty;
        this.refSrc = refSrc;
        this.poQty = poQty;
        this.qcStatus = qcStatus;
        this.orderStatus = orderStatus;
        this.partType=partType;
        this.partCheckType = partCheckType;
    }

    //qc_master.orderNo,qc_master.vendorNo,qc_master.vendorDesc,qc_detail.partNo,
    // qc_detail.partNameRdd,qc_detail.qty,qc_master.refSrc,qc_master.poQty,
    // qc_master.qcStatus,qc_master.orderStatus,qc_detail.partType,qc_detail.partCheckType

    public SxQmsQCDetails(String organizeCode, String partNo, String partNameRdd, String item,
                          Double qty, String unit, String orderNo,
                          Integer itemStatus, String remark, Double factQty,
                          Double passQty, Double rejectQty,
                          Integer orderStatus, String vendorNo, String vendorDesc,
                          String createUser, String createDatetime, String modifyUser, String modifyDatetime) {
        this.organizeCode = organizeCode;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.item = item;
        this.qty = qty;
        this.unit = unit;
        this.orderNo = orderNo;
        this.itemStatus = itemStatus;
        this.remark = remark;
        this.factQty = factQty;
        this.passQty = passQty;
        this.rejectQty = rejectQty;
        this.orderStatus = orderStatus;
        this.vendorNo = vendorNo;
        this.vendorDesc = vendorDesc;
        this.createUser = createUser;
        this.createDatetime = createDatetime;
        this.modifyUser = modifyUser;
        this.modifyDatetime = modifyDatetime;
    }

    public SxQmsQCDetails(String partNo, String partNameRdd, String item,
                          Double qty, String unit, String orderNo,
                          Integer itemStatus, String remark, Double factQty,
                          Double passQty, Double rejectQty,
                          Integer orderStatus, String vendorNo, String vendorDesc) {
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.item = item;
        this.qty = qty;
        this.unit = unit;
        this.orderNo = orderNo;
        this.itemStatus = itemStatus;
        this.remark = remark;
        this.factQty = factQty;
        this.passQty = passQty;
        this.rejectQty = rejectQty;
        this.orderStatus = orderStatus;
        this.vendorNo = vendorNo;
        this.vendorDesc = vendorDesc;
    }
}
