package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * 收货校验结果
 *
 * @author puxiao.liao
 * @date 2022年03月06日 17:21
 */
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_QC_MASTER",indexes =
        {@Index(columnList = "ORDER_NO"),
                @Index(columnList = "VENDOR_NO"),
                @Index(columnList = "DATE_CODE"),}
        )
@Api("收货校验单")
public class SxQmsQCMaster extends BaseBean {

    @Column(name = "ORDER_NO")
    @ApiParam("单号")
    private String orderNo;

    @Column(name = "PO_QTY")
    @ApiParam("PO数量")
    private Double poQty;

    @Column(name = "REF_SRC")
    @ApiParam("关联单号")
    private String refSrc;

    @Column(name = "ERP_SRC_NO")
    @ApiParam("ERP单号")
    public String erpSrcNo;

    @Column(name = "QTY")
    @ApiParam("质检数量")
    private Integer qty;

    @Column(name = "CUST_NAME")
    @ApiParam(value = "客户简称")
    private String custName;

    @Column(name = "CUST_NO")
    @ApiParam("客户编号")
    public String custNo;

    @Column(name = "VENDOR_DESC")
    @ApiParam(value = "供应商全称")
    private String vendorDesc;

    @Column(name = "VENDOR_NO")
    @ApiParam(value = "供应商编号")
    public String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam(value = "供应商名称")
    private String vendorName;

    @Column(name = "GLOBAL_VENDOR_NAME")
    @ApiParam(value = "全球供应商名称")
    private String globalVendorName;

    @Column(name = "IS_TASK")
    @ApiParam(value = "是否生产任务", example = "1")
    @AnnoOutputColumn(refClass = WmsEnumUtil.IS_GENERAL_TASK.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, dataSrc = "IS_GENERAL_TASK")
    public Integer isTask;

    @Column(name = "IS_PART")
    @ApiParam(value = "是否散件", example = "2")
    @AnnoOutputColumn(refClass = WmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, dataSrc = "TRUE_OR_FALSE")
    public Integer isPart;

    /**
     * 业务类型:IQC=进料检验,IPQC=在线检验,
     * FQC=成品检验,OQC=出货检验
     */
    @Column(name = "ORDER_TYPE")
    @ApiParam(value = "业务类型", example = "0")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_INFO_TYPE.class, refForeignKey = "value", value = "description")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, dataSrc = "QC_INFO_TYPE")
    public Integer orderType;

    @Column(name = "QC_MODE")
    @ApiParam("结果类型")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_MODE_TYPE.class, refForeignKey = "value", value = "description")
    private Integer qcMode;

    @Column(name = "ORDER_STATUS")
    @ApiParam("单据状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_INFO_STATUS.class, refForeignKey = "value", value = "description")
    private Integer orderStatus;

    @Column(name = "QC_STATUS")
    @ApiParam("检测结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_STATUS.class, refForeignKey = "value", value = "description")
    private Integer qcStatus;

    @Column(name = "VERSION")
    @ApiParam(value = "版本", example = "1")
    public Integer version;

    @Column(name = "REF_TYPE")
    @ApiParam("关联单号类型")
    public String refType;

    @Column(name = "SUGGESTION")
    @ApiParam("处理意见")
    private String suggestion;

    @Column(name = "REMARK")
    @ApiParam("备注")
    private String remark;

    @Column(name = "COST_TIME")
    @ApiParam("质检用时")
    private Integer costTime;

    @Column(name = "QC_START_DATE_TIME")
    @ApiParam("质检开始时间")
    private String qcStartDateTime;

    @Column(name = "QC_END_DATE_TIME")
    @ApiParam("质检结束时间")
    private String qcEndDateTime;

    @Column(name = "CHECK_DATE")
    @ApiParam("检查日期")
    private String checkDate;

    @Column(name = "DATE_CODE")
    @ApiParam("生产日期")
    private String dateCode;

    @Column(name = "RC_DATE")
    @ApiParam("收货日期")
    private String rcDate;

    @Column(name = "QUALITY_USER")
    @ApiParam("品质担当")
    private String qualityUser;


    @ApiParam("同步状态")
    @Column(name = "IS_SYNC",columnDefinition = "int default 2")
    @AnnoOutputColumn(refClass = QmsEnumUtil.IF_SYNC_STATUS.class, refForeignKey = "value", value = "description")
    private Integer isSync;

    @ApiParam("出厂报告URL")
    @Column(name = "REPORT_URL")
    private Integer reportUrl;

    @ApiParam("出厂报告")
    @Column(name = "REPORT_FILE_NAME")
    private Integer reportFileName;


    @ApiParam("错误信息")
    @Column(name = "SYNC_ERROR_MSG")
    private String syncErrorMsg;

    @Transient
    @ApiParam("物料编码")
    private String partNo;

    @Transient
    @ApiParam("物料名称")
    private String partNameRdd;

    @Transient
    @ApiParam("机种编码")
    private String machineCode;

    @Transient
    @ApiParam(value = "收货数量", example = "0")
    private Double rcQty;

    @ApiParam("检验类型")
    @Column(name = "TEST_TYPE")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TEST_TYPE.class, refForeignKey = "value", value = "description")
    private Integer testType;

    @Column(name = "ITEM_TYPE")
    @ApiParam("单据类型")
    @AnnoOutputColumn(refClass = QmsEnumUtil.ITEM_TYPE.class, refForeignKey = "value", value = "description")
    private Integer itemType;

    @Column(name = "SOURCE_ORDER_NO")
    @ApiParam("源单号")
    private String sourceOrderNo;

    @Transient
    @ApiParam("事业别")
    private String career;

    @Transient
    @ApiParam(value = "合格数量", example = "0")
    private Integer passQty;

    @Transient
    @ApiParam(value = "不合格数量", example = "0")
    private Integer failQty;

    @Transient
    @ApiParam(value = "特采数量", example = "0")
    private Integer specialQty;

    @Transient
    @ApiParam(value = "已质检数量", example = "0")
    private Integer qcQty;

    @Transient
    @ApiParam("部品分类")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PART_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer partType;

    @Transient
    @ApiParam("产品分类")
    private String productType;

    @ApiParam(value = "同一PO单截至目前的收货数量", example = "0")
    @Column(name = "PO_RC_QTY", columnDefinition = "decimal(18,8)", nullable = false)
    @ColumnDefault("0")
    private Double poRcQty;

    @ApiParam(value = "模块")
    @Column(name = "MODULE")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SX_QMS_RC_RULE_NOTE_MODULE.class, refForeignKey = "value", value = "description")
    private Integer module;

    @ApiParam(value = "标识是ODM受入还是部品受入QMS创建的质检单 -- YES = ODM")
    @Column(name = "IS_QC")
    @AnnoOutputColumn(refClass = QmsEnumUtil.IS_EXISTS.class, refForeignKey = "value", value = "description")
    private Integer isQc;

    @Column(name = "QC_STATUS_RESULT")
    @ApiParam("检测总结果 ODM用")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_STATUS.class, refForeignKey = "value", value = "description")
    private Integer qcStatusResult;

    @Column(name = "IS_ABNORMAL_HANDLE")
    @ApiParam("是否异常处置")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer isAbnormalHandle;

    @Column(name = "IQC")
    @ApiParam("是否免检")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description", hidden = true)
    @ColumnDefault(value = "2")
    private Integer iqc;

    @ApiParam("条码")
    @Transient
    private String sn;

    @ApiParam("检验项目")
    @Transient
    private String checkItem;

    @ApiParam("判定基准")
    @Transient
    private String standardOfCriterion;

    @ApiParam("上限值")
    @Transient
    private String upLimit;

    @ApiParam("下限值")
    @Transient
    private String downLimit;

    @ApiParam("测定器具")
    @Transient
    private String checkTool;

    @ApiParam("实测1")
    @Transient
    private String actualValue1;

    @ApiParam("判定结果")
    @Transient
    private Integer checkResult;

    @ApiParam("标准值")
    @Transient
    private String standard;

    @ApiParam("值类型")
    @Transient
    private Integer checkType;

    @Column(name = "SYNC_USER")
    @ApiParam("同步用户")
    public String syncUser;

    @Column(name = "SYNC_DATE_TIME")
    @ApiParam("同步日期")
    public String syncDatetime;

    public SxQmsQCMaster() {}

    public SxQmsQCMaster(String orderNo, Integer costTime) {
        this.orderNo = orderNo;
        this.costTime = costTime;
    }
    public SxQmsQCMaster(String vendorNo, String vendorDesc, Integer qty) {
        this.vendorNo = vendorNo;
        this.vendorDesc = vendorDesc;
        this.qty = qty;
    }

    public SxQmsQCMaster(Integer orderStatus, Integer qcStatus, String career) {
        this.orderStatus = orderStatus;
        this.qcStatus = qcStatus;
        this.career = career;
    }

    public SxQmsQCMaster(String orderNo, String partNo, String partNameRdd, String vendorName, Integer orderStatus, String qcStartDateTime, String createDatetime) {
        this.orderNo = orderNo;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.vendorName = vendorName;
        this.orderStatus = orderStatus;
        this.qcStartDateTime = qcStartDateTime;
        this.createDatetime = createDatetime;
    }

    public SxQmsQCMaster(String vendorName, Integer qcStatus, String createDatetime, Integer orderStatus) {
        this.vendorName = vendorName;
        this.createDatetime = createDatetime;
        this.qcStatus = qcStatus;
        this.orderStatus = orderStatus;
    }

    public SxQmsQCMaster(String checkDate, String orderNo, String refSrc, String vendorNo, String vendorDesc, Integer testType,
                         Integer qcStatus, String rcDate, String dateCode, String partNo, String partNameRdd, String productType, Double rcQty) {
        this.checkDate = checkDate;
        this.orderNo = orderNo;
        this.refSrc = refSrc;
        this.vendorNo = vendorNo;
        this.vendorDesc = vendorDesc;
        this.testType = testType;
        this.qcStatus = qcStatus;
        this.rcDate = rcDate;
        this.dateCode = dateCode;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.productType = productType;
        this.rcQty = rcQty;
    }

    public SxQmsQCMaster(String vendorNo, String partNo, String checkDate) {
        this.vendorNo = vendorNo;
        this.partNo = partNo;
        this.checkDate = checkDate;
    }

    public SxQmsQCMaster(Integer qcStatus, Integer qcMode, Integer orderStatus) {
        this.qcStatus = qcStatus;
        this.qcMode = qcMode;
        this.orderStatus = orderStatus;
    }

    public SxQmsQCMaster(String orderNo, Integer qcStatus, Integer qcMode, Integer orderStatus) {
        this.orderNo = orderNo;
        this.qcStatus = qcStatus;
        this.qcMode = qcMode;
        this.orderStatus = orderStatus;
    }

    public SxQmsQCMaster(String orderNo, String partNo, String partNameRdd, String rcDate, double qty, Integer qcStatusResult) {
        this.orderNo = orderNo;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.rcDate = rcDate;
        this.qty = (int) qty;
        this.qcStatusResult = qcStatusResult;
    }

    public SxQmsQCMaster(String orderNo, String partNo, String partNameRdd, String rcDate, double qty, Integer qcStatusResult, Integer iqc, String modifyUser) {
        this.orderNo = orderNo;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.rcDate = rcDate;
        this.qty = (int) qty;
        this.qcStatusResult = qcStatusResult;
        this.iqc = iqc;
        this.modifyUser = modifyUser;
    }

    public SxQmsQCMaster(String orderNo, String refSrc, String partNo, String partNameRdd, String vendorNo, String vendorName,
                         String sn, Integer itemType, String rcDate, String modifyUser, Integer qcStatus, String qcEndDateTime,
                         String checkItem, String standardOfCriterion, String upLimit, String downLimit, String checkTool, String actualValue1,
                         Integer checkResult, String remark, String standard, Integer checkType) {
        this.orderNo = orderNo;
        this.refSrc = refSrc;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.vendorNo = vendorNo;
        this.vendorName = vendorName;
        this.sn = sn;
        this.itemType = itemType;
        this.rcDate = rcDate;
        this.modifyUser = modifyUser;
        this.qcStatus = qcStatus;
        this.qcEndDateTime = qcEndDateTime;
        this.checkItem = checkItem;
        this.standardOfCriterion = standardOfCriterion;
        this.upLimit = upLimit;
        this.downLimit = downLimit;
        this.checkTool = checkTool;
        this.actualValue1 = actualValue1;
        this.checkResult = checkResult;
        this.remark = remark;
        this.standard = standard;
        this.checkType = checkType;
    }
}
