package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.util.List;

/**
 * @Description : 质检单条码信息
 * @Reference :
 * @Author : puxiao
 * @CreateDate : 2022-02-19 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_QC_SN",indexes = {@Index(columnList = "ORDER_NO,SN")})
@Api("收货条码检测记录")
public class SxQmsQCSn extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    @Column(name="ITEM")
    @ApiParam("行号")
    public String item;

    /**
     * 状态:1=创建,10=已处理
     */
    @Column(name="ITEM_STATUS")
    @ApiParam(value = "状态", example = "1")
    public Integer itemStatus;

    @Column(name="REMARK")
    @ApiParam("备注")
    public String remark;

    @Column(name="PASS_QTY", nullable = false)
    @ApiParam("合格数量")
    @ColumnDefault("0")
    public double passQty;

    @Column(name="REJECT_QTY", nullable = false)
    @ApiParam("不合格数量")
    @ColumnDefault("0")
    public double rejectQty;

    @Column(name="UNIT")
    @ApiParam("单位")
    public String unit;

    @Column(name="PART_NO")
    @ApiParam("物料编码")
    public String partNo;

    @Column(name="PART_NAME_RDD")
    @ApiParam("物料名称")
    public String partNameRdd;

    @Column(name="SN")
    @ApiParam("条码")
    public String sn;

    @Column(name = "QC_USER")
    @ApiParam("检验员")
    public String qcUser;

    @Column(name = "QC_TIME")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @ApiParam(value = "检验时间", example = "2000-01-01 01:00:00")
    public String qcTime;

    @Column(name = "VENDOR_NO")
    @ApiParam(value = "供应商编码")
    public String vendorNo;

    @Column(name = "DATE_CODE")
    @ApiParam("供应商批次")
    public String dateCode;

    @Column(name = "QC_STATUS", columnDefinition = "int default 0")
    @ApiParam("处理结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_SN_STATUS.class, refForeignKey = "value", value = "description")
    public Integer qcStatus;


    @Column(name="SPECIAL_ORDER_NO")
    @ApiParam("特采单号")
    public String specialOrderNo;


    @ApiParam(value = "抽检数量")
    private Double checkQty;

    @Transient
    @ApiParam("检测数量")
    private Double actQty;

    @Transient
    @ApiParam("单号集合")
    private List<String> orderNoLst;

    @Transient
    @ApiParam("ERP单号")
    public String erpSrcNo;





    public SxQmsQCSn() {
    }

    public SxQmsQCSn(String orderNo, double passQty) {
        this.orderNo = orderNo;
        this.passQty = passQty;
    }
}
