package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;
import java.util.StringJoiner;

@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_QC_TRANS_DETAILS_SUM",indexes = {
        @Index(columnList = "PART_NO"),
        @Index(columnList = "VENDOR_NO"),
        @Index(columnList = "DATE_CODE"),
        @Index(columnList = "QC_DATE"),
})
@Api("收货检测记录结果值汇总")
public class SxQmsQCTransDetailsSum extends BaseBean {

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    private String partNameRdd;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "PROJECT_CODE")
    @ApiParam("项目类型")
    private String projectCode;

    @Column(name = "PROJECT_NAME")
    @ApiParam("项目类型")
    private String projectName;


    @ApiParam("检测结果")
    @Column(name = "QC_STATUS")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_STATUS.class, refForeignKey = "value", value = "description")
    private Integer qcStatus;


    @Column(name = "QTY",columnDefinition = "int default 0")
    @ApiParam("数量")
    private Integer qty;

    @Column(name = "DATE_CODE")
    @ApiParam("批次")
    private String dateCode;

    @Column(name = "QC_DATE")
    @ApiParam("质检日期")
    private String qcDate;

    @Transient
    @ApiParam(value = "报表统计周期：day-按日统计显示，week-按周统计显示，month-按月")
    private String region;

    @Transient
    @ApiParam(value = "质检开始时间")
    private String createDatetimeStart;

    @Transient
    @ApiParam(value = "质检结束时间")
    private String createDatetimeEnd;


    public SxQmsQCTransDetailsSum(){}

    public SxQmsQCTransDetailsSum(String organizeCode,
                                  String partNo,
                                  String partNameRdd,
                                  String vendorNo,
                                  String vendorName,
                                  String dateCode,
                                  String qcDate,
                                  String projectCode,
                                  String projectName,
                                  Integer checkResult,
                                  Integer qty) {
        this.organizeCode =organizeCode;
        this.partNo = partNo;
        this.partNameRdd= partNameRdd;
        this.vendorNo= vendorNo;
        this.vendorName= vendorName;
        this.dateCode= dateCode;
        this.qcDate= qcDate;
        this.projectCode= projectCode;
        this.projectName= projectName;
        this.qcStatus= checkResult;
        this.qty = qty;
    }

    public String groupByColumn() {
        String key = new StringJoiner(":")
                .add(this.getVendorNo())
                .add(this.getPartNo())
                .add(this.getProjectCode())
                .add(this.getQcDate())
                .add(String.valueOf(this.getQcStatus())).toString();
        return key;
    }
}
