package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * 受入检验
 * 零部件校验规格书
 *
 * @author songlian.shi
 * @date 2021年02月11日 17:04
 */
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_RC_RULE_NOTE",indexes = {@Index(columnList = "PART_NO")})
@Api("零部件校验规格书(受入检验)")
public class SxQmsRcRuleNote extends BaseBean {

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    private String partNameRdd;

    @Column(name = "MACHINE_CODE")
    @ApiParam(value = "机种编码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, getValWay = CommonEnumUtil.DYNAMIC_FIELD_GET_WAY.URL,
            isRequire = 2, dataSrc = "/qms/qms-enum/qms-enum/query?enumType=MACHINE_CODE_DICTIONARY", listColumnName = "enumValue", explicitColumnName = "enumValueDesc")
    private String machineCode;

    @Column(name = "MACHINE_NAME")
    @ApiParam(value = "机种名称")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String machineName;

    @Column(name = "COMPLATE_DATE")
    @ApiParam("作成日期")
    private String complateDate;

    @Column(name = "PICTRUE_NO")
    @ApiParam("图号")
    private String pictrueNo;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "OUT_QTY")
    @ApiParam("出模数")
    private Integer outQty;

    @Column(name = "STATUS",columnDefinition = "int default 10")
    @ApiParam(value = "式样书状态",name = "式样书状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.NOTE_STATUS_TYPE.class, refForeignKey = "value", value = "description")
    private Integer status;

    @Column(name = "UPLOAD_DATE_TIME")
    @ApiParam("上传时间")
    private String uploadDateTime;

    @Column(name = "FILE_ID")
    @ApiParam("文件ID")
    private Long fileId;

    @Column(name = "FILE_ORIGIN_NAME",columnDefinition = "longtext")
    @ApiParam("文件源名")
    private String fileOriginName;

    @Column(name = "FILE_URL",columnDefinition = "longtext")
    @ApiParam("文件URL")
    private String fileUrl;

    @Column(name = "LOT_NO")
    @ApiParam("批次号")
    private String lotNo;

    @Column(name = "REMARK")
    @ApiParam("备注")
    private String remark;


    @Transient
    @ApiParam("目标物料编码")
    private String targetPartNo;


    @Transient
    @ApiParam("目标物料名称")
    private String targetPartNameRdd;

    @Transient
    @ApiParam("目标供应商编码")
    private String targetVerdorNo;

    @Transient
    @ApiParam("目标供应商编码名称")
    private String targetVerdorName;

    @ApiParam(value = "抽检数量")
    @Column(name = "CHECK_QTY")
    private Integer checkQty;

    @ApiParam(value = "模块")
    @Column(name = "MODULE",columnDefinition = "int default 0")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SX_QMS_RC_RULE_NOTE_MODULE.class, refForeignKey = "value", value = "description")
    private Integer module;

    @Transient
    @ApiParam("修改前的物料号")
    private String oldPartNo;

    @Transient
    @ApiParam("修改前的物料名称")
    private String oldPartName;

    @Transient
    @ApiParam("修改前的供应商编号")
    private String oldVendorNo;

    @Transient
    @ApiParam("修改前的供应商名称")
    private String oldVendorName;
}
