package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_SHIP_STOP_ORDER")
@Api("出货停止指令书")
public class SxQmsShipStopOrder extends BaseBean {

    @Column(name = "ORDER_NO")
    @ApiParam("单号")
    private String orderNo;

    @Column(name = "MANAGE_NO")
    @ApiParam("管理NO")
    private String manageNo;

    @Column(name = "CAUSE_TYPE")
    @ApiParam("异常区分")
    @AnnoOutputColumn(refClass = QmsEnumUtil.ABNORMAL_SOURCE.class)
    private Integer causeType;

    @Column(name = "DEAL_OPTION")
    @ApiParam("应急处理")
    private String dealOption;

    @Column(name = "REF_ORDER_NO")
    @ApiParam("关联单号")
    private String refOrderNo;

    @Column(name = "REF_OQC_NO")
    @ApiParam("出货检验单号")
    private String refOqcNo;

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    private String partNameRdd;

    @Column(name = "MACHINE_CODE")
    @ApiParam("机种编码")
    private String machineCode;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "PUBLISH_DATE")
    @ApiParam("发行日期")
    private String publishDate;

    @Column(name = "FILE_NAME")
    @ApiParam("件名")
    private String fileName;

    @Column(name = "ABNORMAL_CONTENT")
    @ApiParam("异常内容")
    private String abnormalContent;

    @Column(name = "ORDER_STATUS")
    @ApiParam("状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.STOP_ORDER_STATUS.class)
    private Integer orderStatus;

    @Column(name = "RELIEVE_DATE")
    @ApiParam("解除日期")
    private String relieveDate;

    @Column(name = "DEAL_CONTEN")
    @ApiParam("处置内容")
    private String dealConten;

    @Column(name = "RELIEVE_USER_NAME")
    @ApiParam("解除人")
    private String relieveUserName;

    @Column(name = "RELIEVE_TIME")
    @ApiParam("解除时间")
    private String relieveTime;

    @Column(name = "RELIEVE_RANGE")
    @ApiParam("解除对象范围")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SHIP_STOP_RELIEVE_RANGE.class)
    private Integer relieveRange;

    @Column(name = "RE_CHECK_MODE")
    @ApiParam("再检方式")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SHIP_STOP_RE_CHECK_MODE.class)
    private Integer reCheckMode;

    @Column(name = "RE_CHECK_RESULTS")
    @ApiParam("再检结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QMS_OQC_CHECK_RESULT.class)
    private Integer reCheckResults;

    @Column(name = "STOP_TYPE")
    @ApiParam("停止类型")
    @AnnoOutputColumn(refClass = QmsEnumUtil.STOP_TYPE.class)
    private Integer stopType;

    @Column(name = "CONFIRM_STATUS")
    @ApiParam("出货停止指令书确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.PASS_OR_NO_PASS.class, refForeignKey = "value", value = "description")
    private Integer confirmStatus;

    @Transient
    @ApiParam("查询参数，生产线编码")
    private String workCenterCode;

    @Transient
    @ApiParam("查询参数，产品分类")
    @AnnoOutputColumn(refClass = QmsEnumUtil.EP_PRODUCT_TYPE.class, refForeignKey = "value", value = "description")
    private Integer productType;

    @Transient
    @ApiParam("发行开始日期")
    private String publishDateStart;

    @Transient
    @ApiParam("发行结束日期")
    private String publishDateEnd;
}
