package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_SHIP_STOP_ORDER_SN")
@Api("出货停止指令书条码")
public class SxQmsShipStopOrderSn extends BaseBean {

    @Column(name = "ORDER_NO")
    @ApiParam("出货停止指令书单号")
    private String orderNo;

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    private String partNameRdd;

    @Column(name = "MACHINE_CODE")
    @ApiParam("机种编码")
    private String machineCode;

    @Column(name = "SERIAL_NUMBER")
    @ApiParam("产品条码")
    private String serialNumber;

    @Column(name = "PACKAGE_NO")
    @ApiParam("包装编号")
    private String packageNo;

    @Column(name = "NOTE_CHECK_RESULT")
    @ApiParam("停止指示书检验结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QMS_OQC_CHECK_RESULT.class, refForeignKey = "value", value = "description")
    private Integer noteCheckResult;

    @Column(name = "SN_STATUS",columnDefinition = "int(11) default 10")
    @ApiParam("条码状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.STOP_SN_STATUS.class)
    private Integer snStatus;

    @Column(name = "RELIEVE_DATE")
    @ApiParam("解除日期")
    private String relieveDate;

    @Column(name = "DEAL_CONTEN")
    @ApiParam("处置内容")
    private String dealConten;

    @Column(name = "RELIEVE_RANGE")
    @ApiParam("解除对象范围")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SHIP_STOP_RELIEVE_RANGE.class)
    private Integer relieveRange;

    @Column(name = "RE_CHECK_MODE")
    @ApiParam("再检方式")
    @AnnoOutputColumn(refClass = QmsEnumUtil.SHIP_STOP_RE_CHECK_MODE.class)
    private Integer reCheckMode;

    @Column(name = "RE_CHECK_RESULTS")
    @ApiParam("再检结果")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QMS_OQC_CHECK_RESULT.class)
    private Integer reCheckResults;

    @Transient
    @ApiParam("查询参数，产品开始条码")
    private String serialNumberStart;

    @Transient
    @ApiParam("查询参数，产品结束条码")
    private String serialNumberEnd;

    public SxQmsShipStopOrderSn(String orderNo, String partNo, String partNameRdd, String machineCode, String serialNumber, Integer noteCheckResult) {
        this.orderNo = orderNo;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.machineCode = machineCode;
        this.serialNumber = serialNumber;
        this.noteCheckResult = noteCheckResult;
    }

    public SxQmsShipStopOrderSn(String orderNo, String partNo, String partNameRdd, String machineCode, String serialNumber, Integer noteCheckResult, String packageNo) {
        this.orderNo = orderNo;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.machineCode = machineCode;
        this.serialNumber = serialNumber;
        this.noteCheckResult = noteCheckResult;
        this.packageNo = packageNo;
    }

    public SxQmsShipStopOrderSn() {
    }
}
