package cn.estsh.i3plus.pojo.qms.bean;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Inheritance(strategy = InheritanceType.JOINED)
@Table(name = "SX_QMS_VQE_ABNORMAL_MASTER",indexes = {@Index(columnList = "ORDER_NO,PART_NO")})
@Api("供应商业绩异常联络单")
public class SxQmsVqeAbnormalMaster extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    @Column(name = "YEAR")
    @ApiParam("评价年份")
    private Integer year;

    @Column(name = "MONTH")
    @ApiParam("评价月份")
    private Integer month;

    @Column(name = "VENDOR_NO")
    @ApiParam("供应商编码")
    private String vendorNo;

    @Column(name = "VENDOR_NAME")
    @ApiParam("供应商名称")
    private String vendorName;

    @Column(name = "PART_NO")
    @ApiParam("物料编码")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNo;

    @Column(name = "PART_NAME_RDD")
    @ApiParam("物料名称")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.TEXT)
    private String partNameRdd;

    @Column(name = "MONTH_GRADE")
    @ApiParam("当月等级")
    @AnnoOutputColumn(refClass = QmsEnumUtil.ABCD.class)
    private Integer monthGrade;

    /**
     * yyyy-MM-dd 格式
     */
    @Column(name = "REPLY_END_DATE")
    @ApiParam("回复期限日期")
    private String replyEndDate;

    @Column(name = "RED_YELLOW_WARN")
    @ApiParam("红黄牌警告")
    private String redYellowWarn;

    @Column(name = "ISSUE_DATE")
    @ApiParam("发行日期")
    private String issueDate;

    @Column(name = "QUALITY_JUDGE")
    @ApiParam("品质决算判断")
    @AnnoOutputColumn(refClass = QmsEnumUtil.NEED_OR_NO.class)
    private Integer qualityJudge;

    @Column(name = "PROJECT_SUPERVISION_JUDGE")
    @ApiParam("工程监查判断")
    @AnnoOutputColumn(refClass = QmsEnumUtil.NEED_OR_NO.class)
    private Integer projectSupervisionJudge;

    @Column(name = "ORDER_STATUS",columnDefinition = "int default 10")
    @ApiParam("状态")
    @AnnoOutputColumn(refClass = QmsEnumUtil.ABNORMAL_ORDER_STATUS.class, refForeignKey = "value", value = "description")
    private Integer orderStatus;

    @Column(name = "REPLY_OVER_TIME",columnDefinition = "int default 2")
    @ApiParam("是否超时回复")
    @AnnoOutputColumn(refClass = QmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    private Integer replyOverTime;

    @Column(name = "MANAGEMENT_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("物管确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer managementConfirm;

    @Column(name = "MANAGEMENT_CONFIRM_DATE_TIME")
    @ApiParam("物管确认时间")
    private String managementConfirmDateTime;

    @Column(name = "MANAGEMENT_CONFIRM_IDEA")
    @ApiParam("物管确认意见")
    private String managementConfirmIdea;

    @Column(name = "REGULATE_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("调达确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer regulateConfirm;

    @Column(name = "REGULATE_CONFIRM_DATE_TIME")
    @ApiParam("调达确认时间")
    private String regulateConfirmDateTime;

    @Column(name = "REGULATE_CONFIRM_IDEA")
    @ApiParam("调达确认意见")
    private String regulateConfirmIdea;

    @Column(name = "CONTACT_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("联络单确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer contactConfirm;

    @Column(name = "CONTACT_CONFIRM_DATE_TIME")
    @ApiParam("联络单确认时间")
    private String contactConfirmDateTime;

    @Column(name = "CONTACT_CONFIRM_IDEA")
    @ApiParam("联络单确认意见")
    private String contactConfirmIdea;

    @Column(name = "REPLY_CONFIRM",columnDefinition = "int default 20")
    @ApiParam("回复确认")
    @AnnoOutputColumn(refClass = QmsEnumUtil.CONFIRM_STATUS.class, refForeignKey = "value", value = "description")
    private Integer replyConfirm;

    @Column(name = "REPLY_CONFIRM_DATE_TIME")
    @ApiParam("回复确认时间")
    private String replyConfirmDateTime;

    @Column(name = "GAME_ACCEPTANCE_CONFIRM")
    @ApiParam("对策接收确定")
    private String gameAcceptanceConfirm;

    @Column(name = "IMPROVEMENT_EFFECT_CONFIRM")
    @ApiParam("对策接收确定")
    private String improvementEffectConfirm;

    @Transient
    @ApiParam("开始时间")
    private String createDatetimeStart;

    @Transient
    @ApiParam("结束时间")
    private String createDatetimeEnd;
}
