package cn.estsh.i3plus.pojo.qms.model.bu;

import cn.estsh.i3plus.pojo.base.annotation.AnnoOutputColumn;
import cn.estsh.i3plus.pojo.base.annotation.DynamicField;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import cn.estsh.i3plus.pojo.qms.util.QmsEnumUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;

import javax.persistence.Column;
import java.util.List;

/**
 * @Description: 质检拓展model
 * @Author: jiaqi.hou
 * @date: 2022-06-20
 */
@Data
@Api("质检拓展model")
public class WmsQCMasterExtModel extends BaseBean {


    @ApiParam("单号")
    public String orderNo;

    /**
     * 业务类型:IQC=进料检验,IPQC=在线检验,
     * FQC=成品检验,OQC=出货检验
     */
    @ApiParam(value = "业务类型", example = "0")
    @AnnoOutputColumn(refClass = WmsEnumUtil.QC_INFO_TYPE.class, refForeignKey = "value", value = "description")
    public Integer orderType;

    /**
     * 状态:1=创建,5=待处理,10=已完成,90=已关闭,91=已取消
     */
    @ApiParam(value = "单据状态", example = "1")
    @AnnoOutputColumn(refClass = QmsEnumUtil.QC_INFO_STATUS_EXT.class, refForeignKey = "value", value = "description")
    public Integer orderStatus;

    /**
     * 状态:10=质检中,20=合格,30=不合格
     */
    @ApiParam(value = "质检状态", example = "1")
    @AnnoOutputColumn(refClass = WmsEnumUtil.PO_QC_STATUS.class, refForeignKey = "value", value = "description")
    public Integer qcStatus;

    @Column(name = "REMARK")
    @ApiParam("备注")
    public String remark;

    @ApiParam("客户编号")
    public String custNo;

    @ApiParam("供应商编号")
    public String vendorNo;

    @Column(name = "VERSION")
    @ApiParam(value = "版本", example = "1")
    public Integer version;

    @ApiParam("关联单号类型")
    @DynamicField(webFieldType = CommonEnumUtil.FIELD_TYPE.SELECT, dataSrc = "LINK_ORDER_TYPE")
    public String refType;

    @ApiParam("关联单号")
    public String refSrc;

    @ApiParam("PO数量")
    private Double poQty;


    @ApiParam(value = "客户简称")
    private String custName;

    @ApiParam(value = "供应商全称")
    private String vendorDesc;

    @ApiParam(value = "是否生产任务", example = "1")
    @AnnoOutputColumn(refClass = WmsEnumUtil.IS_GENERAL_TASK.class, refForeignKey = "value", value = "description")
    public Integer isTask;

    @ApiParam(value = "是否散件", example = "2")
    @AnnoOutputColumn(refClass = WmsEnumUtil.TRUE_OR_FALSE.class, refForeignKey = "value", value = "description")
    public Integer isPart;

    @ApiParam(value = "ERP单号")
    public String erpSrcNo;

    @ApiParam(value = "零件号")
    public String partNo;

    @ApiParam(value = "零件名称")
    public String partNameRdd;

    @ApiParam(value = "收货数量")
    public Double qty;

    @ApiParam(value = "供应商批次")
    private String dateCode;

    @ApiParam(value = "收货日期")
    private String rcDate;

    @ApiParam(value = "收货数量")
    private Double rcQty;

    @ApiParam(value = "质检状态")
    List<Integer> qcStatusList;

    @ApiParam("条码")
    private String sn;

    public WmsQCMasterExtModel(){}

    public WmsQCMasterExtModel(
            Long id,
            String organizeCode,
            String orderNo,
            Integer orderType,
            Integer orderStatus,
            Integer qcStatus,
            String remark,
            String custNo,
            String vendorNo,
            Integer version,
            String refType,
            String refSrc,
            String custName,
            String vendorDesc,
            Integer isTask,
            Integer isPart,
            String partNo,
            String partNameRdd,
            String createDatetime,
            String createUser,
            String modifyDatetime,
            String modifyUser,
            Integer isDeleted,
            Integer isValid) {
        this.id = id;
        this.organizeCode = organizeCode;
        this.orderNo = orderNo;
        this.orderType = orderType;
        this.orderStatus = orderStatus;
        this.qcStatus = qcStatus;
        this.remark = remark;
        this.custNo = custNo;
        this.vendorNo = vendorNo;
        this.version = version;
        this.refType = refType;
        this.refSrc = refSrc;
        this.custName = custName;
        this.vendorDesc = vendorDesc;
        this.isTask = isTask;
        this.isPart = isPart;
        this.partNo = partNo;
        this.partNameRdd = partNameRdd;
        this.createDatetime = createDatetime;
        this.createUser = createUser;
        this.modifyDatetime = modifyDatetime;
        this.modifyUser = modifyUser;
        this.isDeleted=isDeleted;
        this.isValid=isValid;
    }
}
