package cn.estsh.i3plus.pojo.wms.bean.health;

import lombok.Getter;
import org.springframework.expression.ExpressionParser;
import org.springframework.expression.spel.standard.SpelExpressionParser;
import org.springframework.expression.spel.support.StandardEvaluationContext;

import java.util.*;

/**
 * 健康度测算公式
 *  (#VAR202201070002/#VAR456)/(#VAR123/#VAR456)*100
 */
@Getter
public class WmsHealthIndexFormula {
    /**
     * 工厂代码
     */
    private final String organizeCode;
    /**
     * 健康度指标测算代码 (#VAR202201070002/#VAR456)/(#VAR123/#VAR456) * 100
     */
    private final String calcFormula;
    /**
     * 变量列表
     */
    private Set<WmsHealthIndexVariable> vars = new HashSet<>();
    /**
     * 变量对应的计算结果
     */
    private Map<WmsHealthIndexVariable, WmsHealthIndexVariableValue> results =
            new HashMap<>();


    public WmsHealthIndexFormula(final String organizeCode,final String calcFormula){
        if(null==organizeCode){
            throw  new IllegalArgumentException("organizeCode can't be null");
        }
        if(null==calcFormula){
            throw  new IllegalArgumentException("calcFormula can't be null");
        }
        this.calcFormula = calcFormula;
        this.organizeCode = organizeCode;
        checkCode();
        initVars();
    }

    /**
     * 验证公式是否正常
     */
    private void checkCode(){
    }

    /**
     * 根据配置拆分和初始化变量
     * @return
     */
    private void initVars(){
        Set<WmsHealthIndexVariable> vars = new HashSet<>();
        final String [] varTemp = this.calcFormula.split("#");
        for(String varStrItem : varTemp) {
            if (!varStrItem.startsWith("VAR")||varStrItem.length()<15) {
                continue;
            }
            String variableCode = varStrItem.substring(0, 15);
            vars.add(new WmsHealthIndexVariable(organizeCode,variableCode));
        }
        this.vars = vars;
    }

    public void addResult(WmsHealthIndexVariable key, WmsHealthIndexVariableValue result){
        if(null!=result && null!=key) {
        	if(key.isRefresh()) {
            key.changeValue(result);
        	}
            results.put(key, result);
        }
    }

    public boolean isResultEmpty(){
        return results.isEmpty();
    }

    /**
     *  待执行变量结果和变量结果集是否相同
     * @return
     */
    public boolean isResultSizeSameWithVarsSize(){
        return results.size() == vars.size();
    }

    /**
     * 获取单个值对象
     */
    public WmsHealthIndexVariableValue getSingleValue(){
        if(!isResultEmpty()) {
            WmsHealthIndexVariableValue variableValue = com.google.common.collect.Lists
                    .newArrayList(results.values()).get(0);
            return variableValue;
        }
        return null;
    }

    /**
     * 根据健康度指标calcFormula，计算SPEL表达式的值
     * @return
     */
    public Double getSpelResult(){
        if(results.isEmpty()) {
            return -1.0;
        }
        Double calcResult = 0.0;
        int resultSize = results.size();
        StandardEvaluationContext ctx = new StandardEvaluationContext();
        ExpressionParser parser = new SpelExpressionParser();
        //单个变量，特殊情况特殊处理
        if(resultSize == 1){
            calcResult = getSingleValue().getValue();
        }else{
            Set<WmsHealthIndexVariable> varKeys = results.keySet();
            for (WmsHealthIndexVariable varKey : varKeys) {
                // 取出该变量名称对应的计算结果
                WmsHealthIndexVariableValue variableValue = results.get(varKey);
                Double value = variableValue.getValue();
                ctx.setVariable(varKey.getId().getVariable(), value);
            }
            // 存在多个变量，则按照SPEL进行运算最后取值
            try {
                calcResult =  (Double) parser.parseExpression(calcFormula)
                        .getValue(ctx);
            } catch (Exception e) {
                calcResult = -1.0;
            }
        }
        return calcResult;
    }

    public static WmsHealthIndexFormula of(String organizeCode,String calcFormula){
        return new WmsHealthIndexFormula(organizeCode,calcFormula);
    }
}
